package owapi;

/**
 *
 *<P><H3>COM: TYPELIB=5CE02372-121E-4BCE-8774-80FBC36C509E, CLSID=19266018-0D0B-448d-B27D-B74108AE2DB1</H3></P>
 *
 * Utility class, replaces any occurrence of "boolean[]" in COM code
 *
 * @version CLSID=19266018-0D0B-448d-B27D-B74108AE2DB1 - 1.00
 * @com.register ( clsid=19266018-0D0B-448d-B27D-B74108AE2DB1, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class BooleanArray
   implements com.ms.com.IUnknown
{
   boolean[] array = null;
   
   /**
    * Returns the internal array, for scripting languages where using the array
    * is user than using this helper
    * @return boolean[] the internal array this class is wrapping
    */
   public boolean[] unwrap()
   {
      return this.array;
   }
   
   /**
    * Sets the internal array, for scripting languages where using the array
    * is easier than using this helper
    * @param newArray new internal array
    */
   public void wrap(boolean[] newArray)
   {
      this.array = newArray;
   }

   /**
    * Returns boolean at the specified index.
    * @param index the index to retrieve element
    * @return the value at the specified index
    */
   public boolean getAt(int index)
   {
      return array[index];
   }
   
   /**
    * Sets the element at the specified index.
    * @param index the index to retrieve element
    * @param value the new value
    */
   public void setAt(int index, boolean value)
   {
      array[index] = value;
   }

   /**
    * Returns value at the specified index as a string.
    * @param index the index to retrieve element
    * @return the value at the specified index
    */
   public String getAtAsString(int index)
   {
      return array[index]+"";
   }

   /**
    * Sets the element at the specified index with a string.
    * @param index the index to retrieve element
    * @param value the new value
    */
   public void setAtAsString(int index, String value)
   {
      array[index] = Boolean.valueOf(value).booleanValue();
   }

   /**
    * Sets the size of the boolean[]
    * @param size the new size
    */
   public void setSize(int size)
   {
      boolean[] tmp = array;
      array = new boolean[size];
      if(tmp!=null)
         System.arraycopy(tmp,0,array,0,Math.min(tmp.length,size));
   }

   /**
    * Returns the size of the boolean[]
    * @param size the new size
    */
   public int getSize()
   {
      return array.length;
   }

   /**
    * Converts the boolean[] to a string
    * @return boolean[] as a string
    */
   public String toString()   
   {
      StringBuffer sb = new StringBuffer(7*array.length);
      for (int i = 0; i < array.length; i++)
      {
         if(i>0)
            sb.append(", ");
         sb.append(array[i]);
      }

      return sb.toString();
   }
   
   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.array != null;
   }
   
   /**
    * Used to build from an actual array returned from a Java object
    */
   public void buildFromObject(Object buildObj)
   {
      if(buildObj instanceof BooleanArray)
         this.array = ((BooleanArray)buildObj).array;
      else
         this.array = (boolean[])((boolean[])buildObj).clone();
   }

   BooleanArray setupObject(Object o)
   {
      this.array = (boolean[])o;
      return this;
   }
}
