// COM proxy class, output from FunctionList.js
package owapi;
/**
 * CRC16 is a class containing an implementation of the
 * Cyclic-Redundency-Check (CRC) CRC16.  The CRC16 is used in
 * iButton memory packet structure.
 * <p>
 * CRC16 is based on the polynomial = X^16 + X^15 + X^2 + 1.
 *
 * @version CLSID=8C7253E1-34C2-4C4F-B040-8A152D7287F3 -     0.00, 28 Aug 2000
 * @author     DS
 * @com.register ( clsid=8C7253E1-34C2-4C4F-B040-8A152D7287F3, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class CRC16
   implements com.ms.com.IUnknown
{


   /**
    * Perform the CRC16 on the data element based on a zero seed.
    * <p>
    * CRC16 is based on the polynomial = X^16 + X^15 + X^2 + 1.
    *
    * @param  dataToCrc     data element on which to perform the CRC16
    * @return  CRC16 value
    */
   public int compute(int dataToCrc)
   {      
      return com.dalsemi.onewire.utils.CRC16.compute(dataToCrc);
   }

   /**
    * Perform the CRC16 on the data element based on the provided seed.
    * <p>
    * CRC16 is based on the polynomial = X^16 + X^15 + X^2 + 1.
    *
    * @param  dataToCrc     data element on which to perform the CRC16
    * @return  CRC16 value
    */
   public int compute(int dataToCrc, int seed)
   {      
      return com.dalsemi.onewire.utils.CRC16.compute(dataToCrc, seed);
   }

   /**
    * Perform the CRC16 on an array of data elements based on a
    * zero seed.
    * <p>
    * CRC16 is based on the polynomial = X^16 + X^15 + X^2 + 1.
    *
    * @param   dataToCrc   array of data elements on which to perform the CRC16
    *
    * @return  CRC16 value
    */
   public int computeFromBytes(ByteArray dataToCrc )
   {      
      return com.dalsemi.onewire.utils.CRC16.compute(dataToCrc .array);
   }

   /**
    * Perform the CRC16 on an array of data elements based on a
    * zero seed.
    * <p>
    * CRC16 is based on the polynomial = X^16 + X^15 + X^2 + 1.
    *
    * @param   dataToCrc   array of data elements on which to perform the CRC16
    * @param   off         offset into the data array
    * @param   len         length of data to CRC16
    *
    * @return  CRC16 value
    */
   public int computeFromBytes(ByteArray dataToCrc , int off, int len)
   {      
      return com.dalsemi.onewire.utils.CRC16.compute(dataToCrc .array, off, len);
   }

   /**
    * Perform the CRC16 on an array of data elements based on the
    * provided seed.
    * <p>
    * CRC16 is based on the polynomial = X^16 + X^15 + X^2 + 1.
    *
    * @param   dataToCrc   array of data elements on which to perform the CRC16
    * @param   off         offset into the data array
    * @param   len         length of data to CRC16
    * @param   seed        seed to use for CRC16
    *
    * @return  CRC16 value
    */
   public int computeFromBytes(ByteArray dataToCrc , int off, int len, int seed)
   {      
      return com.dalsemi.onewire.utils.CRC16.compute(dataToCrc .array, off, len, seed);
   }

   /**
    * Perform the CRC16 on an array of data elements based on a
    * zero seed.
    * <p>
    * CRC16 is based on the polynomial = X^16 + X^15 + X^2 + 1.
    *
    * @param   dataToCrc   array of data elements on which to perform the CRC16
    * @param   off         offset into the data array
    * @param   len         length of data to CRC16
    *
    * @return  CRC16 value
    */
   public int computeFromBytes(ByteArray dataToCrc , int off)
   {      
      return com.dalsemi.onewire.utils.CRC16.compute(dataToCrc .array, off);
   }


}
