package owapi;

/**
 *
 *<P><H3>COM: TYPELIB=5CE02372-121E-4BCE-8774-80FBC36C509E, CLSID=55402D8A-EFF4-485f-93A9-8141CF267BE3</H3></P>
 *
 * Utility class, replaces any occurrence of "char[]" in COM code
 *
 * @version CLSID=55402D8A-EFF4-485f-93A9-8141CF267BE3 - 1.00
 * @com.register ( clsid=55402D8A-EFF4-485f-93A9-8141CF267BE3, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class CharArray
   implements com.ms.com.IUnknown
{
   char[] array = null;
   
   /**
    * Returns the internal array, for scripting languages where using the array
    * is user than using this helper
    * @return char[] the internal array this class is wrapping
    */
   public char[] unwrap()
   {
      return this.array;
   }
   
   /**
    * Sets the internal array, for scripting languages where using the array
    * is easier than using this helper
    * @param newArray new internal array
    */
   public void wrap(char[] newArray)
   {
      this.array = newArray;
   }

   /**
    * Returns char at the specified index.
    * @param index the index to retrieve element
    * @return the value at the specified index
    */
   public char getAt(int index)
   {
      return array[index];
   }
   
   /**
    * Sets the element at the specified index.
    * @param index the index to retrieve element
    * @param value the new value
    */
   public void setAt(int index, char value)
   {
      array[index] = value;
   }

   /**
    * Returns value at the specified index as a string.
    * @param index the index to retrieve element
    * @return the value at the specified index
    */
   public String getAtAsString(int index)
   {
      return array[index]+"";
   }

   /**
    * Sets the element at the specified index with a string.
    * @param index the index to retrieve element
    * @param value the new value
    */
   public void setAtAsString(int index, String value)
   {
      array[index] = (value).charAt(0);
   }

   /**
    * Sets the size of the char[]
    * @param size the new size
    */
   public void setSize(int size)
   {
      char[] tmp = array;
      array = new char[size];
      if(tmp!=null)
         System.arraycopy(tmp,0,array,0,Math.min(tmp.length,size));
   }

   /**
    * Returns the size of the char[]
    * @param size the new size
    */
   public int getSize()
   {
      return array.length;
   }

   /**
    * Converts the char[] to a string
    * @return char[] as a string
    */
   public String toString()   
   {
      StringBuffer sb = new StringBuffer(7*array.length);
      for (int i = 0; i < array.length; i++)
      {
         if(i>0)
            sb.append(", ");
         sb.append(array[i]);
      }

      return sb.toString();
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.array != null;
   }
   
   /**
    * Used to build from an actual array returned from a Java object
    */
   public void buildFromObject(Object buildObj)
   {
      if(buildObj instanceof CharArray)
         this.array = ((CharArray)buildObj).array;
      else
         this.array = (char[])((char[])buildObj).clone();
   }

   CharArray setupObject(Object o)
   {
      this.array = (char[])o;
      return this;
   }
}
