// COM proxy class, output from FunctionList.js
package owapi;
/**
 * A <code>CommandAPDU</code> represents an ISO 7816-4 specified
 * Application Protocol Data Unit (APDU) sent to a
 * smart card. A response from the smart card is in turn represented
 * by a <code>ResponseAPDU</code>.<BR><BR>
 *
 * According to ISO 7816-4, a <code>CommandAPDU</code> has the following
 * format: <pre>
 *                  HEADER         |           BODY
 *         CLA    INS    P1    P2  |  [LC]    [DATA]    [LE]</pre>
 * where
 * <ul>
 * <li><code>CLA</code>  is the class byte
 * <li><code>INS</code>  is the instruction byte
 * <li><code>P1</code>   is the first parameter byte
 * <li><code>P2</code>   is the second parameter byte
 * <li><code>LC</code>   is the number of bytes present in the data block
 * <li><code>DATA</code> is an byte array of data to be sent
 * <li><code>LE</code>   is the maximum number of bytes expected in the <code>ResponseAPDU</code>
 * <li><code>[ ]</code>  denotes optional fields
 * </ul>
 *
 * <H3> Usage </H3> 
 * <OL>
 * <LI> 
 *    <code><pre>
 *   byte[] buffer = {(byte)0x90, (byte)0x00, (byte)0x00, (byte)0x00, 
 *                    (byte)0x01, (byte)0x02, (byte)0x03};
 *   CommandAPDU capdu = new CommandAPDU(buffer); </pre></code>
 * <LI>
 *   <code><pre>
 *   CommandAPDU capdu = new CommandAPDU((byte)0x90, (byte)0x00, (byte)0x00, (byte)0x00, 
 *                                       (byte)0x01, (byte)0x02, (byte)0x03);</pre></code>
 * </OL>
 * 
 * <H3> Additonal information </H3> 
 * <DL>
 * <DD><A HREF="http://www.opencard.org"> http://www.opencard.org</A>
 * </DL>
 * 
 * @see ResponseAPDU
 * @see OneWireContainer16
 * 
 * @version CLSID=B15D8BD8-0D2F-43E1-B069-AC787031E072 -     0.00, 28 Aug 2000
 * @author     YL
 *
 * @com.register ( clsid=B15D8BD8-0D2F-43E1-B069-AC787031E072, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class CommandAPDU
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.container.CommandAPDU objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public CommandAPDU()
   {
   }

   CommandAPDU(com.dalsemi.onewire.container.CommandAPDU o)
   {
      this.objectInstance = o;
   }
   CommandAPDU(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.container.CommandAPDU)o);
   }

   public static final int CLA
          = com.dalsemi.onewire.container.CommandAPDU.CLA;

   public static final int INS
          = com.dalsemi.onewire.container.CommandAPDU.INS;

   public static final int P1
          = com.dalsemi.onewire.container.CommandAPDU.P1;

   public static final int P2
          = com.dalsemi.onewire.container.CommandAPDU.P2;

   public static final int LC
          = com.dalsemi.onewire.container.CommandAPDU.LC;

   /**
    * Constructs a new ISO 7816-4 <code>CommandAPDU</code>.
    *
    * @param     buffer  the entire <code>CommandAPDU</code> as a byte array
    */
   public void createNewInstance(ByteArray buffer)
   {      
      objectInstance = new com.dalsemi.onewire.container.CommandAPDU(buffer.array);
   }

   /**
    * Constructs a new ISO 7816-4 CASE 1 <code>CommandAPDU</code>.
    *
    * @param     cla  <code>CLA</code> byte
    * @param     ins  <code>INS</code> byte
    * @param     p1   parameter byte <code>P1</code>
    * @param     p2   parameter byte <code>P2</code>
    */
   public void createNewInstance(byte cla, byte ins, byte p1, byte p2)
   {      
      objectInstance = new com.dalsemi.onewire.container.CommandAPDU(cla, ins, p1, p2);
   }

   /**
    * Constructs a new ISO 7816-4 CASE 2 <code>CommandAPDU</code>.
    *
    * @param     cla  <code>CLA</code> byte
    * @param     ins  <code>INS</code> byte
    * @param     p1   parameter byte <code>P1</code>
    * @param     p2   parameter byte <code>P2</code>
    * @param     le   length of expected <code>ResponseAPDU</code>,
    *                 ranges from <code>-1</code> to 
    *                 <code>255</code>, where <code>-1</code> is no length
    *                 and <code>0</code> is the maximum length 
    *                 supported
    *
    * @see       ResponseAPDU
    */
   public void createNewInstanceFromInt(byte cla, byte ins, byte p1, byte p2, int le)
   {      
      objectInstance = new com.dalsemi.onewire.container.CommandAPDU(cla, ins, p1, p2, le);
   }

   /**
    * Constructs a new ISO 7816-4 CASE 3 <code>CommandAPDU</code>.
    *
    * @param     cla  <code>CLA</code> byte
    * @param     ins  <code>INS</code> byte
    * @param     p1   parameter byte <code>P1</code>
    * @param     p2   parameter byte <code>P2</code>
    * @param     data this <code>CommandAPDU</code> data as a byte array,
    *                 <code>LC</code> is derived from this data 
    *                 array length
    */
   public void createNewInstance(byte cla, byte ins, byte p1, byte p2, ByteArray data)
   {      
      objectInstance = new com.dalsemi.onewire.container.CommandAPDU(cla, ins, p1, p2, data.array);
   }

   /**
    * Constructs a new ISO 7816-4 CASE 4 <code>CommandAPDU</code>.
    *
    * @param     cla  <code>CLA</code> byte
    * @param     ins  <code>INS</code> byte
    * @param     p1   parameter byte <code>P1</code>
    * @param     p2   parameter byte <code>P2</code>
    * @param     data <code>CommandAPDU</code> data as a byte array,
    *                 <code>LC</code> is derived from this data 
    *                 array length
    * @param     le   length of expected <code>ResponseAPDU</code>,
    *                 ranges from <code>-1</code> to 
    *                 <code>255</code>, where <code>-1</code> is no length
    *                 and <code>0</code> is the maximum length 
    *                 supported
    *
    * @see       ResponseAPDU
    */
   public void createNewInstanceFromInt(byte cla, byte ins, byte p1, byte p2, ByteArray data, int le)
   {      
      objectInstance = new com.dalsemi.onewire.container.CommandAPDU(cla, ins, p1, p2, data.array, le);
   }

   /**
    * Gets the <code>CLA</code> byte value.
    *
    * @return <code>CLA</code> byte of this <code>CommandAPDU</code>
    */
   public byte getCLA()
   {      
      return objectInstance.getCLA();
   }

   /**
    * Gets the <code>INS</code> byte value.
    *
    * @return <code>INS</code> byte of this <code>CommandAPDU</code>
    */
   public byte getINS()
   {      
      return objectInstance.getINS();
   }

   /**
    * Gets the first parameter (<code>P1</code>) byte value.
    *
    * @return <code>P1</code> byte of this <code>CommandAPDU</code>
    */
   public byte getP1()
   {      
      return objectInstance.getP1();
   }

   /**
    * Gets the second parameter (<code>P2</code>) byte value.
    *
    * @return <code>P2</code> byte of this <code>CommandAPDU</code>
    */
   public byte getP2()
   {      
      return objectInstance.getP2();
   }

   /**
    * Gets the length of data field (<code>LC</code>).
    *
    * @return the number of bytes present in the data field of
    * this <code>CommandAPDU</code>, <code>0</code> 
    * indicates that there is no body
    */
   public int getLC()
   {      
      return objectInstance.getLC();
   }

   /**
    * Gets the expected length of <code>ResponseAPDU</code> (<code>LE</code>).
    *
    * @return the maximum number of bytes expected in the data field
    * of the <code>ResponseAPDU</code> to this <code>CommandAPDU</code>, 
    * <code>-1</code> indicates that no value is specified
    *
    * @see       ResponseAPDU
    */
   public int getLE()
   {      
      return objectInstance.getLE();
   }

   /**
    * Gets this <code>CommandAPDU</code> <code>apduBuffer</code>.
    * This method allows user to manipulate the buffered <code>CommandAPDU</code>.
    *
    * @return  <code>apduBuffer</code> that holds the current <code>CommandAPDU</code>
    *
    * @see #getBytes
    *
    */
   public final ByteArray getBuffer()
   {      
      return new ByteArray().setupObject(objectInstance.getBuffer());
   }

   /**
    * Gets the byte at the specified offset in the <code>apduBuffer</code>.
    * This method can only be used to access the <code>CommandAPDU</code>
    * currently stored.  It is not possible to read beyond the
    * end of the <code>CommandAPDU</code>.
    *
    * @param index   the offset in the <code>apduBuffer</code>
    *
    * @return        the value at the given offset,
    *                or <code>-1</code> if the offset is invalid
    *
    * @see #setByte
    * @see #getLength
    */
   public final byte getByte(int index)
   {      
      return objectInstance.getByte(index);
   }

   /**
    * Gets a byte array of the buffered <code>CommandAPDU</code>.
    * The byte array returned gets allocated with the exact size of the
    * buffered <code>CommandAPDU</code>. To get direct access to the 
    * internal <code>apduBuffer</code>, use <code>getBuffer()</code>.
    *
    * @return  the buffered <code>CommandAPDU</code> copied into a new array
    *
    * @see #getBuffer
    */
   public final ByteArray getBytes()
   {      
      return new ByteArray().setupObject(objectInstance.getBytes());
   }

   /**
    * Gets the length of the buffered <code>CommandAPDU</code>.
    *
    * @return  the length of the <code>CommandAPDU</code> currently stored
    */
   public final int getLength()
   {      
      return objectInstance.getLength();
   }

   /**
    * Sets the byte value at the specified offset in the 
    * <code>apduBuffer</code>.
    * This method can only be used to modify a <code>CommandAPDU</code>
    * already stored. It is not possible to set bytes beyond
    * the end of the current <code>CommandAPDU</code>.
    *
    * @param index   the offset in the <code>apduBuffer</code>
    * @param value   the new byte value to store
    *
    * @see #getByte
    * @see #getLength
    *
    */
   public final void setByte(int index, byte value)
   {      
      objectInstance.setByte(index, value);
   }

   /**
    * Gets a string representation of this <code>CommandAPDU</code>.
    *
    * @return a string describing this <code>CommandAPDU</code>
    */
   public java.lang.String toString()
   {      
      return objectInstance.toString();
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   CommandAPDU setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.CommandAPDU)o;
      return this;
   }
}
