// COM proxy class, output from FunctionList.js
package owapi;
/**
 * Utilities for conversion between miscellaneous datatypes.
 *
 * @version CLSID=9501221D-177A-4230-8B25-0DD821F58166 -     1.00, 28 December 2001
 * @author     SH
 * @com.register ( clsid=9501221D-177A-4230-8B25-0DD821F58166, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class Convert
   implements com.ms.com.IUnknown
{


   /**
    * Converts a temperature reading from Celsius to Fahrenheit.
    *
    * @param   celsiusTemperature temperature value in Celsius
    *
    * @return  the Fahrenheit conversion of the supplied temperature
    */
   public final double toFahrenheitFromDouble(double celsiusTemperature)
   {      
      return com.dalsemi.onewire.utils.Convert.toFahrenheit(celsiusTemperature);
   }

   /**
    * Converts a temperature reading from Fahrenheit to Celsius.
    *
    * @param  fahrenheitTemperature temperature value in Fahrenheit
    *
    * @return  the Celsius conversion of the supplied temperature
    */
   public final double toCelsiusFromDouble(double fahrenheitTemperature)
   {      
      return com.dalsemi.onewire.utils.Convert.toCelsius(fahrenheitTemperature);
   }

   /**
    * This method constructs a long from a LSByte byte array of specified length.
    *
    * @param  byteArray byte array to convert to a long (LSByte first)
    * @param  offset byte offset into the array where to start to convert
    * @param  len number of bytes to use to convert to a long
    *
    * @returns value constructed from bytes
    */
   public final String toLongFromBytes(ByteArray byteArray, int offset, int len)
   {      
      return ""+com.dalsemi.onewire.utils.Convert.toLong(byteArray.array, offset, len);
   }

   /**
    * This method constructs a long from a LSByte byte array of specified length.
    *
    * @param  byteArray byte array to convert to a long (LSByte first)
    * @param  offset byte offset into the array where to start to convert
    * @param  len number of bytes to use to convert to a long
    *
    * @returns value constructed from bytes
    */
   public final String toLongFromBytes(ByteArray byteArray)
   {      
      return ""+com.dalsemi.onewire.utils.Convert.toLong(byteArray.array);
   }

   /**
    * This method constructs a LSByte byte array with specified length from a long.
    *
    * @param  longVal the long value to convert to a byte array.
    * @param  byteArray LSByte first byte array, holds bytes from long
    * @param  offset byte offset into the array
    * @param  len number of bytes to get
    *
    * @returns value constructed from bytes
    */
   public final void toByteArrayFromLong(String longVal, ByteArray byteArray, int offset, int len)
   {      
      com.dalsemi.onewire.utils.Convert.toByteArray(Long.parseLong(longVal), byteArray.array, offset, len);
   }

   /**
    * This method constructs a LSByte byte array with specified length from a long.
    *
    * @param  longVal the long value to convert to a byte array.
    * @param  byteArray LSByte first byte array, holds bytes from long
    * @param  offset byte offset into the array
    * @param  len number of bytes to get
    *
    * @returns value constructed from bytes
    */
   public final void toByteArrayFromLong(String longVal, ByteArray byteArray)
   {      
      com.dalsemi.onewire.utils.Convert.toByteArray(Long.parseLong(longVal), byteArray.array);
   }

   /**
    * This method constructs a LSByte byte array with 8 bytes from a long.
    *
    * @param  longVal the long value to convert to a byte array.
    *
    * @returns value constructed from bytes
    */
   public final ByteArray toByteArrayFromLong(String longVal)
   {      
      return new ByteArray().setupObject(com.dalsemi.onewire.utils.Convert.toByteArray(Long.parseLong(longVal)));
   }

   /**
    * This method constructs an int from a LSByte byte array of specified length.
    *
    * @param  byteArray byte array to convert to an int (LSByte first)
    * @param  offset byte offset into the array where to start to convert
    * @param  len number of bytes to use to convert to an int
    *
    * @returns value constructed from bytes
    */
   public final int toIntFromBytes(ByteArray byteArray, int offset, int len)
   {      
      return com.dalsemi.onewire.utils.Convert.toInt(byteArray.array, offset, len);
   }

   /**
    * This method constructs an int from a LSByte byte array of specified length.
    *
    * @param  byteArray byte array to convert to an int (LSByte first)
    * @param  offset byte offset into the array where to start to convert
    * @param  len number of bytes to use to convert to an int
    *
    * @returns value constructed from bytes
    */
   public final int toIntFromBytes(ByteArray byteArray)
   {      
      return com.dalsemi.onewire.utils.Convert.toInt(byteArray.array);
   }

   /**
    * This method constructs a LSByte byte array with specified length from an int.
    *
    * @param  intVal the int value to convert to a byte array.
    * @param  byteArray LSByte first byte array, holds bytes from int
    * @param  offset byte offset into the array
    * @param  len number of bytes to get
    */
   public final void toByteArrayFromInt(int intVal, ByteArray byteArray, int offset, int len)
   {      
      com.dalsemi.onewire.utils.Convert.toByteArray(intVal, byteArray.array, offset, len);
   }

   /**
    * This method constructs a LSByte byte array with specified length from an int.
    *
    * @param  intVal the int value to convert to a byte array.
    * @param  byteArray LSByte first byte array, holds bytes from int
    * @param  offset byte offset into the array
    * @param  len number of bytes to get
    */
   public final void toByteArrayFromInt(int intVal, ByteArray byteArray)
   {      
      com.dalsemi.onewire.utils.Convert.toByteArray(intVal, byteArray.array);
   }

   /**
    * This method constructs a LSByte byte array with 4 bytes from an int.
    *
    * @param  longVal the long value to convert to a byte array.
    *
    * @returns value constructed from bytes
    */
   public final ByteArray toByteArrayFromInt(int intVal)
   {      
      return new ByteArray().setupObject(com.dalsemi.onewire.utils.Convert.toByteArray(intVal));
   }

   /**
    * <P>Converts a hex-encoded string into an array of bytes.</P>
    * <P>To illustrate the rules for parsing, the following String:<br>
    * "FF 0 1234 567"<br>
    * becomes:<br>
    * byte[]{0xFF,0x00,0x12,0x34,0x56,0x07}
    * </P>
    *
    * @param strData hex-encoded numerical string
    * @return byte[] the decoded bytes
    */
   public final ByteArray toByteArrayFromHexString(java.lang.String strData)
      throws com.dalsemi.onewire.utils.Convert. ConvertException
   {      
      return new ByteArray().setupObject(com.dalsemi.onewire.utils.Convert.toByteArray(strData));
   }

   /**
    * <P>Converts a hex-encoded string into an array of bytes.</P>
    * <P>To illustrate the rules for parsing, the following String:<br>
    * "FF 0 1234 567"<br>
    * becomes:<br>
    * byte[]{0xFF,0x00,0x12,0x34,0x56,0x07}
    * </P>
    *
    * @param strData hex-encoded numerical string
    * @param bData byte[] which will hold the decoded bytes
    * @return The number of bytes converted
    */
   public final int toByteArrayFromHexString(java.lang.String strData, ByteArray bData)
      throws com.dalsemi.onewire.utils.Convert. ConvertException
   {      
      return com.dalsemi.onewire.utils.Convert.toByteArray(strData, bData.array);
   }

   /**
    * <P>Converts a hex-encoded string into an array of bytes.</P>
    * <P>To illustrate the rules for parsing, the following String:<br>
    * "FF 0 1234 567"<br>
    * becomes:<br>
    * byte[]{0xFF,0x00,0x12,0x34,0x56,0x07}
    * </P>
    *
    * @param strData hex-encoded numerical string
    * @param bData byte[] which will hold the decoded bytes
    * @param offset the offset into bData to start placing bytes
    * @param length the maximum number of bytes to convert
    * @return The number of bytes converted
    */
   public final int toByteArrayFromHexString(java.lang.String strData, ByteArray bData, int offset, int length)
      throws com.dalsemi.onewire.utils.Convert. ConvertException
   {      
      return com.dalsemi.onewire.utils.Convert.toByteArray(strData, bData.array, offset, length);
   }

   /**
    * Converts a byte array into a hex-encoded String, using the provided
    * delimeter.
    *
    * @param data The byte[] to convert to a hex-encoded string
    * @return Hex-encoded String
    */
   public final java.lang.String toHexStringFromBytes(ByteArray data)
   {      
      return com.dalsemi.onewire.utils.Convert.toHexString(data.array);
   }

   /**
    * Converts a byte array into a hex-encoded String, using the provided
    * delimeter.
    *
    * @param data The byte[] to convert to a hex-encoded string
    * @param offset the offset to start converting bytes
    * @param length the number of bytes to convert
    * @return Hex-encoded String
    */
   public final java.lang.String toHexStringFromBytes(ByteArray data, int offset, int length)
   {      
      return com.dalsemi.onewire.utils.Convert.toHexString(data.array, offset, length);
   }

   /**
    * Converts a byte array into a hex-encoded String, using the provided
    * delimeter.
    *
    * @param data The byte[] to convert to a hex-encoded string
    * @param delimeter the delimeter to place between each byte of data
    * @return Hex-encoded String
    */
   public final java.lang.String toHexStringFromBytes(ByteArray data, java.lang.String delimeter)
   {      
      return com.dalsemi.onewire.utils.Convert.toHexString(data.array, delimeter);
   }

   /**
    * Converts a byte array into a hex-encoded String, using the provided
    * delimeter.
    *
    * @param data The byte[] to convert to a hex-encoded string
    * @param offset the offset to start converting bytes
    * @param length the number of bytes to convert
    * @param delimeter the delimeter to place between each byte of data
    * @return Hex-encoded String
    */
   public final java.lang.String toHexStringFromBytes(ByteArray data, int offset, int length, java.lang.String delimeter)
   {      
      return com.dalsemi.onewire.utils.Convert.toHexString(data.array, offset, length, delimeter);
   }

   /**
    * Converts a byte array into a hex-encoded String, using the provided
    * delimeter.
    *
    * @param data The byte[] to convert to a hex-encoded string
    * @return Hex-encoded String
    */
   public final java.lang.String toHexStringFromByte(byte data)
   {      
      return com.dalsemi.onewire.utils.Convert.toHexString(data);
   }

   /**
    * Converts a char array into a hex-encoded String, using the provided
    * delimeter.
    *
    * @param data The char[] to convert to a hex-encoded string
    * @return Hex-encoded String
    */
   public final java.lang.String toHexStringFromChars(CharArray data)
   {      
      return com.dalsemi.onewire.utils.Convert.toHexString(data.array);
   }

   /**
    * Converts a byte array into a hex-encoded String, using the provided
    * delimeter.
    *
    * @param data The char[] to convert to a hex-encoded string
    * @param offset the offset to start converting bytes
    * @param length the number of bytes to convert
    * @return Hex-encoded String
    */
   public final java.lang.String toHexStringFromChars(CharArray data, int offset, int length)
   {      
      return com.dalsemi.onewire.utils.Convert.toHexString(data.array, offset, length);
   }

   /**
    * Converts a char array into a hex-encoded String, using the provided
    * delimeter.
    *
    * @param data The char[] to convert to a hex-encoded string
    * @param delimeter the delimeter to place between each byte of data
    * @return Hex-encoded String
    */
   public final java.lang.String toHexStringFromChars(CharArray data, java.lang.String delimeter)
   {      
      return com.dalsemi.onewire.utils.Convert.toHexString(data.array, delimeter);
   }

   /**
    * Converts a char array into a hex-encoded String, using the provided
    * delimeter.
    *
    * @param data The char[] to convert to a hex-encoded string
    * @param offset the offset to start converting bytes
    * @param length the number of bytes to convert
    * @param delimeter the delimeter to place between each byte of data
    * @return Hex-encoded String
    */
   public final java.lang.String toHexStringFromChars(CharArray data, int offset, int length, java.lang.String delimeter)
   {      
      return com.dalsemi.onewire.utils.Convert.toHexString(data.array, offset, length, delimeter);
   }

   /**
    * Converts a char array into a hex-encoded String, using the provided
    * delimeter.
    *
    * @param data The char[] to convert to a hex-encoded string
    * @return Hex-encoded String
    */
   public final java.lang.String toHexStringFromChar(char data)
   {      
      return com.dalsemi.onewire.utils.Convert.toHexString(data);
   }

   /**
    * <P>Converts a hex-encoded string (LSByte) into a long.</P>
    * <P>To illustrate the rules for parsing, the following String:<br>
    * "FF 0 1234 567 12 03"<br>
    * becomes:<br>
    * long 0x03120756341200ff
    * </P>
    *
    * @param strData hex-encoded numerical string
    * @return the decoded long
    */
   public final String toLongFromHexString(java.lang.String strData)
      throws com.dalsemi.onewire.utils.Convert. ConvertException
   {      
      return ""+com.dalsemi.onewire.utils.Convert.toLong(strData);
   }

   /**
    * <P>Converts a long into a hex-encoded string (LSByte).</P>
    *
    * @param lValue the long integer to encode
    * @return String Hex-encoded String
    */
   public final java.lang.String toHexStringFromLong(String lValue)
   {      
      return com.dalsemi.onewire.utils.Convert.toHexString(Long.parseLong(lValue));
   }

   /**
    * <P>Converts a hex-encoded string (LSByte) into an int.</P>
    * <P>To illustrate the rules for parsing, the following String:<br>
    * "FF 0 1234 567 12 03"<br>
    * becomes:<br>
    * long 0x03120756341200ff
    * </P>
    *
    * @param strData hex-encoded numerical string
    * @return the decoded int
    */
   public final int toIntFromHexString(java.lang.String strData)
      throws com.dalsemi.onewire.utils.Convert. ConvertException
   {      
      return com.dalsemi.onewire.utils.Convert.toInt(strData);
   }

   /**
    * Converts a byte array into a hex-encoded String, using the provided
    * delimeter.
    *
    * @param data The byte[] to convert to a hex-encoded string
    * @param offset the offset to start converting bytes
    * @param length the number of bytes to convert
    * @return Hex-encoded String
    */
   public final java.lang.String toHexStringFromInt(int data)
   {      
      return com.dalsemi.onewire.utils.Convert.toHexString(data);
   }

   /**
    * <P>Converts a double value into a string with the specified number of
    * digits after the decimal place.</P>
    *
    * @param dubbel the double value to convert to a string
    * @param nFrac the number of digits to display after the decimal point
    *
    * @return String representation of the double value with the specified
    *         number of digits after the decimal place.
    */
   public final java.lang.String toStringFromDouble(double dubbel, int nFrac)
   {      
      return com.dalsemi.onewire.utils.Convert.toString(dubbel, nFrac);
   }

   /**
    * <P>Converts a float value into a string with the specified number of
    * digits after the decimal place.</P>
    * <P>Note: this function does not properly handle special case float
    * values such as Infinity and NaN.</P>
    *
    * @param flote the float value to convert to a string
    * @param nFrac the number of digits to display after the decimal point
    *
    * @return String representation of the float value with the specified
    *         number of digits after the decimal place.
    */
   public final java.lang.String toStringFromFloat(float flote, int nFrac)
   {      
      return com.dalsemi.onewire.utils.Convert.toString(flote, nFrac);
   }


}
