// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <p>This class is intended to help both developers of the 1-Wire API for
 * Java and developers using the 1-Wire API for Java to have a standard
 * method for printing debug messages.  Applications that want to see debug messages
 * should call  the <code>setDebugMode(boolean)</code> method.
 * Classes that want to print information under debugging
 * circumstances should call the <code>debug(String)</code>
 * method.</p>
 *
 * <p>Debug printing is turned off by default.</p>
 *
 * @version CLSID=03227B5E-628A-4617-B715-C3F42D33E2A0 -     1.00, 1 Sep 2003
 * @author     KA, SH
 * @com.register ( clsid=03227B5E-628A-4617-B715-C3F42D33E2A0, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class Debug
   implements com.ms.com.IUnknown
{


   /**
    * Sets the debug printing mode for this application.
    *
    * @param <code>true</code> to see debug messages, <code>false</code>
    *        to suppress them
    */
   public final void setDebugMode(boolean onoff)
   {      
      com.dalsemi.onewire.debug.Debug.setDebugMode(onoff);
   }

   /**
    * Gets the debug printing mode for this application.
    *
    * @return <code>true</code> indicates debug messages are on,
    *         <code>false</code> supresses them.
    */
   public final boolean getDebugMode()
   {      
      return com.dalsemi.onewire.debug.Debug.getDebugMode();
   }

	/**
	 * Sets the output stream for printing the debug info.
	 *
	 * @param out the output stream for printing the debug info.
	 */
   public final void setPrintStream(java.io.PrintStream outStream)
   {      
      com.dalsemi.onewire.debug.Debug.setPrintStream(outStream);
   }

   /**
    * Prints the specified <code>java.lang.String</code> object
    * if debug mode is enabled.  This method calls <code>PrintStream.println(String)</code>,
    * and pre-pends the <code>String</code> ">> " to the message, so
    * taht if a program were to call (when debug mode was enabled):
    * <code><pre>
    *     ");
    * </pre></code>
    * the resulting output would look like:
    * <code><pre>
    *     >> Some notification...
    * </pre></code>
    *
    * @param x the message to print out if in debug mode
    */
   public final void debug(java.lang.String a0)
   {      
      com.dalsemi.onewire.debug.Debug.debug(a0);
   }

   /**
    * Prints the specified array of bytes with a given label
    * if debug mode is enabled.  This method calls
    * <code>PrintStream.println(String)</code>,
    * and pre-pends the <code>String</code> ">> " to the message, so
    * taht if a program were to call (when debug mode was enabled):
    * <code><pre>
    *     ", myBytes);
    * </pre></code>
    * the resulting output would look like:
    * <code><pre>
    *     >> my label
    *     >>   FF F1 F2 F3 F4 F5 F6 FF
    * </pre></code>
    *
    * @param lbl the message to print out above the array
    * @param bytes the byte array to print out
    */
   public final void debug(java.lang.String a0, ByteArray a1)
   {      
      com.dalsemi.onewire.debug.Debug.debug(a0, a1.array);
   }

   /**
    * Prints the specified array of bytes with a given label
    * if debug mode is enabled.  This method calls
    * <code>PrintStream.println(String)</code>,
    * and pre-pends the <code>String</code> ">> " to the message, so
    * taht if a program were to call (when debug mode was enabled):
    * <code><pre>
    *     ", myBytes, 0, 8);
    * </pre></code>
    * the resulting output would look like:
    * <code><pre>
    *     >> my label
    *     >>   FF F1 F2 F3 F4 F5 F6 FF
    * </pre></code>
    *
    * @param lbl the message to print out above the array
    * @param bytes the byte array to print out
    * @param offset the offset to start printing from the array
    * @param length the number of bytes to print from the array
    */
   public final void debug(java.lang.String a0, ByteArray a1, int a2, int a3)
   {      
      com.dalsemi.onewire.debug.Debug.debug(a0, a1.array, a2, a3);
   }

   /**
    * Prints the specified exception with a given label
    * if debug mode is enabled.  This method calls
    * <code>PrintStream.println(String)</code>,
    * and pre-pends the <code>String</code> ">> " to the message, so
    * taht if a program were to call (when debug mode was enabled):
    * <code><pre>
    *     ", exception);
    * </pre></code>
    * the resulting output would look like:
    * <code><pre>
    *     >> my label
    *     >>   OneWireIOException: Device Not Present
    * </pre></code>
    *
    * @param lbl the message to print out above the array
    * @param bytes the byte array to print out
    * @param offset the offset to start printing from the array
    * @param length the number of bytes to print from the array
    */
   public final void debugWithException(java.lang.String a0, java.lang.Throwable a1)
   {      
      com.dalsemi.onewire.debug.Debug.debug(a0, a1);
   }

   /**
    * Prints out an exception stack trace for debugging purposes.
    * This is useful to figure out which functions are calling
    * a particular function at runtime.
    *
    */
   public final void stackTrace()
   {      
      com.dalsemi.onewire.debug.Debug.stackTrace();
   }


}
