package owapi;

/**
 *
 *<P><H3>COM: TYPELIB=5CE02372-121E-4BCE-8774-80FBC36C509E, CLSID=17E0CCD4-8F26-4eab-B4E9-56C0260F913A</H3></P>
 *
 * Utility class, replaces any occurrence of "double[]" in COM code
 *
 * @version CLSID=17E0CCD4-8F26-4eab-B4E9-56C0260F913A - 1.00
 * @com.register ( clsid=17E0CCD4-8F26-4eab-B4E9-56C0260F913A, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class DoubleArray
   implements com.ms.com.IUnknown
{
   double[] array = null;
   
   /**
    * Returns the internal array, for scripting languages where using the array
    * is user than using this helper
    * @return double[] the internal array this class is wrapping
    */
   public double[] unwrap()
   {
      return this.array;
   }
   
   /**
    * Sets the internal array, for scripting languages where using the array
    * is easier than using this helper
    * @param newArray new internal array
    */
   public void wrap(double[] newArray)
   {
      this.array = newArray;
   }

   /**
    * Returns double at the specified index.
    * @param index the index to retrieve element
    * @return the value at the specified index
    */
   public double getAt(int index)
   {
      return array[index];
   }
   
   /**
    * Sets the element at the specified index.
    * @param index the index to retrieve element
    * @param value the new value
    */
   public void setAt(int index, double value)
   {
      array[index] = value;
   }

   /**
    * Returns value at the specified index as a string.
    * @param index the index to retrieve element
    * @return the value at the specified index
    */
   public String getAtAsString(int index)
   {
      return Double.toString(array[index]);
   }

   /**
    * Sets the element at the specified index with a string.
    * @param index the index to retrieve element
    * @param value the new value
    */
   public void setAtAsString(int index, String value)
   {
      array[index] = Double.valueOf(value).doubleValue();
   }

   /**
    * Sets the size of the double[]
    * @param size the new size
    */
   public void setSize(int size)
   {
      double[] tmp = array;
      array = new double[size];
      if(tmp!=null)
         System.arraycopy(tmp,0,array,0,Math.min(tmp.length,size));
   }

   /**
    * Returns the size of the double[]
    * @param size the new size
    */
   public int getSize()
   {
      return array.length;
   }

   /**
    * Converts the double[] to a string
    * @return double[] as a string
    */
   public String toString()   
   {
      StringBuffer sb = new StringBuffer(7*array.length);
      for (int i = 0; i < array.length; i++)
      {
         if(i>0)
            sb.append(", ");
         sb.append(array[i]);
      }

      return sb.toString();
   }
   
   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.array != null;
   }
   
   /**
    * Used to build from an actual array returned from a Java object
    */
   public void buildFromObject(Object buildObj)
   {
      if(buildObj instanceof DoubleArray)
         this.array = ((DoubleArray)buildObj).array;
      else
         this.array = (double[])((double[])buildObj).clone();
   }

   DoubleArray setupObject(Object o)
   {
      this.array = (double[])o;
      return this;
   }
}
