package owapi;

/**
 *
 *<P><H3>COM: TYPELIB=5CE02372-121E-4BCE-8774-80FBC36C509E, CLSID=FC08049C-4158-4a88-9C83-581CD334CDC1</H3></P>
 *
 * Utility class, replaces any occurrence of "float[]" in COM code
 *
 * @version CLSID=FC08049C-4158-4a88-9C83-581CD334CDC1 - 1.00
 * @com.register ( clsid=FC08049C-4158-4a88-9C83-581CD334CDC1, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class FloatArray
   implements com.ms.com.IUnknown
{
   float[] array = null;
   
   /**
    * Returns the internal array, for scripting languages where using the array
    * is user than using this helper
    * @return float[] the internal array this class is wrapping
    */
   public float[] unwrap()
   {
      return this.array;
   }
   
   /**
    * Sets the internal array, for scripting languages where using the array
    * is easier than using this helper
    * @param newArray new internal array
    */
   public void wrap(float[] newArray)
   {
      this.array = newArray;
   }

   /**
    * Returns float at the specified index.
    * @param index the index to retrieve element
    * @return the value at the specified index
    */
   public float getAt(int index)
   {
      return array[index];
   }
   
   /**
    * Sets the element at the specified index.
    * @param index the index to retrieve element
    * @param value the new value
    */
   public void setAt(int index, float value)
   {
      array[index] = value;
   }

   /**
    * Returns value at the specified index as a string.
    * @param index the index to retrieve element
    * @return the value at the specified index
    */
   public String getAtAsString(int index)
   {
      return Float.toString(array[index]);
   }

   /**
    * Sets the element at the specified index with a string.
    * @param index the index to retrieve element
    * @param value the new value
    */
   public void setAtAsString(int index, String value)
   {
      array[index] = Float.valueOf(value).floatValue();
   }

   /**
    * Sets the size of the float[]
    * @param size the new size
    */
   public void setSize(int size)
   {
      float[] tmp = array;
      array = new float[size];
      if(tmp!=null)
         System.arraycopy(tmp,0,array,0,Math.min(tmp.length,size));
   }

   /**
    * Returns the size of the float[]
    * @param size the new size
    */
   public int getSize()
   {
      return array.length;
   }

   /**
    * Converts the float[] to a string
    * @return float[] as a string
    */
   public String toString()   
   {
      StringBuffer sb = new StringBuffer(7*array.length);
      for (int i = 0; i < array.length; i++)
      {
         if(i>0)
            sb.append(", ");
         sb.append(array[i]);
      }

      return sb.toString();
   }
   
   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.array != null;
   }
   
   /**
    * Used to build from an actual array returned from a Java object
    */
   public void buildFromObject(Object buildObj)
   {
      if(buildObj instanceof FloatArray)
         this.array = ((FloatArray)buildObj).array;
      else
         this.array = (float[])((float[])buildObj).clone();
   }

   FloatArray setupObject(Object o)
   {
      this.array = (float[])o;
      return this;
   }
}
