// COM proxy class, output from FunctionList.js
package owapi;
/** JibComm - an object that implements the necessary communication protocol
 * to access the Java iButtons.  Note that many methods are now synchronized
 * because they access global byte arrays.  This should not affect performance,
 * however, since applications <i>should</i> be using the <code>DSPortAdapter</code>
 * methods <code>beginExclusive(boolean)</code> and <code>endExclusive()</code>
 * to synchronize their 1-Wire operations.
 *
 * <H3> Usage </H3>
 *
 * <DL>
 * <DD> Used primarily by
 * {@link OneWireContainer16 OneWireContainer16}
 * </DL>
 *
 *
 * @see OneWireContainer16
 *
 * @version CLSID=58720074-BF3D-481A-8D9D-E904F39AAC37 -     0.04, 23 Jan 2002
 * @author     K, JK
 *
 *
 * @com.register ( clsid=58720074-BF3D-481A-8D9D-E904F39AAC37, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class JibComm
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.container.JibComm objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public JibComm()
   {
   }

   JibComm(com.dalsemi.onewire.container.JibComm o)
   {
      this.objectInstance = o;
   }
   JibComm(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.container.JibComm)o);
   }

   /**
    * Sets the time given by a host for the Java Powered <u>i</u>Button to
    * perform its task. In some cases, increases in this value may help
    * avoid communications errors.  63 milliseconds is the absolute lowest
    * rated value, but 96 milliseconds makes for fewer errors.
    *
    * @param runtime minimum runtime the host gives a Java <u>i</u>Button to perform its task (in ms)
    *
    * @throws IllegalArgumentException on illegal run time values (must be at least 63)
    */
   public void setMinRuntime(int runtime)
   {      
      com.dalsemi.onewire.container.JibComm.setMinRuntime(runtime);
   }

   /**
    * Sets the incremental increase in runtime a host will give a
    * Java Powered <u>i</u>Button to perform its task. Beyond the initial
    * minimum runtime, the Java <u>i</u>Button only understands increments
    * of 250 milliseconds.  However, due to clock and timing variations,
    * this value may need to be altered.  CRC errors are common if this value
    * is too low for a given operation. 250 milliseconds is the absolute lowest
    * rated value.  290 milliseconds is the default.
    *
    * @param multiplier new incremental runtime increase value to be used
    *                   for this Java <u>i</u>Button to perform its task (in ms)
    *
    * @throws IllegalArgumentException on illegal multiplier values (must be at least 250)
    */
   public void setRuntimeMultiplier(int multiplier)
   {      
      com.dalsemi.onewire.container.JibComm.setRuntimeMultiplier(multiplier);
   }

   /** Constructs a <code>JibComm</code> object to communicate with
   * this Java iButton.
   *
   * @param newAdapter adapter used to communicate with this Java iButton
   * @param newAddress address of this Java iButton
   *
   * @throws IllegalArgumentException Invalid Java iButton address
   *
   * @see Address
   */
   public void createNewInstance(OneWireContainer16 a0, DSPortAdapter a1, ByteArray a2)
      throws java.lang.IllegalArgumentException
   {      
      objectInstance = new com.dalsemi.onewire.container.JibComm(((com.dalsemi.onewire.container.OneWireContainer16)a0.objectInstance), ((com.dalsemi.onewire.adapter.DSPortAdapter)a1.objectInstance), a2.array);
   }

   /**
    * Transfers data to and from this Java iButton.
    *
    * @param data    byte array with data to be written to this Java iButton
    * @param runTime a <code>4</code> bit value <code>(0 -15)</code>
    *                that represents the expected run time of the device.
    *
    *  Actual run time is calculated as followed:
    *  <code><pre>
    *    runTime * 250 + 62.5 mS <BR>
    *  Therefore, 0 -> 0 * 250 + 62.5 =  62.5 mS
    *             1 -> 1 * 250 + 62.5 = 312.5 mS </pre></code>
    *  and so on.
    *
    * @return byte array containing data read back from this Java iButton.
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    */
   public synchronized ByteArray transferJibData(ByteArray data, int runTime)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ByteArray().setupObject(objectInstance.transferJibData(data.array, runTime));
   }

   /**
    * Corrects the device from a Power-On-Reset (POR) error.
    *
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    */
   public void correctPOR()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance.correctPOR();
   }

   /**
    * Gets the status from this Java iButton.
    *
    * @return status byte array read from this Java iButton.
    * The contents of the status array is as follows:
    *
    * <pre>
    *      Byte 0 - number of free bytes in the Input Buffer.
    *      Byte 1 - number of used bytes in the Output Buffer.
    *      Byte 2 - contents of the OWMS Register.
    *      Byte 3 - contents of the CPST register.</pre>
    *
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #checkStatus
    * @see    #setStatus
    */
   public synchronized void getStatus(ByteArray status, int start)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance.getStatus(status.array, start);
   }

   /**
    * Checks the status of this Java iButton.
    *
    * @param runTime a <code>4</code> bit value <code>(0 -15)</code>
    *                that represents the expected run time of the device.
    *  Actual run time is calculated as followed:
    *  <code><pre>
    *    runTime * 250 + 62.5 mS <BR>
    *  Therefore, 0 -> 0 * 250 + 62.5 =  62.5 mS
    *             1 -> 1 * 250 + 62.5 = 312.5 mS </pre></code>
    *  and so on.
    * @param dir <code>SEND</code> if sending data to this Java iButton,
    *            <code>RECEIVE</code> if receiving
    *
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getStatus
    * @see    #setStatus
    */
   public synchronized void checkStatus(int runTime, int dir, ByteArray status, int start)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.checkStatus(runTime, dir, status.array, start);
   }

   /**
    * Sets status register of this Java iButton.
    *
    * @param runTime a <code>4</code> bit value <code>(0 -15)</code>
    *                that represents the expected run time of the device
    *  Actual run time is calculated as followed:
    *  <code><pre>
    *    runTime * 250 + 62.5 mS <BR>
    *  Therefore, 0 -> 0 * 250 + 62.5 =  62.5 mS
    *             1 -> 1 * 250 + 62.5 = 312.5 mS </pre></code>
    *  and so on.
    *
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #checkStatus
    * @see    #getStatus
    */
   public synchronized void setStatus(int runTime)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance.setStatus(runTime);
   }

   /**
    * Sets header to be written to this Java iButton.
    *
    * @param header byte array with the header information
    *
    * @throws IllegalArgumentException Invalid header length
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #checkStatus
    * @see    #getHeader
    */
   public synchronized void setHeader(ByteArray header)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      objectInstance.setHeader(header.array);
   }

   /**
    * Gets header from this Java iButton.
    *
    * @return header read from this Java iButton.
    *
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #checkStatus
    * @see    #setHeader
    */
   public synchronized void getHeader(ByteArray header, int start)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance.getHeader(header.array, start);
   }

   /**
    * Sets data to be written to this Java iButton.
    *
    * @param data data to be written to this Java iButton
    *
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #checkStatus
    * @see    #getData
    */
   public void setData(ByteArray data)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance.setData(data.array);
   }

   /**
    * Gets data from this Java iButton.
    *
    * @param length expected number of bytes of data to be read from the IPR
    *
    * @return data from this Java iButton.
    *
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #checkStatus
    * @see    #setData
    */
   public ByteArray getData(int length)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return new ByteArray().setupObject(objectInstance.getData(length));
   }

   /**
    * Runs the Micro in this Java iButton.
    *
    * @param runTime a <code>4</code> bit value <code>(0 -15)</code>
    *                that represents the expected run time of the device
    *  Actual run time is calculated as followed:
    *  <code><pre>
    *    runTime * 250 + 62.5 mS <BR>
    *  Therefore, 0 -> 0 * 250 + 62.5 =  62.5 mS
    *             1 -> 1 * 250 + 62.5 = 312.5 mS </pre></code>
    *  and so on.
    *
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    */
   public synchronized void run(int runTime)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance.run(runTime);
   }

   /**
    * Interrupts the Micro in this Java iButton.
    *
    * @param runTime a <code>4</code> bit value <code>(0 -15)</code>
    *                that represents the expected run time of the device
    *  Actual run time is calculated as followed:
    *  <code><pre>
    *    runTime * 250 + 62.5 mS <BR>
    *  Therefore, 0 -> 0 * 250 + 62.5 =  62.5 mS
    *             1 -> 1 * 250 + 62.5 = 312.5 mS </pre></code>
    *  and so on.
    *
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    */
   public synchronized void interrupt(int runTime)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance.interrupt(runTime);
   }

   /**
    * Resets the Micro in this Java iButton.
    *
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    */
   public void reset()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance.reset();
   }

   /**
    * Sends command to this Java iButton.
    *
    * @param commandBuffer byte array containing the command
    * @param releaseBuffer byte array containing the release code
    * @param powerMode <code>true</code> if power supply is to be toggled
    * @param sleepTime sleep time for the program while the Micro runs.
    *                  Applicable only if <code>powerMode</code> is true.
    *
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    */
   public synchronized void sendCommand(ByteArray commandBuffer, ByteArray releaseBuffer, boolean powerMode, String sleepTime)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance.sendCommand(commandBuffer.array, releaseBuffer.array, powerMode, Long.parseLong(sleepTime));
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   JibComm setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.JibComm)o;
      return this;
   }
}
