package owapi;

/**
 *
 *<P><H3>COM: TYPELIB=5CE02372-121E-4BCE-8774-80FBC36C509E, CLSID=9377793F-B3A9-4865-AC7A-110F06F89D0C</H3></P>
 *
 * Utility class, replaces any occurrence of "long[]" in COM code
 *
 * @version CLSID=9377793F-B3A9-4865-AC7A-110F06F89D0C - 1.00
 * @com.register ( clsid=9377793F-B3A9-4865-AC7A-110F06F89D0C, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class LongArray
   implements com.ms.com.IUnknown
{
   long[] array = null;
   
   /**
    * Returns the internal array, for scripting languages where using the array
    * is user than using this helper
    * @return long[] the internal array this class is wrapping
    */
   public long[] unwrap()
   {
      return this.array;
   }
   
   /**
    * Sets the internal array, for scripting languages where using the array
    * is easier than using this helper
    * @param newArray new internal array
    */
   public void wrap(long[] newArray)
   {
      this.array = newArray;
   }

   /**
    * Returns long at the specified index.
    * @param index the index to retrieve element
    * @return the value at the specified index
    */
   public long getAt(int index)
   {
      return array[index];
   }
   
   /**
    * Sets the element at the specified index.
    * @param index the index to retrieve element
    * @param value the new value
    */
   public void setAt(int index, long value)
   {
      array[index] = value;
   }

   /**
    * Returns value at the specified index as a string.
    * @param index the index to retrieve element
    * @return the value at the specified index
    */
   public String getAtAsString(int index)
   {
      return Long.toString(array[index]);
   }

   /**
    * Sets the element at the specified index with a string.
    * @param index the index to retrieve element
    * @param value the new value
    */
   public void setAtAsString(int index, String value)
   {
      array[index] = Long.parseLong(value);
   }

   /**
    * Sets the size of the long[]
    * @param size the new size
    */
   public void setSize(int size)
   {
      long[] tmp = array;
      array = new long[size];
      if(tmp!=null)
         System.arraycopy(tmp,0,array,0,Math.min(tmp.length,size));
   }

   /**
    * Returns the size of the long[]
    * @param size the new size
    */
   public int getSize()
   {
      return array.length;
   }

   /**
    * Converts the long[] to a string
    * @return long[] as a string
    */
   public String toString()   
   {
      StringBuffer sb = new StringBuffer(7*array.length);
      for (int i = 0; i < array.length; i++)
      {
         if(i>0)
            sb.append(", ");
         sb.append(array[i]);
      }

      return sb.toString();
   }
   
   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.array != null;
   }
   
   /**
    * Used to build from an actual array returned from a Java object
    */
   public void buildFromObject(Object buildObj)
   {
      if(buildObj instanceof LongArray)
         this.array = ((LongArray)buildObj).array;
      else
         this.array = (long[])((long[])buildObj).clone();
   }

   LongArray setupObject(Object o)
   {
      this.array = (long[])o;
      return this;
   }
}
