// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>Memory bank interface class for basic memory communication with
 * iButtons (or 1-Wire devices).  The method <CODE> getMemoryBanks </CODE>
 * in all 1-Wire Containers ({@link OneWireContainer OneWireContainer})
 * returns an Enumeration of this interface to be used to read or write it's
 * memory. If the 1-Wire device does not have memory or the memory is non-standard,
 * then this enumeration may be empty. 
 * A MemoryBank returned from this method may also implement the
 * {@link PagedMemoryBank PagedMemoryBank}, 
 * or {@link OTPMemoryBank OTPMemoryBank} interfaces, 
 * to provide additional functionality. </P> 
 * 
 * <P>The MemoryBank methods can be organized into the following categories: </P>
 * <UL>
 *   <LI> <B> Information </B>
 *     <UL>
 *       <LI> {@link #getBankDescription() getBankDescription} 
 *       <LI> {@link #getSize() getSize} 
 *       <LI> {@link #getStartPhysicalAddress() getStartPhysicalAddress} 
 *       <LI> {@link #isGeneralPurposeMemory() isGeneralPurposeMemory} 
 *       <LI> {@link #isReadWrite() isReadWrite}
 *       <LI> {@link #isWriteOnce() isWriteOnce}
 *       <LI> {@link #isReadOnly() isReadOnly}
 *       <LI> {@link #isNonVolatile() isNonVolatile}
 *       <LI> {@link #needsProgramPulse() needsProgramPulse}
 *       <LI> {@link #needsPowerDelivery() needsPowerDelivery}
 *     </UL>
 *   <LI> <B> Options </B>
 *     <UL>
 *       <LI> {@link #setWriteVerification(boolean) setWriteVerification}
 *     </UL>
 *   <LI> <B> I/O </B>
 *     <UL>
 *       <LI> {@link #read(int,boolean,byte[],int,int) read}
 *       <LI> {@link #write(int,byte[], int, int) write}
 *     </UL>
 *  </UL>
 *
 * <H3> Usage </H3> 
 *  
 * <DL> 
 * <DD> <H4> Example 1</H4> 
 * Display some features of MemoryBank instance 'mb': 
 * <PRE> <CODE>
 *  if (mb.isWriteOnce())
 *     System.out.println("MemoryBank is write-once");
 * 
 *  if (mb.needsProgramPulse())
 *     System.out.println("MemoryBank requires program-pulse to write");
 * </CODE> </PRE>
 * 
 * <DD> <H4> Example 2</H4> 
 * Write the entire contents of a MemoryBank instance 'mb' with zeros: 
 * <PRE> <CODE>
 *  byte[] write_buf = new byte[mb.getSize()];
 *  for (int i = 0; i < write_buf.length; i++)
 *      write_buf[i] = (byte)0;
 * 
 *  mb.write(0, write_buf, 0, write_buf.length);
 * </CODE> </PRE>
 *
 * <DD> <H4> Example 3</H4>
 * Read the entire contents of a MemoryBank instance 'mb': 
 * <PRE> <CODE>
 *  byte[] read_buf = new byte[mb.getSize()];
 *
 *  mb.read(0, false, read_buf, 0, read_buf.length);
 * </CODE> </PRE>
 * </DL>
 *
 * @see PagedMemoryBank
 * @see OTPMemoryBank
 * @see OneWireContainer04
 * @see OneWireContainer06
 * @see OneWireContainer08
 * @see OneWireContainer09
 * @see OneWireContainer0A
 * @see OneWireContainer0B
 * @see OneWireContainer0C
 * @see OneWireContainer0F
 * @see OneWireContainer12
 * @see OneWireContainer13
 * @see OneWireContainer14
 * @see OneWireContainer18
 * @see OneWireContainer1A
 * @see OneWireContainer1D
 * @see OneWireContainer20
 * @see OneWireContainer21
 * @see OneWireContainer23
 * 
 * @version CLSID=8F4C79AC-8C69-4ED3-9AAD-1E4BFD84B4F1 -     0.00, 28 Aug 2000
 * @author     DS
 * @com.register ( clsid=8F4C79AC-8C69-4ED3-9AAD-1E4BFD84B4F1, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class MemoryBank
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.container.MemoryBank objectInstance  = null;

   /**
    * Default constructor. Does nothing.
    */
   public MemoryBank()
   {
   }

   MemoryBank(com.dalsemi.onewire.container.MemoryBank o)
   {
      this.objectInstance = o;
   }
   MemoryBank(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.container.MemoryBank)o);
   }

   /**
    * Gets a string description of this memory bank.
    *
    * @return  the memory bank description
    */
   public java.lang.String getBankDescription()
   {      
      return objectInstance.getBankDescription();
   }

   /**
    * Checks to see if this memory bank is general purpose
    * user memory.  If it is NOT then it may be Memory-Mapped and writing
    * values to this memory may affect the behavior of the 1-Wire
    * device.
    *
    * @return  <CODE> true </CODE> if this memory bank is general purpose
    */
   public boolean isGeneralPurposeMemory()
   {      
      return objectInstance.isGeneralPurposeMemory();
   }

   /**
    * Gets the size of this memory bank in bytes.
    *
    * @return  number of bytes in current memory bank
    */
   public int getSize()
   {      
      return objectInstance.getSize();
   }

   /**
    * Checks to see if this memory bank is read/write.
    *
    * @return  <CODE> true </CODE> if this memory bank is read/write
    */
   public boolean isReadWrite()
   {      
      return objectInstance.isReadWrite();
   }

   /**
    * Checks to see if this memory bank is write once such
    * as with EPROM technology.
    *
    * @return  <CODE>  true </CODE> if this memory bank can only be written once
    */
   public boolean isWriteOnce()
   {      
      return objectInstance.isWriteOnce();
   }

   /**
    * Checks to see if this memory bank is read only.
    *
    * @return  <CODE>  true </CODE> if this memory bank can only be read
    */
   public boolean isReadOnly()
   {      
      return objectInstance.isReadOnly();
   }

   /**
    * Checks to see if this memory bank is non-volatile.  Memory is
    * non-volatile if it retains its contents even when removed from
    * the 1-Wire network.
    *
    * @return  <CODE> true </CODE>  if this memory bank is non volatile
    */
   public boolean isNonVolatile()
   {      
      return objectInstance.isNonVolatile();
   }

   /**
    * Checks to see if this  memory bank requires a 
    * 'ProgramPulse' in order to write.
    *
    * @return  <CODE> true </CODE>  if writing to this memory bank 
    *                 requires a 'ProgramPulse' from the 1-Wire Adapter.
    *
    * @see DSPortAdapter
    */
   public boolean needsProgramPulse()
   {      
      return objectInstance.needsProgramPulse();
   }

   /**
    * Checks to see if this memory bank requires 'PowerDelivery'
    * in order to write.
    *
    * @return  <CODE> true </CODE> if writing to this memory bank 
    *                 requires 'PowerDelivery' from the 1-Wire Adapter
    *
    * @see DSPortAdapter
    */
   public boolean needsPowerDelivery()
   {      
      return objectInstance.needsPowerDelivery();
   }

   /**
    * Gets the starting physical address of this bank.  Physical
    * banks are sometimes sub-divided into logical banks due to changes
    * in attributes.  Note that this method is for information only.  The read
    * and write methods will automatically calculate the physical address
    * when writing to a logical memory bank.
    *
    * @return  physical starting address of this logical bank
    */
   public int getStartPhysicalAddress()
   {      
      return objectInstance.getStartPhysicalAddress();
   }

   /**
    * Sets or clears write verification for the 
    * {@link #write(int,byte[],int,int) write} method.
    *
    * @param  doReadVerf   <CODE> true </CODE>  (default) 
    *                      verify write in 'write',
    *                      <CODE> false </CODE> don't verify write (used on
    *                      Write-Once bit manipulation)
    *
    * @see OTPMemoryBank
    */
   public void setWriteVerification(boolean a0)
   {      
      objectInstance.setWriteVerification(a0);
   }

   /**
    * Reads memory in this bank with no CRC checking (device or
    * data). The resulting data from this API may or may not be what is on
    * the 1-Wire device.  It is recommended that the data contain some kind
    * of checking (CRC) like in the <CODE> readPagePacket </CODE> method in
    * the
    * {@link PagedMemoryBank PagedMemoryBank}
    * interface.  Some 1-Wire devices provide thier own CRC as in 
    * <CODE> readPageCRC </CODE> also found in the 
    * {@link PagedMemoryBank PagedMemoryBank} 
    * interface.  The <CODE> readPageCRC </CODE> method 
    * is not supported on all memory types, see <CODE> hasPageAutoCRC </CODE>
    * in the same interface.
    * If neither is an option then this method could be called more
    * then once to at least verify that the same data is read consistently.  The
    * readContinue parameter is used to eliminate the overhead in re-accessing
    * a part already being read from. For example, if pages 0 - 4 are to
    * be read, readContinue would be set to false for page 0 and would be set
    * to true for the next four calls.
    *
    * <P> Note: Using readContinue = true  can only be used if the new
    *           read continuous where the last one led off
    *           and it is inside a 'beginExclusive/endExclusive'
    *           block.
    *
    * @param  startAddr     starting address
    * @param  readContinue  <CODE> true </CODE> then device read is 
    *                       continued without re-selecting
    * @param  readBuf       location for data read
    * @param  offset        offset into readBuf to place data
    * @param  len           length in bytes to read
    *
    * @throws OneWireIOException on a 1-Wire communication error such as 
    *         no device present.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to 
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire 
    *         adapter
    */
   public void read(int a0, boolean a1, ByteArray a2, int a3, int a4)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.read(a0, a1, a2.array, a3, a4);
   }

   /**
    * Writes memory in this bank. It is recommended that a structure with some
    * built in error checking is used to provide data integrity on read.
    * The method <CODE> writePagePacket </CODE> found in the 
    * {@link PagedMemoryBank PagedMemoryBank} 
    * interface, which automatically wraps the data in a length and CRC, could
    * be used for this purpose.
    *
    * <P> When using on Write-Once devices care must be taken to write into
    * into empty space.  If <CODE> write </CODE> is used to write over an unlocked
    * page on a Write-Once device it will fail.  If write verification
    * is turned off with the method 
    * {@link #setWriteVerification(boolean) setWriteVerification(false)} 
    * then the result will be an 'AND' of the existing data and the new data. 
    *
    * @param  startAddr     starting address
    * @param  writeBuf      data to write
    * @param  offset        offset into writeBuf to get data
    * @param  len           length in bytes to write
    *
    * @throws OneWireIOException on a 1-Wire communication error such as 
    *         no device present or a read back verification fails.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to 
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire 
    *         adapter
    */
   public void write(int a0, ByteArray a1, int a2, int a3)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.write(a0, a1.array, a2, a3);
   }

   /**
    * Indicates whether or not this class implements the methods defined in the PagedMemoryBank.
    * @see owapi.PagedMemoryBank
    */
   public boolean isPagedMemoryBank()
   {
      return (this.objectInstance instanceof com.dalsemi.onewire.container.PagedMemoryBank);
   }

   /**
    * Indicates whether or not this class implements the methods defined in the OTPMemoryBank.
    * @see owapi.OTPMemoryBank
    */
   public boolean isOTPMemoryBank()
   {
      return (this.objectInstance instanceof com.dalsemi.onewire.container.OTPMemoryBank);
   }

   /**
    * If this class is an instance of MemoryBank, this method will return the most specific
    * MemoryBank class, such as OTPMemoryBank or PagedMemoryBank.
    */
   public MemoryBank getMostSpecificComponent()
   {
      MemoryBank mb = this;

         if(objectInstance instanceof com.dalsemi.onewire.container.OTPMemoryBank)
            mb = new OTPMemoryBank(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.PagedMemoryBank)
            mb = new PagedMemoryBank(objectInstance);

      return mb;
   }

   /**
    * This method will define this object to hold the same MemoryBank object as the one
    * passed in.  This is used in early binding, where you create the specific type first, then
    * initialize it with a type returned from another method in the API.
    */
   public void buildFromObject(MemoryBank buildMB)
   {
      this.objectInstance = buildMB.objectInstance;
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   MemoryBank setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.MemoryBank)o;
      return this;
   }
}
