// COM proxy class, output from FunctionList.js
package owapi;
/**
 * Memory bank class for the NVRAM with built-in CRC generation and Password
 * protected memory read/write iButtons and 1-Wire Devices.  An example of
 * such a devices is the DS1922 Thermochron with 8k or password protected
 * log memory.
 *
 *  @version    CLSID=C6096489-614A-4EBE-BE0F-CC24E6E4BFD6 - 1.00, 11 Feb 2002
 *  @author     SH
 * @com.register ( clsid=C6096489-614A-4EBE-BE0F-CC24E6E4BFD6, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class MemoryBankNVCRCPW
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.container.MemoryBankNVCRCPW objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public MemoryBankNVCRCPW()
   {
   }

   MemoryBankNVCRCPW(com.dalsemi.onewire.container.MemoryBankNVCRCPW o)
   {
      this.objectInstance = o;
   }
   MemoryBankNVCRCPW(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.container.MemoryBankNVCRCPW)o);
   }

   public static final byte READ_MEMORY_CRC_PW_COMMAND
          = com.dalsemi.onewire.container.MemoryBankNVCRCPW.READ_MEMORY_CRC_PW_COMMAND;

   /**
    * Memory bank contstuctor.  Requires reference to the OneWireContainer
    * this memory bank resides on.
    */
   public void createNewInstance(PasswordContainer ibutton, MemoryBankScratchCRCPW scratch)
   {  
      OneWireContainer owc = (OneWireContainer)ibutton;
      objectInstance = new com.dalsemi.onewire.container.MemoryBankNVCRCPW(
         ((com.dalsemi.onewire.container.PasswordContainer)(owc.objectInstance)), 
         ((com.dalsemi.onewire.container.MemoryBankScratchCRCPW)scratch.objectInstance));
   }

   /**
    * Read a complete memory page with CRC verification provided by the
    * device with extra information.  Not supported by all devices.
    * See the method 'hasPageAutoCRC()'.
    * See the method 'hasExtraInfo()' for a description of the optional
    * extra information.
    *
    * @param  page          page number to read
    * @param  readContinue  if 'true' then device read is continued without
    *                       re-selecting.  This can only be used if the new
    *                       readPagePacket() continious where the last one
    *                       stopped and it is inside a
    *                       'beginExclusive/endExclusive' block.
    * @param  readBuf       byte array to put data read. Must have at least
    *                       'getMaxPacketDataLength()' elements.
    * @param  offset        offset into readBuf to place data
    * @param  extraInfo     byte array to put extra info read into
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void readPageCRC(int page, boolean readContinue, ByteArray readBuf, int offset, ByteArray extraInfo)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.readPageCRC(page, readContinue, readBuf.array, offset, extraInfo.array);
   }

   /**
    * Read  memory in the current bank with no CRC checking (device or
    * data). The resulting data from this API may or may not be what is on
    * the 1-Wire device.  It is recommends that the data contain some kind
    * of checking (CRC) like in the readPagePacket() method or have
    * the 1-Wire device provide the CRC as in readPageCRC().  readPageCRC()
    * however is not supported on all memory types, see 'hasPageAutoCRC()'.
    * If neither is an option then this method could be called more
    * then once to at least verify that the same thing is read consistantly.
    *
    * @param  startAddr     starting physical address
    * @param  readContinue  if 'true' then device read is continued without
    *                       re-selecting.  This can only be used if the new
    *                       read() continious where the last one led off
    *                       and it is inside a 'beginExclusive/endExclusive'
    *                       block.
    * @param  readBuf       byte array to place read data into
    * @param  offset        offset into readBuf to place data
    * @param  len           length in bytes to read
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void read(int startAddr, boolean readContinue, ByteArray readBuf, int offset, int len)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.read(startAddr, readContinue, readBuf.array, offset, len);
   }

   /**
    * Write  memory in the current bank.  It is recommended that
    * when writing  data that some structure in the data is created
    * to provide error free reading back with read().  Or the
    * method 'writePagePacket()' could be used which automatically
    * wraps the data in a length and CRC.
    *
    * When using on Write-Once devices care must be taken to write into
    * into empty space.  If write() is used to write over an unlocked
    * page on a Write-Once device it will fail.  If write verification
    * is turned off with the method 'setWriteVerification(false)' then
    * the result will be an 'AND' of the existing data and the new data.
    *
    * @param  startAddr     starting address
    * @param  writeBuf      byte array containing data to write
    * @param  offset        offset into writeBuf to get data
    * @param  len           length in bytes to write
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void write(int startAddr, ByteArray writeBuf, int offset, int len)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.write(startAddr, writeBuf.array, offset, len);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   MemoryBankNVCRCPW setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.MemoryBankNVCRCPW)o;
      return this;
   }
}
