// COM proxy class, output from FunctionList.js
package owapi;
/**
 * Memory bank class for the Scratchpad section of NVRAM iButtons and
 * 1-Wire devices with password protected memory pages.
 *
 *  @version    CLSID=B387E7DA-6694-4DBD-AE71-E996A45B3234 - 1.00, 11 Aug 2002
 *  @author     SH
 * @com.register ( clsid=B387E7DA-6694-4DBD-AE71-E996A45B3234, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class MemoryBankScratchCRCPW
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.container.MemoryBankScratchCRCPW objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public MemoryBankScratchCRCPW()
   {
   }

   MemoryBankScratchCRCPW(com.dalsemi.onewire.container.MemoryBankScratchCRCPW o)
   {
      this.objectInstance = o;
   }
   MemoryBankScratchCRCPW(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.container.MemoryBankScratchCRCPW)o);
   }

   /**
    * Memory bank contstuctor.  Requires reference to the OneWireContainer
    * this memory bank resides on.
    */
   public void createNewInstance(PasswordContainer ibutton)
   {      
      OneWireContainer owc = (OneWireContainer)ibutton;
      objectInstance = new com.dalsemi.onewire.container.MemoryBankScratchCRCPW(
         ((com.dalsemi.onewire.container.PasswordContainer)(owc.objectInstance)));
   }

   /**
    * Read a complete memory page with CRC verification provided by the
    * device.  Not supported by all devices.  See the method
    * 'hasPageAutoCRC()'.
    *
    * @param  page          page number to read
    * @param  readContinue  if 'true' then device read is continued without
    *                       re-selecting.  This can only be used if the new
    *                       readPagePacket() continious where the last one
    *                       stopped and it is inside a
    *                       'beginExclusive/endExclusive' block.
    * @param  readBuf       byte array to put data read. Must have at least
    *                       'getMaxPacketDataLength()' elements.
    * @param  offset        offset into readBuf to place data
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void readPageCRC(int page, boolean readContinue, ByteArray readBuf, int offset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.readPageCRC(page, readContinue, readBuf.array, offset);
   }

   /**
    * Read a complete memory page with CRC verification provided by the
    * device with extra information.  Not supported by all devices.
    * See the method 'hasPageAutoCRC()'.
    * See the method 'hasExtraInfo()' for a description of the optional
    * extra information.
    *
    * @param  page          page number to read
    * @param  readContinue  if 'true' then device read is continued without
    *                       re-selecting.  This can only be used if the new
    *                       readPagePacket() continious where the last one
    *                       stopped and it is inside a
    *                       'beginExclusive/endExclusive' block.
    * @param  readBuf       byte array to put data read. Must have at least
    *                       'getMaxPacketDataLength()' elements.
    * @param  offset        offset into readBuf to place data
    * @param  extraInfo     byte array to put extra info read into
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void readPageCRC(int page, boolean readContinue, ByteArray readBuf, int offset, ByteArray extraInfo)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.readPageCRC(page, readContinue, readBuf.array, offset, extraInfo.array);
   }

   /**
    * Read the scratchpad page of memory from a NVRAM device
    * This method reads and returns the entire scratchpad after the byte
    * offset regardless of the actual ending offset
    *
    * @param  readBuf       byte array to place read data into
    *                       length of array is always pageLength.
    * @param  offset        offset into readBuf to pug data
    * @param  len           length in bytes to read
    * @param  extraInfo     byte array to put extra info read into
    *                       (TA1, TA2, e/s byte)
    *                       length of array is always extraInfoLength.
    *                       Can be 'null' if extra info is not needed.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void readScratchpad(ByteArray readBuf, int offset, int len, ByteArray extraInfo)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.readScratchpad(readBuf.array, offset, len, extraInfo.array);
   }

   /**
    * Copy the scratchpad page to memory.
    *
    * @param  startAddr     starting address
    * @param  len           length in bytes that was written already
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void copyScratchpad(int startAddr, int len)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.copyScratchpad(startAddr, len);
   }

   /**
    * Write to the scratchpad page of memory a NVRAM device.
    *
    * @param  startAddr     starting address
    * @param  writeBuf      byte array containing data to write
    * @param  offset        offset into readBuf to place data
    * @param  len           length in bytes to write
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void writeScratchpad(int startAddr, ByteArray writeBuf, int offset, int len)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.writeScratchpad(startAddr, writeBuf.array, offset, len);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   MemoryBankScratchCRCPW setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.MemoryBankScratchCRCPW)o;
      return this;
   }
}
