// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <p>Interface class for 1-Wire&#174 devices that perform analog measuring
 * operations. This class should be implemented for each A/D
 * type 1-Wire device.</p>
 *
 * <h3> Features </h3>
 *
 * <ul>
 *    <li>
 *        Allows multi-channel voltage readings
 *    </li>
 *    <li>
 *        Supports A/D Alarm enabling on devices with A/D Alarms
 *    </li>
 *    <li>
 *        Supports selectable A/D ranges on devices with selectable ranges
 *    </li>
 *    <li>
 *        Supports selectable A/D resolutions on devices with selectable resolutions
 *    </li>
 * </ul>
 *
 * <h3> Usage </h3>
 *
 * <p><code>ADContainer</code> extends <code>OneWireSensor</code>, so the general usage
 * model applies to any <code>ADContainer</code>:
 * <ol>
 *   <li> readDevice()  </li>
 *   <li> perform operations on the <code>ADContainer</code>  </li>
 *   <li> writeDevice(byte[]) </li>
 * </ol>
 *
 * <p>Consider this interaction with an <code>ADContainer</code> that reads from all of its
 * A/D channels, then tries to set its high alarm on its first channel (channel 0):
 *
 * <pre><code>
 *     //adcontainer is a ADContainer
 *     byte[] state = adcontainer.readDevice();
 *     double[] voltages = new double[adcontainer.getNumberADChannels()];
 *     for (int i=0; i &lt; adcontainer.getNumberADChannels(); i++)
 *     {
 *          adcontainer.doADConvert(i, state);
 *          voltages[i] = adc.getADVoltage(i, state);
 *     }
 *     if (adcontainer.hasADAlarms())
 *     {
 *          double highalarm = adcontainer.getADAlarm(0, ADContainer.ALARM_HIGH, state);
 *          adcontainer.setADAlarm(0, ADContainer.ALARM_HIGH, highalarm + 1.0, state);
 *          adcontainer.writeDevice(state);
 *     }
 *
 * </code></pre>
 *
 * @version    1.00, 20 February 2002
 * @author     SH
 */
public interface MissionContainer
   extends ClockContainer

{


   public static final int ALARM_HIGH
          = com.dalsemi.onewire.container.MissionContainer.ALARM_HIGH;

   public static final int ALARM_LOW
          = com.dalsemi.onewire.container.MissionContainer.ALARM_LOW;

   /**
    * No documentation available for method 
    */
   public void startNewMission(int a0, int a1, boolean a2, boolean a3, BooleanArray a4)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public void stopMission()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public boolean isMissionRunning()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public boolean isMissionRolloverEnabled()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public boolean hasMissionRolloverOccurred()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public void loadMissionResults()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public boolean isMissionLoaded();

   /**
    * No documentation available for method 
    */
   public void clearMissionResults()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public int getNumberMissionChannels()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public void setMissionChannelEnable(int a0, boolean a1)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public boolean getMissionChannelEnable(int a0)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public java.lang.String getMissionLabel(int a0)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public String getMissionTimeStamp(int a0)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public String getFirstSampleOffset(int a0)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public int getMissionSampleRate(int a0)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public int getMissionSampleCount(int a0)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * Returns the total number of samples taken for the specified channel
    * during the current mission.  This number can be more than the actual
    * sample count if rollover is enabled and the log has been filled.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @return number of samples taken for the specified channel
    */
   public int getMissionSampleCountTotal(int channel)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public double getMissionSample(int a0, int a1)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * Returns the sample as an integer value.  This value is not converted to
    * degrees Celsius for temperature or to percent RH for Humidity.  It is
    * simply the 8 or 16 bits of digital data written in the mission log for
    * this sample entry.  It is up to the user to mask off the unused bits
    * and convert this value to it's proper units.  This method is primarily
    * for users of the DS2422 who are using an input device which is not an
    * A-D or have an A-D wholly dissimilar to the one specified in the
    * datasheet.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @param sampleNum the sample number to return, between <code>0</code> and
    *        <code>(getMissionSampleCount(channel)-1)</code>
    * @return the sample as a whole integer
    */
   public int getMissionSampleAsInteger(int channel, int sampleNum)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public String getMissionSampleTimeStamp(int a0, int a1)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public DoubleArray getMissionResolutions(int a0)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public double getMissionResolution(int a0)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public void setMissionResolution(int a0, double a1)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public boolean hasMissionAlarms(int a0);

   /**
    * No documentation available for method 
    */
   public boolean hasMissionAlarmed(int a0, int a1)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public boolean getMissionAlarmEnable(int a0, int a1)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public void setMissionAlarmEnable(int a0, int a1, boolean a2)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public double getMissionAlarm(int a0, int a1)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;

   /**
    * No documentation available for method 
    */
   public void setMissionAlarm(int a0, int a1, double a2)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException;


}
