// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>NetAdapter is a network-based DSPortAdapter.  It allows for the use of
 * an actual DSPortAdapter which isn't on the local machine, but rather is
 * connected to another device which is reachable via a TCP/IP network
 * connection.</P>
 *
 * <P>The syntax for the <code>selectPort(String)</code> command is the
 * hostname of the computer which hosts the actual DSPortAdapter and the
 * TCP/IP port that the host is listening on.  If the port number is not
 * specified, a default value of 6161 is used. Here are a few examples to
 * illustrate the syntax:
 * <ul>
 *    <li>my.host.com:6060</li>
 *    <li>180.0.2.46:6262</li>
 *    <li>my.host.com</li>
 *    <li>180.0.2.46</li>
 * </ul></P>
 *
 * <P?The use of the NetAdapter is virtually identical to the use of any
 * other DSPortAdapter.  The only significant changes are the necessity
 * of the 'host' component (see NetAdapterHost)
 * and the discovery of hosts on your network.  There are currently two
 * techniques used for discovering all of the hosts: The look-up of each host
 * from the onewire.properties file and the use of multicast sockets for
 * automatic discovery.</P>
 *
 * <P>In the onewire.properties file, you can add a host to your list of valid
 * hosts by making a NetAdapter.host with an integer to distinguish the hosts.
 * There is no limit on the number of hosts which can appear in this list, but
 * the first one must be numbered '0'.  These hosts will then be returned in
 * the list of valid 'ports' from the <code>selectPortNames()</code> method.
 * Note that there do not have to be any servers returned from
 * <code>selectPortNames()</code> for the NetAdapter to be able to connect
 * to them (so it isn't necessary to add these entries for it to function),
 * but applications which allow a user to automatically select an appropriate
 * adapter and a port from a given list will not function properly without it.
 * For example:
 * <ul>
 *    <li>NetAdapter.host0=my.host.com:6060</li>
 *    <li>NetAdapter.host1=180.0.2.46:6262</li>
 *    <li>NetAdapter.host2=my.host.com</li>
 *    <li>NetAdapter.host3=180.0.2.46</li>
 * </ul></P>
 *
 * <P>The multicast socket technique allows you to automatically discover
 * hosts on your subnet which are listening for multicast packets.  By
 * default, the multicast discovery of NetAdapter hosts is disabled.
 * When enabled, the NetAdapter creates a multicast socket and looks for servers
 * every time you call <code>selectPortNames()</code>.  This will add a
 * 1 second delay (due to the socket timeout) on calling the method.  If you'd
 * like to enable this feature, add the following line to your
 * onewire.properties file:
 * <ul>
 *    <li>NetAdapter.MulticastEnabled=true</li>
 * </ul>
 * The port used and the multicast group used for multicast sockets can
 * also be changed.  The group however, must fall withing a valid range.
 * For more information about multicast sockets in Java, see the Java
 * tutorial on networking at <A HREF="http://java.sun.com/docs/books/tutorial/">
 * http://java.sun.com/docs/books/tutorial/</A>.  Change the defaults in the
 * onewire.properties file with the following entries:
 * <ul>
 *    <li>NetAdapter.MulticastGroup=228.5.6.7</li>
 *    <li>NetAdapter.MulticastPort=6163</li>
 * </ul>
 * </P>
 *
 * <P>Once the NetAdapter is connected with a host, a version check is performed
 * followed by a simple authentication step.  The authentication is dependent
 * upon a secret shared between the NetAdapter and the host.  Both will use
 * a default value, that each will agree with if you don't provide a secret
 * of your own.  To set the secret, add the following line to your
 * onewire.properties file:
 * <ul>
 *    <li>NetAdapter.secret="This is my custom secret"</li>
 * </ul>
 * Optionally, the secret can be specified on a per-host basis by simply
 * adding the secret after the port number followed by a colon.  If no port
 * number is specified, a double-colon is required.  Here are examples:
 * <ul>
 *    <li>my.host.com:6060:my custom secret</li>
 *    <li>180.0.2.46:6262:another custom secret</li>
 *    <li>my.host.com::the custom secret without port number</li>
 *    <li>180.0.2.46::another example of a custom secret</li>
 * </ul></P>
 *
 * <P>All of the above mentioned properties can be set on the command-line
 * as well as being set in the onewire.properties file.  To set the
 * properties on the command-line, use the -D option:
 * java -DNetAdapter.Secret="custom secret" myApplication</P>
 *
 * <P>The following is a list of all parameters that can be set for the
 * NetAdapter, followed by default values where applicable.<br>
 * <ul>
 *    <li>NetAdapter.secret=Adapter Secret Default</li>
 *    <li>NetAdapter.secret[0-MaxInt]=[no default]</li>
 *    <li>NetAdapter.host[0-MaxInt]=[no default]</li>
 *    <li>NetAdapter.MulticastEnabled=false</li>
 *    <li>NetAdapter.MulticastGroup=228.5.6.7</li>
 *    <li>NetAdapter.MulticastPort=6163</li>
 * </ul></P>
 *
 * <p>If you wanted added security on the communication channel, an SSL socket
 * (or similar custom socket implementation) can be used by circumventing the
 * standard DSPortAdapter's <code>selectPort(String)</code> and using the
 * NetAdapter-specific <code>selectPort(Socket)</code>.  For example:
 * <pre>
 *    NetAdapter na = new NetAdapter();
 *
 *    Socket secureSocket = // insert fancy secure socket implementation here
 *
 *    na.selectPort(secureSocket);
 * <pre></P>
 *
 * <P>For information on setting up the host component, see the JavaDocs
 * for the <code>NetAdapterHost</code>
 *
 * @see NetAdapterHost
 *
 * @author SH
 * @version CLSID=44E0AE2A-B1F3-4E6E-8524-A0DABA72B152 -     1.00, 9 Jan 2002
 * @com.register ( clsid=44E0AE2A-B1F3-4E6E-8524-A0DABA72B152, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class NetAdapter
   extends DSPortAdapter
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: DSPortAdapter
   //com.dalsemi.onewire.adapter.NetAdapter objectInstance  = null;

   /**
    * Default constructor. Does nothing.
    */
   public NetAdapter()
   {
      super(new com.dalsemi.onewire.adapter.NetAdapter());
   }

   NetAdapter(com.dalsemi.onewire.adapter.NetAdapter o)
   {
      super(o);
   }
   NetAdapter(java.lang.Object o)
   {
      super((com.dalsemi.onewire.adapter.NetAdapter)o);
   }

   /**
    * Sets the shared secret for authenticating this NetAdapter with
    * a NetAdapterHost.
    *
    * @param secret the new secret for authenticating this client.
    */
   public void setSecret(java.lang.String secret)
   {      
      ((com.dalsemi.onewire.adapter.NetAdapter)objectInstance).setSecret(secret);
   }

   /**
    * Resets the secret to be the default stored in the onewire.properties
    * file (if there is one), or the default as defined by NetAdapterConstants.
    */
   public void resetSecret()
   {      
      ((com.dalsemi.onewire.adapter.NetAdapter)objectInstance).resetSecret();
   }

   /**
    * Sends a ping to the host, just to keep the connection alive.  Although
    * it currently is not implemented on the standard NetAdapterHost, this
    * command is used as a signal to the NetAdapterSim to simulate some amount
    * of time that has run.
    */
   public void pingHost()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.adapter.NetAdapter)objectInstance).pingHost();
   }

   /**
    * New method, unique to NetAdapter.  Sets the "port", i.e. the connection
    * to the server via an already established socket connection.
    *
    * @param sock Socket connection to NetAdapterHost
    *
    * @return <code>true</code> if connection to host was successful
    *
    * @throws OneWireIOException If port does not exist, or unable to communicate with port.
    * @throws OneWireException If port does not exist
    */
   public boolean selectPortFromSocket(java.net.Socket sock)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.adapter.NetAdapter)objectInstance).selectPort(sock);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   DSPortAdapter setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.adapter.NetAdapter)o;
      return this;
   }
}
