// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>NetAdapterHost is the host (or server) component for a network-based
 * DSPortAdapter.  It actually wraps the hardware DSPortAdapter and handles
 * connections from outside sources (NetAdapter) who want to access it.</P>
 *
 * <P>NetAdapterHost is designed to be run in a thread, waiting for incoming
 * connections.  You can run this in the same thread as your main program or
 * you can establish the connections yourself (presumably using some higher
 * level of security) and then call the <code>handleConnection(Socket)</code>
 * {@see #handleConnection(Socket)}.</P>
 *
 * <P>Once a NetAdapter is connected with the host, a version check is performed
 * followed by a simple authentication step.  The authentication is dependent
 * upon a secret shared between the NetAdapter and the host.  Both will use
 * a default value, that each will agree with if you don't provide a secret
 * of your own.  To set the secret, add the following line to your
 * onewire.properties file:
 * <ul>
 *    <li>NetAdapter.secret="This is my custom secret"</li>
 * </ul>
 * Optionally, the secret can be set by calling the <code>setSecret(String)</code>
 * {@see #setSecret(String)}</P>
 *
 * <P>The NetAdapter and NetAdapterHost support multicast broadcasts for
 * automatic discovery of compatible servers on your LAN.  To start the
 * multicast listener for this NetAdapterHost, call the
 * <code>createMulticastListener()</code> method
 * {@see #createMulticastListener()}.</P>
 *
 * <P>For information on creating the client component, see the JavaDocs
 * for the  {@link 
 *
 * @see NetAdapter
 *
 * @author SH
 * @version CLSID=BB43F1B4-5B7A-4F84-AB25-90554A26AE0D -     1.00, 9 Jan 2002
 * @com.register ( clsid=BB43F1B4-5B7A-4F84-AB25-90554A26AE0D, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class NetAdapterHost
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.adapter.NetAdapterHost objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public NetAdapterHost()
   {
   }

   NetAdapterHost(com.dalsemi.onewire.adapter.NetAdapterHost o)
   {
      this.objectInstance = o;
   }
   NetAdapterHost(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.adapter.NetAdapterHost)o);
   }

   /**
    * <P>Creates an instance of a NetAdapterHost which wraps the provided
    * adapter.  The host listens on the default port as specified by
    * NetAdapterConstants.</P>
    *
    * <P>Note that the secret used for authentication is the value specified
    * in the onewire.properties file as "NetAdapter.secret=mySecret".
    * To set the secret to another value, use the
    * <code>setSecret(String)</code> method.</P>
    *
    * @param adapter DSPortAdapter that this NetAdapterHost will proxy
    * commands to.
    *
    * @throws IOException if a network error occurs or the listen socket
    * cannot be created on the specified port.
    */
   public void createNewInstance(DSPortAdapter adapter)
      throws java.io.IOException
   {      
      objectInstance = new com.dalsemi.onewire.adapter.NetAdapterHost(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance));
   }

   /**
    * <P>Creates a single-threaded instance of a NetAdapterHost which wraps the
    * provided adapter.  The host listens on the specified port.</P>
    *
    * <P>Note that the secret used for authentication is the value specified
    * in the onewire.properties file as "NetAdapter.secret=mySecret".
    * To set the secret to another value, use the
    * <code>setSecret(String)</code> method.</P>
    *
    * @param adapter DSPortAdapter that this NetAdapterHost will proxy
    * commands to.
    * @param listenPort the TCP/IP port to listen on for incoming connections
    *
    * @throws IOException if a network error occurs or the listen socket
    * cannot be created on the specified port.
    */
   public void createNewInstance(DSPortAdapter adapter, int listenPort)
      throws java.io.IOException
   {      
      objectInstance = new com.dalsemi.onewire.adapter.NetAdapterHost(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), listenPort);
   }

   /**
    * <P>Creates an (optionally multithreaded) instance of a NetAdapterHost
    * which wraps the provided adapter.  The listen port is set to the
    * default port as defined in NetAdapterConstants.</P>
    *
    * <P>Note that the secret used for authentication is the value specified
    * in the onewire.properties file as "NetAdapter.secret=mySecret".
    * To set the secret to another value, use the
    * <code>setSecret(String)</code> method.</P>
    *
    * @param adapter DSPortAdapter that this NetAdapterHost will proxy
    * commands to.
    * @param multiThread if true, multiple TCP/IP connections are allowed
    * to interact simulataneously with this adapter.
    *
    * @throws IOException if a network error occurs or the listen socket
    * cannot be created on the specified port.
    */
   public void createNewInstanceMultithreaded(DSPortAdapter adapter, boolean multiThread)
      throws java.io.IOException
   {      
      objectInstance = new com.dalsemi.onewire.adapter.NetAdapterHost(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), multiThread);
   }

   /**
    * <P>Creates an (optionally multi-threaded) instance of a NetAdapterHost which
    * wraps the provided adapter.  The host listens on the specified port.</P>
    *
    * <P>Note that the secret used for authentication is the value specified
    * in the onewire.properties file as "NetAdapter.secret=mySecret".
    * To set the secret to another value, use the
    * <code>setSecret(String)</code> method.</P>
    *
    * @param adapter DSPortAdapter that this NetAdapterHost will proxy
    * commands to.
    * @param listenPort the TCP/IP port to listen on for incoming connections
    * @param multiThread if true, multiple TCP/IP connections are allowed
    * to interact simulataneously with this adapter.
    *
    * @throws IOException if a network error occurs or the listen socket
    * cannot be created on the specified port.
    */
   public void createNewInstanceMultithreaded(DSPortAdapter adapter, int listenPort, boolean multiThread)
      throws java.io.IOException
   {      
      objectInstance = new com.dalsemi.onewire.adapter.NetAdapterHost(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), listenPort, multiThread);
   }

   /**
    * <P>Creates an instance of a NetAdapterHost which wraps the provided
    * adapter.  The host listens on the default port as specified by
    * NetAdapterConstants.</P>
    *
    * <P>Note that the secret used for authentication is the value specified
    * in the onewire.properties file as "NetAdapter.secret=mySecret".
    * To set the secret to another value, use the
    * <code>setSecret(String)</code> method.</P>
    *
    * @param adapter DSPortAdapter that this NetAdapterHost will proxy
    * commands to.
    * @param serverSock the ServerSocket for incoming connections
    *
    * @throws IOException if a network error occurs or the listen socket
    * cannot be created on the specified port.
    */
   public void createNewInstanceFromSocket(DSPortAdapter adapter, java.net.ServerSocket serverSock)
      throws java.io.IOException
   {      
      objectInstance = new com.dalsemi.onewire.adapter.NetAdapterHost(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), serverSock);
   }

   /**
    * <P>Creates an (optionally multi-threaded) instance of a NetAdapterHost which
    * wraps the provided adapter.  The host listens on the specified port.</P>
    *
    * <P>Note that the secret used for authentication is the value specified
    * in the onewire.properties file as "NetAdapter.secret=mySecret".
    * To set the secret to another value, use the
    * <code>setSecret(String)</code> method.</P>
    *
    * @param adapter DSPortAdapter that this NetAdapterHost will proxy
    * commands to.
    * @param serverSock the ServerSocket for incoming connections
    * @param multiThread if true, multiple TCP/IP connections are allowed
    * to interact simulataneously with this adapter.
    *
    * @throws IOException if a network error occurs or the listen socket
    * cannot be created on the specified port.
    */
   public void createNewInstanceFromSocketMultithreaded(DSPortAdapter adapter, java.net.ServerSocket serverSock, boolean multiThread)
      throws java.io.IOException
   {      
      objectInstance = new com.dalsemi.onewire.adapter.NetAdapterHost(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), serverSock, multiThread);
   }

   /**
    * Sets the secret used for authenticating incoming client connections.
    *
    * @param secret The shared secret information used for authenticating
    *               incoming client connections.
    */
   public void setSecret(java.lang.String secret)
   {      
      objectInstance.setSecret(secret);
   }

   /**
    * Creates a Multicast Listener to allow NetAdapter clients to discover
    * this NetAdapterHost automatically.  Uses defaults for Multicast group
    * and port.
    */
   public void createMulticastListener()
      throws java.io.IOException, java.net.UnknownHostException
   {      
      objectInstance.createMulticastListener();
   }

   /**
    * Creates a Multicast Listener to allow NetAdapter clients to discover
    * this NetAdapterHost automatically.  Uses default for Multicast group.
    *
    * @param port The port the Multicast socket will receive packets on
    */
   public void createMulticastListener(int port)
      throws java.io.IOException, java.net.UnknownHostException
   {      
      objectInstance.createMulticastListener(port);
   }

   /**
    * Creates a Multicast Listener to allow NetAdapter clients to discover
    * this NetAdapterHost automatically.
    *
    * @param port The port the Multicast socket will receive packets on
    * @param group The group the Multicast socket will join
    */
   public void createMulticastListener(int port, java.lang.String group)
      throws java.io.IOException, java.net.UnknownHostException
   {      
      objectInstance.createMulticastListener(port, group);
   }

   /**
    * Run method for threaded NetAdapterHost.  Maintains server socket which
    * waits for incoming connections.  Whenever a connection is received
    * launches it services the socket or (optionally) launches a new thread
    * for servicing the socket.
    */
   public void run()
   {      
      objectInstance.run();
   }

   /**
    * Handles a socket connection.  If single-threaded, the connection is
    * serviced in the current thread.  If multi-threaded, a new thread is
    * created for servicing this connection.
    */
   public void handleConnection(java.net.Socket sock)
      throws java.io.IOException
   {      
      objectInstance.handleConnection(sock);
   }

   /**
    * Stops all threads and kills the server socket.
    */
   public void stopHost()
   {      
      objectInstance.stopHost();
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   NetAdapterHost setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.adapter.NetAdapterHost)o;
      return this;
   }
}
