// COM proxy class, output from FunctionList.js
package owapi;
/**
 * 1-Wire&#174 Network path element.  Instances of this class are
 * used to represent a single branch of a complex 1-Wire network.
 *
 * <H3> Usage </H3> 
 * 
 * <DL> 
 * <DD> <H4> Example</H4> 
 * Enumerate through the 1-wire path elements in the 1-Wire path 'path' and print information:
 * <PRE> <CODE>
 *   OWPathElement path_element;
 *
 *   // enumerature through the path elements
 *   for (Enumeration path_enum = path.getAllOWPathElements(); 
 *           path_enum.hasMoreElements(); )
 *   {
 *
 *      // cast the enum as a OWPathElement
 *      path_element = (OWPathElement)path_enum.nextElement();
 *   
 *      // print info
 *      System.out.println("Address: " + path_element.getContainer().getAddressAsString());
 *      System.out.println("Channel number: " + path_element.getChannel()); 
 *   }
 * </CODE> </PRE>
 * </DL>
 *
 * @see OWPath
 * @see OneWireContainer
 *
 * @version CLSID=167FEC60-5A99-4035-B6B8-0BAAB5ED52DB -     0.00, 18 September 2000
 * @author     DS
 * @com.register ( clsid=167FEC60-5A99-4035-B6B8-0BAAB5ED52DB, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OWPathElement
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.utils.OWPathElement objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public OWPathElement()
   {
   }

   OWPathElement(com.dalsemi.onewire.utils.OWPathElement o)
   {
      this.objectInstance = o;
   }
   OWPathElement(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.utils.OWPathElement)o);
   }

   /**
    * Create a new 1-Wire path element.
    *
    * @param  owcInstance device that is the path element. Must implement
    *         SwitchContainer.
    * @param  channelNumber channel number of the 1-Wire path 
    */
   public void createNewInstance(OneWireContainer owcInstance, int channelNumber)
   {      
      objectInstance = new com.dalsemi.onewire.utils.OWPathElement(((com.dalsemi.onewire.container.OneWireContainer)owcInstance.objectInstance), channelNumber);
   }

   /**
    * Get the 1-Wire container for this 1-Wire path element.
    *
    * @return OneWireContainer of this 1-Wire path element
    *
    * @see OneWireContainer
    */
   public OneWireContainer getContainer()
   {      
      return new OneWireContainer(objectInstance.getContainer());
   }

   /**
    * Get the channel number of this 1-Wire path element.
    *
    * @return channel number of this element
    */
   public int getChannel()
   {      
      return objectInstance.getChannel();
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OWPathElement setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.utils.OWPathElement)o;
      return this;
   }
}
