// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>1-Wire&#174 container that encapsulates the functionality of the 1-Wire
 * family type <B>02</B> (hex), Dallas Semiconductor part number: <B>DS1991,
 * MultiKey</B>.</P>
 *
 * <P> This iButton is primarily used as a minimal security read/write portable memory device. </P>
 *
 * <H2> Features </H2>
 * <UL>
 *   <LI> Three 384 bit (48 bytes) password protected memory blocks
 *   <LI> 64 bit (8 byte) password per memory block
 *   <LI> 64 bit (8 byte) identification per memory block
 *   <LI> Data integrity assured with strict read/write
 *        protocols
 *   <LI> Operating temperature range from -40&#176C to
 *        +70&#176C
 *   <LI> Over 10 years of data retention
 * </UL>
 *
 * <H2> Memory </H2>
 *
 * <P> All memory is accessed through read/write routines, no <code>MemoryBank</code> classes are used.</P>
 *
 * <H2> Alternate Names </H2>
 * <UL>
 *   <LI> DS1425 (Family 82)
 * </UL>
 *
 * <H2> DataSheets </H2>
 *
 *   <A HREF="http://pdfserv.maxim-ic.com/arpdf/DS1991.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS1991.pdf</A><br>
 *   <A HREF="http://pdfserv.maxim-ic.com/arpdf/DS1425.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS1425.pdf</A>
 *
 *
 *  @version CLSID=D40728A2-EEE9-4F78-84BB-6AC30C0257CF -     0.00, 28 Aug 2000
 *  @author     DS,GH
 * @com.register ( clsid=D40728A2-EEE9-4F78-84BB-6AC30C0257CF, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer02
   extends OneWireContainer
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer02 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer02()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer02());
   }

   OneWireContainer02(com.dalsemi.onewire.container.OneWireContainer02 o)
   {
      super(o);
   }
   OneWireContainer02(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer02)o);
   }

   /**
    * Writes the data to the scratchpad from the given address.
    *
    * @param  addr     address to begin writing.  Must be between
    * 0x00 and 0x3F.
    * @param  data     data to write.
    *
    *
    * @throws IllegalArgumentException If address is out of range, or data is to long for scratchpad
    * @throws OneWireIOException If device is not found on the 1-Wire network
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void writeScratchpad(int addr, ByteArray data)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer02)objectInstance).writeScratchpad(addr, data.array);
   }

   /**
    * Reads the entire scratchpad.
    *
    * @return  <code>byte[]</code> containing the data from the scratchpad;
    * the array will have a length of 64.
    *
    * @throws OneWireIOException If device is not found on the 1-Wire network
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public ByteArray readScratchpad()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer02)objectInstance).readScratchpad());
   }

   /**
    * Writes the data from the scratchpad to the specified block or
    * blocks.  Note that the write will erase the data from the
    * scratchpad.
    *
    * @param  key          subkey being written
    * @param  passwd       password for the subkey being written
    * @param  blockNum     number of the block to be copied (see page 7 of the
    *                      DS1991 data sheet) block 0-7, or 8 to copy all 64 bytes.
    *
    *
    * @throws IllegalArgumentException If key is out of range (0 to 2), or password is not 8 characters, or if
    * blockNum is out of range (0 to 8)
    * @throws OneWireIOException If device is not found on the 1-Wire network
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void copyScratchpad(int key, ByteArray passwd, int blockNum)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer02)objectInstance).copyScratchpad(key, passwd.array, blockNum);
   }

   /**
    * Reads the subkey requested with the given key name and password.
    * Note that this method allows for reading from the subkey data
    * only which starts at address 0x10 within a key. It does not allow
    * reading from any earlier address within a key because the device
    * cannot be force to allow reading the password. This is why the
    * subkey number is or-ed with 0x10 in creating the address in bytes
    * 1 and 2 of the sendBlock.
    *
    * @param             key number indicating the key to be read: 0, 1, or 2
    * @param  passwd     password of destination subkey
    *
    * @return byte[] containing the data from the subkey;
    *        the array will have a length of 64, since it includes the key
    *        identifier, sent password, and 48 bytes of data.
    *
    *
    * @throws IllegalArgumentException If key is out of range (0 to 2), or password is not 8 characters, or if
    * data does not have a length of 64
    * @throws OneWireIOException If device is not found on the 1-Wire network
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public ByteArray readSubkey(int key, ByteArray passwd)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer02)objectInstance).readSubkey(key, passwd.array));
   }

   /**
    * Reads the subkey requested with the given key name and password.
    * Note that this method allows for reading from the subkey data
    * only which starts at address 0x10 within a key. It does not allow
    * reading from any earlier address within a key because the device
    * cannot be force to allow reading the password. This is why the
    * subkey number is or-ed with 0x10 in creating the address in bytes
    * 1 and 2 of the sendBlock.
    *
    * @param  data       buffer of length 64 into which to write the data
    * @param  key        number indicating the key to be read: 0, 1, or 2
    * @param  passwd     password of destination subkey
    *
    *
    * @throws IllegalArgumentException If key is out of range (0 to 2), or password is not 8 characters, or if
    * data does not have a length of 64
    * @throws OneWireIOException If device is not found on the 1-Wire network
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void readSubkey(ByteArray data, int key, ByteArray passwd)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer02)objectInstance).readSubkey(data.array, key, passwd.array);
   }

   /**
    * Writes a new identifier and password to the secure subkey iButton
    *
    * @param  key          number indicating the key to be read: 0, 1, or 2
    * @param  oldName      identifier of the key used to confirm the correct
    * key's password to be changed.  Must be exactly length 8.
    * @param  newName      identifier to be used for the key with the new
    * password.  Must be exactly length 8.
    * @param  newPasswd    new password for destination subkey.  Must be
    * exactly length 8.
    *
    *
    * @throws IllegalArgumentException If key value is out of range (0 to 2), or if newPasswd, newName, or oldName
    * are not 8 characters
    * @throws OneWireIOException If device is not found on the 1-Wire network
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void writePassword(int key, ByteArray oldName, ByteArray newName, ByteArray newPasswd)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer02)objectInstance).writePassword(key, oldName.array, newName.array, newPasswd.array);
   }

   /**
    * Writes new data to the secure subkey
    *
    * @param  key       number indicating the key to be written: 0, 1, or 2
    * @param  addr      address to start writing at ( 0x00 to 0x3F )
    * @param  passwd    passwird for the subkey
    * @param  data      data to be written
    *
    *
    * @throws IllegalArgumentException If key is out of range (0 to 2), or if address is out of range, or if passwd is
    * not 8 characters, or if data length is out of bounds
    * @throws OneWireIOException If device is not found on the 1-Wire network
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void writeSubkey(int key, int addr, ByteArray passwd, ByteArray data)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer02)objectInstance).writeSubkey(key, addr, passwd.array, data.array);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer02)o;
      return this;
   }
}
