// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire container for 128 byte Add-Only memory (EPROM) iButton, DS1982 and 1-Wire Chip, DS2502. 
 * This container encapsulates the functionality of the 1-Wire family 
 * type <B>09</B> (hex)</P>
 *
 * <P> The iButton package for this device is primarily used as a read/write portable memory device.  
 * The 1-Wire Chip version is used for small non-volatile storage. </P>
 * 
 * <H3> Features </H3> 
 * <UL>
 *   <LI> 1024 bits (128 bytes) Electrically Programmable Read-Only
 *        Memory (EPROM) communicates with
 *        the economy of one signal plus ground
 *   <LI> EPROM partitioned into four 256-bit (32-byte) pages
 *        for randomly accessing packetized data
 *   <LI> Each memory page can be permanently
 *        write-protected to prevent tampering
 *   <LI> Device is an "add only" memory where
 *        additional data can be programmed into
 *        EPROM without disturbing existing data
 *   <LI> Architecture allows software to patch data by
 *        superseding an old page in favor of a newly
 *        programmed page
 *   <LI> Overdrive mode boosts communication to
 *        142 kbits per second
 *   <LI> Reads over a wide voltage range of 2.8V to
 *        6.0V from -40&#176C to +85&#176C; programs at
 *        11.5V to 12.0V from -40&#176C to +50&#176C
 * </UL>
 * 
 * <H3> Alternate Names </H3>
 * <UL>
 *   <LI> D2502
 * </UL>
 *
 * <H3> Memory </H3> 
 *  
 * <P> The memory can be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 * 
 * The following is a list of the MemoryBank instances that are returned: 
 *
 * <UL>
 *   <LI> <B> Main Memory </B>
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                  {@link PagedMemoryBank PagedMemoryBank}, 
 *                  {@link OTPMemoryBank OTPMemoryBank} 
 *         <LI> <I> Size </I> 128 starting at physical address 0
 *         <LI> <I> Features</I> Write-once general-purpose non-volatile needs-program-pulse
 *         <LI> <I> Pages</I> 4 pages of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC pages-redirectable pages-lockable
 *      </UL> 
 *   <LI> <B> Write protect pages and Page redirection </B>
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                  {@link PagedMemoryBank PagedMemoryBank}, 
 *                  {@link OTPMemoryBank OTPMemoryBank} 
 *         <LI> <I> Size </I> 8 starting at physical address 0 (in STATUS memory area)
 *         <LI> <I> Features</I> Write-once not-general-purpose non-volatile needs-program-pulse
 *         <LI> <I> Pages</I> 1 pages of length 8 bytes
 *         <LI> <I> Page Features </I> page-device-CRC 
 *      </UL> 
 * </UL>
 * 
 * <H3> Usage </H3> 
 * 
 * <DL> 
 * <DD> See the usage example in 
 * {@link OneWireContainer OneWireContainer}
 * to enumerate the MemoryBanks.
 * <DD> See the usage examples in 
 * {@link MemoryBank MemoryBank}, 
 * {@link PagedMemoryBank PagedMemoryBank}, and
 * {@link OTPMemoryBank OTPMemoryBank}
 * for bank specific operations.
 * </DL>
 *
 * <H3> DataSheets </H3> 
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2502.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2502.pdf</A>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS1982.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS1982.pdf</A>
 * </DL>
 * 
 * @see MemoryBank
 * @see PagedMemoryBank
 * @see OTPMemoryBank
 * @see OneWireContainer0B
 * @see OneWireContainer0F
 * 
 * @version CLSID=229F18A4-E66C-46E4-B981-C0D230292F13 -     0.00, 28 Aug 2000
 * @author     DS
 * @com.register ( clsid=229F18A4-E66C-46E4-B981-C0D230292F13, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer09
   extends OneWireContainer
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer09 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer09()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer09());
   }

   OneWireContainer09(com.dalsemi.onewire.container.OneWireContainer09 o)
   {
      super(o);
   }
   OneWireContainer09(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer09)o);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer09)o;
      return this;
   }
}
