// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire container for 8192 byte memory iButton, DS1996.  This container
 * encapsulates the functionality of the iButton family 
 * type <B>0C</B> (hex)</P>
 *
 * <P> This iButton is primarily used as a read/write portable memory device. </P>
 * 
 * <H3> Features </H3> 
 * <UL>
 *   <LI> 65536 bits (8192 bytes) of read/write nonvolatile memory
 *   <LI> 256-bit (32-byte) scratchpad ensures integrity of data
 *        transfer
 *   <LI> Memory partitioned into 256-bit (32-byte) pages for
 *        packetizing data
 *   <LI> Overdrive mode boosts communication to
 *        142 kbits per second
 *   <LI> Data integrity assured with strict read/write
 *        protocols
 *   <LI> Operating temperature range from -40&#176C to
 *        +70&#176C
 *   <LI> Over 10 years of data retention
 * </UL>
 * 
 * <H3> Memory </H3> 
 *  
 * <P> The memory can be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 * 
 * The following is a list of the MemoryBank instances that are returned: 
 *
 * <UL>
 *   <LI> <B> Scratchpad </B> 
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                   {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write not-general-purpose volatile
 *         <LI> <I> Pages</I> 1 pages of length 32 bytes 
 *         <LI> <I> Extra information for each page</I>  Target address, offset, length 3
 *      </UL> 
 *   <LI> <B> Main Memory </B>
 *      <UL> 
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank}, 
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 8192 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 256 pages of length 32 bytes giving 29 bytes Packet data payload
 *      </UL> 
 * </UL>
 * 
 * <H3> Usage </H3> 
 * 
 * <DL> 
 * <DD> See the usage example in 
 * {@link OneWireContainer OneWireContainer}
 * to enumerate the MemoryBanks.
 * <DD> See the usage examples in 
 * {@link MemoryBank MemoryBank} and
 * {@link PagedMemoryBank PagedMemoryBank}
 * for bank specific operations.
 * </DL>
 *
 * <H3> DataSheet </H3> 
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS1996.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS1996.pdf</A>
 * </DL>
 * 
 * @see MemoryBank
 * @see PagedMemoryBank
 *
 * @version CLSID=43CA34D0-862E-4E7D-B302-46EE6C53B655 -     0.01, 11 Dec 2000
 * @author     DS
 * @com.register ( clsid=43CA34D0-862E-4E7D-B302-46EE6C53B655, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer0C
   extends OneWireContainer
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer0C objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer0C()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer0C());
   }

   OneWireContainer0C(com.dalsemi.onewire.container.OneWireContainer0C o)
   {
      super(o);
   }
   OneWireContainer0C(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer0C)o);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer0C)o;
      return this;
   }
}
