// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire container for Java-powered iButton, DS195X.  This container
 * encapsulates the functionality of the iButton family  type
 * <B>16</B> and <B>96</B> (hex)</P>
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> Java Card&#8482 2.0-compliant
 *   <LI> True 32-bit Java integers for straightforward computation
 *   <LI> Automatic garbage collection for efficient reuse of memory space
 *   <LI> Resizable scratchpad optimizes memory usage and allows large atomic transactions
 *   <LI> Dynamic applet capability for post-issuance updates
 *   <LI> up to 64-kbyte ROM for Java VM and operating system
 *   <LI> 6-kbyte NV SRAMwrites in 100 nanosecondssupports multiple applications
 *   <LI> Java-accessible True Time Clock time-stamps transactions
 *   <LI> Java-accessible random number generator for cryptographic keys
 *   <LI> JavaCardX.Crypto, SHA-1, RSA DES, triple DES cryptographic classes for secret key digital signatures
 *   <LI> PKI support: PKCS # 11(Netscape&#174), CSP (Microsoft&#174), X509 certificates
 *   <LI> Support for Win2000 log-on
 *   <LI> Physically secure iButtonTM case zeroizes contents on tampering
 *   <LI> 3V to 5V operating range
 *   <LI> ESD protection >25,000V
 *   <LI> Over 10 years of data retention
 * </UL>
 *
 * <H3> Usage </H3>
 *
 * <DL>
 * <DD> See the usage examples in
 * {@link CommandAPDU CommandAPDU}
 * to create <code>CommandAPDU</code>.
 * <DD> See the usage examples in
 * {@link ResponseAPDU ResponseAPDU}
 * to create <code>ResponseAPDU</code>.
 * </DL>
 *
 * <H3> DataSheet </H3>
 * <DL>
 * <DD><A HREF="http://www.ibutton.com/ibuttons/java.html">
 *              http://www.ibutton.com/ibuttons/java.html</A>
 * </DL>
 *
 * @see CommandAPDU
 * @see ResponseAPDU
 *
 * @version CLSID=98BA285A-4EE5-4EDF-8B97-51E87AD5FA72 -    0.00, 28 Aug 2000
 * @author    YL
 * @com.register ( clsid=98BA285A-4EE5-4EDF-8B97-51E87AD5FA72, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer16
   extends OneWireContainer
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer16 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer16()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer16());
   }

   OneWireContainer16(com.dalsemi.onewire.container.OneWireContainer16 o)
   {
      super(o);
   }
   OneWireContainer16(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer16)o);
   }

   public static final int PASSWORD_LENGTH_SIZE
          = com.dalsemi.onewire.container.OneWireContainer16.PASSWORD_LENGTH_SIZE;

   public static final int PASSWORD_SIZE
          = com.dalsemi.onewire.container.OneWireContainer16.PASSWORD_SIZE;

   public static final int AID_LENGTH_SIZE
          = com.dalsemi.onewire.container.OneWireContainer16.AID_LENGTH_SIZE;

   public static final int AID_SIZE
          = com.dalsemi.onewire.container.OneWireContainer16.AID_SIZE;

   public static final int AID_LENGTH_OFFSET
          = com.dalsemi.onewire.container.OneWireContainer16.AID_LENGTH_OFFSET;

   public static final int AID_NAME_OFFSET
          = com.dalsemi.onewire.container.OneWireContainer16.AID_NAME_OFFSET;

   public static final int APPLET_FILE_HEADER_SIZE
          = com.dalsemi.onewire.container.OneWireContainer16.APPLET_FILE_HEADER_SIZE;

   /**
    * Provides an <code>JibComm</code> object to communicate
    * with this Java iButton.
    *
    * @param  sourceAdapter     adapter object required to communicate with
    *                           this Java iButton
    * @param  newAddress        address of this One-Wire device as a byte array
    *
    * @see Address
    */
   public void setupJibComm(DSPortAdapter sourceAdapter, ByteArray newAddress)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setupJibComm(((com.dalsemi.onewire.adapter.DSPortAdapter)sourceAdapter.objectInstance), newAddress.array);
   }

   /**
   * Gets the current <code>CommandAPDU</code> sent to this Java iButton
   *
   * @return current <code>CommandAPDU</code> sent to this Java iButton
   */
   public CommandAPDU getCommandAPDUInfo()
   {      
      return new CommandAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getCommandAPDUInfo());
   }

   /**
   * Gets the current <code>ResponseAPDU</code> received from this Java iButton
   *
   * @return current <code>ResponseAPDU</code> received from this Java iButton
   */
   public ResponseAPDU getResponseAPDUInfo()
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getResponseAPDUInfo());
   }

   /**
   * Gets the run time value set for this Java iButton
   *
   * @return run time value of this Java iButton
   *
   * @see    #setRunTime
   */
   public int getRunTime()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getRunTime();
   }

   /**
   * Gets the select run time value set for this Java iButton
   *
   * @return run time value of this Java iButton on select operations
   *
   * @see    #setSelectRunTime
   */
   public int getSelectRunTime()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getSelectRunTime();
   }

   /**
   * Gets the load run time value set for this Java iButton
   *
   * @return run time value of this Java iButton on load operations
   *
   * @see    #setLoadRunTime
   */
   public int getLoadRunTime()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getLoadRunTime();
   }

   /**
    * Sets the run time value for this Java iButton
    *
    * @param  runTime a <code>4</code> bit value (<code>0 -15</code>) that
    *                 represents the expected run time of the device
    *
    *  Actual run time is calculated as followed:
    *  <code><pre>
    *    runTime * 250 + 62.5 mS <BR>
    *  Therefore, 0 -> 0 * 250 + 62.5 =  62.5 mS
    *             1 -> 1 * 250 + 62.5 = 312.5 mS </pre></code>
    *  and so on.
    *
    * @throws IllegalArgumentException Invalid run time value
    *
    * @see #getRunTime
    */
   public void setRunTime(int newRunTime)
      throws java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setRunTime(newRunTime);
   }

   /**
    * Sets the select operation run time value for this Java iButton.
    * The select-applet operation may require special consideration
    * because APDU processing is done on a select.
    *
    * @param  runTime a <code>4</code> bit value (<code>0 -15</code>) that
    *                 represents the expected run time of the device on a 
    *                 select operation. This value should not be less than 
    *                 the normal <code>runTime</codE> value.
    *
    *  Actual run time is calculated as followed:
    *  <code><pre>
    *    runTime * 250 + 62.5 mS <BR>
    *  Therefore, 0 -> 0 * 250 + 62.5 =  62.5 mS
    *             1 -> 1 * 250 + 62.5 = 312.5 mS </pre></code>
    *  and so on.
    *
    * @throws IllegalArgumentException Invalid run time value
    *
    * @see #getSelectRunTime
    */
   public void setSelectRunTime(int newRunTime)
      throws java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setSelectRunTime(newRunTime);
   }

   /**
    * Sets the load operation run time value for this Java iButton.
    * The last packet of a load-applet operation may require special consideration
    * because additional processing is performed once the applet is loaded.
    * All non-final load packets run based on the normal <code>runTime</code>
    * value.
    *
    * @param  runTime a <code>4</code> bit value (<code>0 -15</code>) that
    *                 represents the expected run time of the device on a 
    *                 final load packet.  This value should not be less than
    *                 the normal <code>runTime</code> value.
    *
    *  Actual run time is calculated as followed:
    *  <code><pre>
    *    runTime * 250 + 62.5 mS <BR>
    *  Therefore, 0 -> 0 * 250 + 62.5 =  62.5 mS
    *             1 -> 1 * 250 + 62.5 = 312.5 mS </pre></code>
    *  and so on.
    *
    * @throws IllegalArgumentException Invalid run time value
    *
    * @see #getLoadRunTime
    */
   public void setLoadRunTime(int newRunTime)
      throws java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setLoadRunTime(newRunTime);
   }

   /**
    * Sets the run time value for reading bytes from the output buffer of this Java iButton.
    * Generally, output data is read giving the button the minimal amount of runtime
    * needed.  However, for larger amounts of data, this may fail, causing the operation
    * to be retried.  To avoid the retry, this value can be altered if something is known about
    * the size of the output data.
    *
    * @param  runTime a <code>4</code> bit value (<code>0-15</code>) that
    *                 represents the run time of the device for reading
    *                 data from the output buffer of this Java Powered iButton
    *
    * @throws IllegalArgumentException Invalid run time value
    *
    * @see #getLoadRunTime
    */
   public void setReadingRunTime(int newRunTime)
      throws java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setReadingRunTime(newRunTime);
   }

   /**
    * Sets the size of the packets sent on load.
    * The range can be from <code>64</code> to <code>112</code> bytes.
    *
    * @param  size new packet size
    *
    * @return <code>true</code> if packet size is set to the new value <BR>
    *         <code>false</code> if invalid packet size is requested
    *
    * @see #getLoadPacketSize
    * @see #loadApplet
    */
   public boolean setLoadPacketSize(int size)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setLoadPacketSize(size);
   }

   /**
    * Gets the size of the packets sent on load.
    *
    * @return  size of the packets sent on load
    *
    * @see #setLoadPacketSize
    * @see #loadApplet
    *
    */
   public int getLoadPacketSize()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getLoadPacketSize();
   }

   /**
    * Sets the PIN used to communicate with this Java iButton.
    * Once this method has been called, the PIN will be sent to every method
    * that requires a PIN.
    *
    * @param  passwd PIN to be set and sent to this Java iButton for each command
    *         that requires a PIN
    *
    * @see    #getCommandPINMode
    * @see    #setCommandPINMode
    * @see    #setCommonPIN
    */
   public void setPIN(java.lang.String passwd)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setPIN(passwd);
   }

   /**
    * Gets the amount of free RAM in this Java iButton.  No PIN required.
    *
    * @return <code>ResponseAPDU</code> with a data field containing the amount
    *         of free RAM in this Java iButton.  Value returned is in little endian
    *         format.
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    */
   public ResponseAPDU getFreeRAM()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getFreeRAM());
   }

   /**
    * Gets requested number of bytes of random data generated by this Java
    * iButton. No PIN required.
    *
    * @param  numBytes the number of bytes requested.  <code>numByes</code>
    *         should not exceed <code>119</code>.  If the number is greater
    *         than <code>119</code>, the API only returns <code>119</code>.
    *
    * @return <code>ResponseAPDU</code> with a data field containing random
    *         bytes generated
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    */
   public ResponseAPDU getRandomBytes(int numBytes)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getRandomBytes(numBytes));
   }

   /**
    * Gets the firmware version string. No PIN required.
    *
    * @return <code>ResponseAPDU</code> with a data field containing the firmware
    *         version string of this Java iButton
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    */
   public ResponseAPDU getFirmwareVersionString()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getFirmwareVersionString());
   }

   /**
    * Gets the last error value.
    * If the error reporting mode is set (<code>1</code>), then this method
    * will return the value of the last exception. No PIN required.
    *
    * @return <code>ResponseAPDU</code> containing the last exception value
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getErrorReportingMode
    * @see    #setErrorReportingMode
    */
   public ResponseAPDU getLastError()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getLastError());
   }

   /**
    * Gets the Error Reporting Mode.  This function is not supported in
    * the <code>.033</code> version of the firmware. No PIN required.
    *
    * @return <code>ResponseAPDU</code> containing the error reporting mode
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6A02. Command not supported by this Java iButton.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getLastError
    * @see    #setErrorReportingMode
    */
   public ResponseAPDU getErrorReportingMode()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getErrorReportingMode());
   }

   /**
    * Sets the Error Reporting mode.
    * If the error reporting mode is set (<code>1</code>), this Java iButton
    * stores the last exception value code.  This code can be retreived by
    * calling <code>getLastError()</code>.
    *
    *
    * @param mode <code>1</code> to turn on  Error Reporting Mode.
    *             <code>0</code> to turn off.
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getLastError
    * @see    #getErrorReportingMode
    */
   public ResponseAPDU setErrorReportingMode(int mode)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setErrorReportingMode(mode));
   }

   /**
    * Gets the AID of the applet by its installed number. No PIN required.
    *
    * @param index installed number of the applet on this Java iButton to get
    *              the AID of
    *
    * @return <code>ResponseAPDU</code> containing the AID of the applet
    *         requested
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x8453.  Applet not found.
    *             Valid applet index are in the range of <code>0-15</code>.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    */
   public ResponseAPDU getAIDByNumber(int index)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getAIDByNumber(index));
   }

   /**
    * Deletes the currently selected applet.
    * If PIN protection is enabled, a PIN must be supplied.
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #deleteAppletByAID
    * @see    #deleteAppletByNumber
    */
   public ResponseAPDU deleteSelectedApplet()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).deleteSelectedApplet());
   }

   /**
    * Deletes an applet by its installed number.
    *
    * @param  index installed number of the applet to delete
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>Failure SW 0x8453. Applet not found.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #deleteAppletByAID
    * @see    #deleteSelectedApplet
    */
   public ResponseAPDU deleteAppletByNumber(int index)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).deleteAppletByNumber(index));
   }

   /**
    * Deletes an applet by its AID.
    *
    * @param  aid AID of applet to be deleted
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>Failure SW 0x8453. Applet not found.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #deleteSelectedApplet
    * @see    #deleteAppletByNumber
    */
   public ResponseAPDU deleteAppletByAID(java.lang.String aid)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).deleteAppletByAID(aid));
   }

   /**
    * Loads an applet onto this Java iButton.
    * This method takes an input stream
    * and an AID.  The AID length must NOT exceed <code>AID_SIZE</code>.
    *
    * @param  in Stream to read the applet from
    * @param  aid AID of the applet to be loaded
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         Possible return values are
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6400. Insufficient Memory
    *         <li>Failure SW 0x6901. Invalid AID Length
    *         <li>Failure SW 0x6902. Invalid API Version
    *         <li>Failure SW 0x6903. Invalid Password
    *         <li>Failure SW 0x6904. Invalid Signature Length
    *         <li>Failure SW 0x6905. Hash Corruption
    *         <li>Failure SW 0x6906. Hash Failure
    *         <li>Failure SW 0x6982. Invalid Signature
    *         <li>Failure SW 0x6A84. Class Length Overrun
    *         <li>Failure SW 0x6A86. Invalid Loader Command
    *         <li>Failure SW 0x6A87. Invalid Packet
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IOException              Problem reading applet from the stream
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getLoadPINMode
    * @see    #setLoadPINMode
    */
   public ResponseAPDU loadApplet(java.io.InputStream appletInputStream, java.lang.String aid)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException, java.io.IOException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).loadApplet(appletInputStream, aid));
   }

   /**
    * Loads an applet onto this Java iButton.
    * This method takes an applet filename, directory
    * and AID.  The AID length must NOT exceed <code>AID_SIZE</code>.
    *
    * @param  fileName file name of the applet to be loaded into this Java iButton
    * @param  directoryName path to the applet to be loaded
    * @param  aid AID of the applet to be loaded
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         Possible return values are
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6400. Insufficient Memory
    *         <li>Failure SW 0x6901. Invalid AID Length
    *         <li>Failure SW 0x6902. Invalid API Version
    *         <li>Failure SW 0x6903. Invalid Password
    *         <li>Failure SW 0x6904. Invalid Signature Length
    *         <li>Failure SW 0x6905. Hash Corruption
    *         <li>Failure SW 0x6906. Hash Failure
    *         <li>Failure SW 0x6982. Invalid Signature
    *         <li>Failure SW 0x6A84. Class Length Overrun
    *         <li>Failure SW 0x6A86. Invalid Loader Command
    *         <li>Failure SW 0x6A87. Invalid Packet
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws FileNotFoundException    Applet file not found
    * @throws IOException              Problem reading applet file
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getLoadPINMode
    * @see    #setLoadPINMode
    */
   public ResponseAPDU loadApplet(java.lang.String fileName, java.lang.String directoryName, java.lang.String aid)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException, java.io.FileNotFoundException, java.io.IOException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).loadApplet(fileName, directoryName, aid));
   }

   /**
    * Clears all memory in this Java iButton.  The erase will occur at the
    * beginning of the next command.
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    */
   public ResponseAPDU masterErase()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).masterErase());
   }

   /**
    * Gets the number of times this Java iButton has been power-on-reset (POR)
    * since the last master erase.  Return value is in little endian
    * format. No PIN required.
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000. Data field contains the POR count.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #masterErase
    */
   public ResponseAPDU getPORCount()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getPORCount());
   }

   /**
    * Gets the Real Time Clock.  No PIN required.
    *
    * @return <code>ResponseAPDU</code> containing the value of the real
    *         time clock
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    */
   public ResponseAPDU getRealTimeClock()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getRealTimeClock());
   }

   /**
    * Gets the Answer To Reset (ATR) from this Java iButton. No PIN required.
    *
    * @return <code>ResponseAPDU</code> containing the ATR in the data field
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    */
   public ResponseAPDU getATR()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getATR());
   }

   /**
    * Gets the Ephemeral Gabage Collection Mode.
    * A value of <code>1</code> indicates ephemeral garbage collection
    * is turned on, <code>0</code> if turned off. No PIN required.
    *
    * @return <code>ResponseAPDU</code> containing the Ephemeral Garbage
    *         Collector Mode
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #setEphemeralGCMode
    */
   public ResponseAPDU getEphemeralGCMode()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getEphemeralGCMode());
   }

   /**
    * Gets the Applet Garbage Collection Mode.
    * A value of <code>1</code> indicates applet garbage collection
    * is turned on, <code>0</code> if turned off. No PIN required.
    *
    * @return <code>ResponseAPDU</code> containing the Applet Garbage
    *         Collector Mode
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #setAppletGCMode
    */
   public ResponseAPDU getAppletGCMode()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getAppletGCMode());
   }

   /**
    * Gets the Command PIN Mode.
    * A value of <code>1</code> indicates that a PIN is required for
    * all Administrative and AID commands, <code>0</code> indicates
    * free access. No PIN required.
    *
    * @return <code>ResponseAPDU</code> containing the Command PIN Mode
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #setCommandPINMode
    * @see    #setCommonPIN
    * @see    #setPIN
    */
   public ResponseAPDU getCommandPINMode()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getCommandPINMode());
   }

   /**
    * Gets the Load PIN Mode.
    * A value of <code>1</code> indicates that a PIN is required for Applet
    * loading. No PIN required.
    *
    * @return <code>ResponseAPDU</code> containing the Load PIN Mode
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #loadApplet
    * @see    #setLoadPINMode
    */
   public ResponseAPDU getLoadPINMode()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getLoadPINMode());
   }

   /**
    * Gets the Restore Mode.
    * When Restore Mode is enabled (<code>1</code>), all field updates and
    * <code>javacard.framework.System</code> transactions are considered atomic.
    * If a tear occurs in the middle of these updates, values just
    * prior to the update are restored. No PIN required.
    *
    * @return <code>ResponseAPDU</code> containing the Restore Mode
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #setRestoreMode
    */
   public ResponseAPDU getRestoreMode()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getRestoreMode());
   }

   /**
    * Gets the Exception Mode.
    * When Exception Mode is enabled (<code>1</code>), Java API exceptions
    * are thrown.  All uncaught exceptions return 0x6F00 in the SW.
    * When disabled, an error is returned from the VM. No PIN required.
    *
    * @return <code>ResponseAPDU</code> containing the Exception Mode value
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #setExceptionMode
    */
   public ResponseAPDU getExceptionMode()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getExceptionMode());
   }

   /**
    * Gets the size of the Commit Buffer.
    * Committing one field to the buffer requires <code>9</code> bytes.
    * Therefore the default size of <code>72</code> bytes allows <code>8</code>
    * field updates. The minimum size allowed is <code>72</code> bytes and the
    * maximum is restricted by the amount of free RAM. All values will be rounded
    * up to the next multiple of <code>9</code>. No PIN required.
    *
    * @return <code>ResponseAPDU</code> containing the Commit Buffer size in little
    *         endian format
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getFreeRAM
    * @see    #setCommitBufferSize
    */
   public ResponseAPDU getCommitBufferSize()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).getCommitBufferSize());
   }

   /**
    * Sets the Common PIN.
    * This method is used to change the value of the Common PIN on the Java
    * iButton. If this Java iButton currently has a PIN, the <code>setPIN()</code>
    * method should be called prior to this method with the 'oldPIN' value.
    *
    * @param newPIN the value of the PIN to be set in this Java iButton
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getCommandPINMode
    * @see    #setCommandPINMode
    * @see    #setPIN
    */
   public ResponseAPDU setCommonPIN(java.lang.String newPIN)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setCommonPIN(newPIN));
   }

   /**
    * Sets the Ephemeral Garbage Collection Mode.
    * A value of <code>1</code> turns the Ephemeral Garbage Collection on
    * and a value of <code>0</code> turns it off.
    *
    * @param mode <code>1</code> to turn on  Ephemeral Garbage Collection Mode.
    *             <code>0</code> to turn off.
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getEphemeralGCMode
    */
   public ResponseAPDU setEphemeralGCMode(int mode)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setEphemeralGCMode(mode));
   }

   /**
    * Sets the Applet Garbage Collection Mode.
    * A value of <code>1</code> turns the Applet Garbage Collection on
    * and a value of <code>0</code> turns it off.
    *
    * @param mode <code>1</code> to turn on  Applet Garbage Collection Mode.
    *             <code>0</code> to turn off.
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getAppletGCMode
    */
   public ResponseAPDU setAppletGCMode(int mode)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setAppletGCMode(mode));
   }

   /**
    * Sets the Command PIN Mode.
    * If command PIN mode is set to <code>1</code>, a PIN is required for all
    * Administrative commands.
    *
    * @param mode <code>1</code> to turn on  Command PIN Mode.
    *             <code>0</code> to turn off.
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getCommandPINMode
    * @see    #setCommonPIN
    * @see    #setPIN
    */
   public ResponseAPDU setCommandPINMode(int mode)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setCommandPINMode(mode));
   }

   /**
    * Sets the Load PIN Mode.
    * If the load PIN mode is set (<code>1</code>), then PINs are required
    * on applet loading.
    *
    * @param mode <code>1</code> to turn on  Load PIN Mode.
    *             <code>0</code> to turn off.
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getLoadPINMode
    * @see    #loadApplet
    */
   public ResponseAPDU setLoadPINMode(int mode)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setLoadPINMode(mode));
   }

   /**
    * Sets the Restore Mode.
    * When Restore Mode is enabled (<code>1</code>), all field updates and
    * <code>javacard.framework.System</code> transactions are considered atomic.
    * If a tear occurs in the middle of these updates, values just prior to the
    * update are restored.
    *
    * @param mode <code>1</code> to turn on  Restore Mode.
    *             <code>0</code> to turn off.
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getRestoreMode
    */
   public ResponseAPDU setRestoreMode(int mode)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setRestoreMode(mode));
   }

   /**
    * Sets the Exception Mode.
    * When Exception Mode is enabled (<code>1</code>), Java API exceptions
    * are thrown. All uncaught exceptions return 0x6F00 in the SW. When
    * disabled, an error is returned from the VM.
    *
    * @param mode <code>1</code> to turn on  Exception Mode.
    *             <code>0</code> to turn off.
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getExceptionMode
    */
   public ResponseAPDU setExceptionMode(int mode)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setExceptionMode(mode));
   }

   /**
    * Sets the Commit Buffer size.
    * Committing one field to the buffer requires <code>9</code> bytes.
    * Therefore the default size of <code>72</code> bytes allows <code>8</code>
    * field updates. The minimum size allowed is <code>72</code> bytes and the
    * maximum is restricted by the amount of free RAM. All values will be rounded
    * up to the next multiple of <code>9</code>.
    *
    * @param  size size of the desired commit buffer
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6681. Invalid PIN.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #getCommitBufferSize
    */
   public ResponseAPDU setCommitBufferSize(int size)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).setCommitBufferSize(size));
   }

   /**
    * Selects an applet by AID.
    * Lenght of AID should not exceed <code>AID_SIZE</code>. No PIN required.
    *
    * @param  aid the AID of the applet to be selected
    *
    * @return <code>ResponseAPDU</code> indicating success or failure
    *         <ul>
    *         <li>Success SW 0x9000.
    *         <li>Failure SW 0x6A82. Unable to Select Applet
    *         <li>Failure SW 0x8453. Applet not found.
    *         <li>For additional error codes, please see:
    *             <A HREF="http://www.ibutton.com/jibkit/documents/sw.html">
    *                      http://www.ibutton.com/jibkit/documents/sw.html</A>
    *         </ul>
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #deleteAppletByAID
    * @see    #deleteAppletByNumber
    * @see    #deleteSelectedApplet
    * @see    #getAIDByNumber
    * @see    #process
    */
   public ResponseAPDU select(java.lang.String aid)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).select(aid));
   }

   /**
    * Sends a generic process command to this JavaiButton.
    * This method can be used to send any <code>CommandAPDU</code>.
    * No PIN required.
    *
    * @param capdu <code>CommandAPDU</code> to be sent to this Java iButton
    *
    * @return <code>ResponseAPDU</code> the response from this Java iButton
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    *
    * @see    #select
    */
   public ResponseAPDU process(CommandAPDU capdu)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).process(((com.dalsemi.onewire.container.CommandAPDU)capdu.objectInstance)));
   }

   /**
    * Sends a <code>CommandAPDU</code> to this Java iButton.
    * No PIN required.
    *
    * @param  capdu the <code>CommandAPDU</code> to be sent to this Java iButton
    *
    * @param  runTime a <code>4</code> bit value (<code>0 -15</code>) that
    *                 represents the expected run time of the device
    *
    *  <code><pre>
    *    runTime * 250 + 62.5 mS <BR>
    *  Therefore, 0 -> 0 * 250 + 62.5 =  62.5 mS
    *             1 -> 1 * 250 + 62.5 = 312.5 mS </pre></code>
    *  and so on.
    *
    * @return <code>ResponseAPDU</code> the <code>ResponseAPDU</code> from
    *         this Java iButton
    *
    * @throws IllegalArgumentException Invalid run time value
    * @throws OneWireException         Part could not be found [ fatal ]
    * @throws OneWireIOException       Data wasn't transferred properly [ recoverable ]
    */
   public ResponseAPDU sendAPDU(CommandAPDU capdu, int runTime)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException, java.lang.IllegalArgumentException
   {      
      return new ResponseAPDU(((com.dalsemi.onewire.container.OneWireContainer16)objectInstance).sendAPDU(((com.dalsemi.onewire.container.CommandAPDU)capdu.objectInstance), runTime));
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer16)o;
      return this;
   }
}
