// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire&#174 container for 1-Wire(MicroLAN) Coupler, DS2409.
 * This container encapsulates the functionality of the 1-Wire family type <B>1F</B> (hex).
 * </P>
 *
 * <H3> Features </H3>
 * <UL>
 *   <li> Low impedance coupler to create large
 *        common-ground, multi-level MicroLAN
 *        networks
 *   <li> Keeps inactive branches pulled high to 5V
 *   <li> Simplifies network topology analysis by
 *        logically decoupling devices on active
 *        network segments
 *   <li> Conditional search for fast event signaling
 *   <li> Auxiliary 1-Wire TM line to connect a memory
 *        chip or to be used as digital input
 *   <li> Programmable, general purpose open drain
 *        control output
 *   <li> Operating temperature range from -40&#176C to
 *        +85&#176C
 *   <li> Compact, low cost 6-pin TSOC surface mount
 *        package
 * </UL>
 *
 * <P> Setting the latch on the DS2409 to 'on'
 * (see {@link #setLatchState(int,boolean,boolean,byte[]) seLatchState})
 * connects the channel [Main(0) or Auxillary(1)] to the 1-Wire data line.  Note
 * that this is the opposite of the
 * {@link OneWireContainer12 DS2406} and
 * {@link OneWireContainer05 DS2405}
 * which connect thier I/O lines to ground.
 * <H3> Usage </H3>
 *
 * <DL>
 * <DD> See the usage example in
 * {@link SwitchContainer SwitchContainer}
 * for basic switch operations.
 * </DL>
 *
 * <H3> DataSheet </H3>
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2409.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2409.pdf</A>
 * </DL>
 *
 * @see OneWireSensor
 * @see SwitchContainer
 * @see OneWireContainer05
 * @see OneWireContainer12
 *
 * @version CLSID=13ED91C5-5252-49CC-A87C-2B71EA98B2AB -     0.00, 13 Sept 2000
 * @author     DSS
 * @com.register ( clsid=13ED91C5-5252-49CC-A87C-2B71EA98B2AB, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer1F
   extends OneWireContainer
   implements com.ms.com.IUnknown, SwitchContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer1F objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer1F()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer1F());
   }

   OneWireContainer1F(com.dalsemi.onewire.container.OneWireContainer1F o)
   {
      super(o);
   }
   OneWireContainer1F(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer1F)o);
   }

   public static final int CHANNEL_MAIN
          = com.dalsemi.onewire.container.OneWireContainer1F.CHANNEL_MAIN;

   public static final int CHANNEL_AUX
          = com.dalsemi.onewire.container.OneWireContainer1F.CHANNEL_AUX;

   /**
    * Directs the container to avoid the calls to doSpeed() in methods that communicate
    * with the Thermocron. To ensure that all parts can talk to the 1-Wire bus
    * at their desired speed, each method contains a call
    * to <code>doSpeed()</code>.  However, this is an expensive operation.
    * If a user manages the bus speed in an
    * application,  call this method with <code>doSpeedCheck</code>
    * as <code>false</code>.  The default behavior is
    * to call <code>doSpeed()</code>.
    *
    * @param doSpeedCheck <code>true</code> for <code>doSpeed()</code> to be called before every
    * 1-Wire bus access, <code>false</code> to skip this expensive call
    *
    * @see OneWireContainer#doSpeed()
    */
   public synchronized void setSpeedCheck(boolean doSpeedCheck)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).setSpeedCheck(doSpeedCheck);
   }

   /**
    * Retrieves the 1-Wire device sensor state.  This state is
    * returned as a byte array.  Pass this byte array to the 'get'
    * and 'set' methods.  If the device state needs to be changed then call
    * the 'writeDevice' to finalize the changes.
    *
    * @return 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).readDevice());
   }

   /**
    * Writes the 1-Wire device sensor state that
    * have been changed by 'set' methods.  Only the state registers that
    * changed are updated.  This is done by referencing a field information
    * appended to the state data.
    *
    * @param  state 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).writeDevice(state.array);
   }

   /**
    * <P>Force a power-on reset for parasitically powered 1-Wire
    * devices connected to the main or auziliary output of the DS2409. </P>
    *
    * <P>IMPORTANT: the duration of the discharge time should be 100ms minimum.</P> <BR>
    *
    * @param time number of milliseconds the lines are
    *      to be discharged for (minimum 100)
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void dischargeLines(int time)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).dischargeLines(time);
   }

   /**
    * Checks to see if the channels of this switch are 'high side'
    * switches.  This indicates that when 'on' or <code>true</code>, the switch output is
    * connect to the 1-Wire data.  If this method returns  <code>false</code>
    * then when the switch is 'on' or <code>true</code>, the switch is connected
    * to ground.
    *
    * @return <code>true</code> if the switch is a 'high side' switch,
    *         <code>false</code> if the switch is a 'low side' switch
    *
    * @see #getLatchState(int,byte[])
    */
   public boolean isHighSideSwitch()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).isHighSideSwitch();
   }

   /**
    * Checks to see if the channels of this switch support
    * activity sensing.  If this method returns <code>true</code> then the
    * method <code>getSensedActivity(int,byte[])</code> can be used.
    *
    * @return <code>true</code> if channels support activity sensing
    *
    * @see #getSensedActivity(int,byte[])
    * @see #clearActivity()
    */
   public boolean hasActivitySensing()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).hasActivitySensing();
   }

   /**
    * Checks to see if the channels of this switch support
    * level sensing.  If this method returns <code>true</code> then the
    * method <code>getLevel(int,byte[])</code> can be used.
    *
    * @return <code>true</code> if channels support level sensing
    *
    * @see #getLevel(int,byte[])
    */
   public boolean hasLevelSensing()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).hasLevelSensing();
   }

   /**
    * Checks to see if the channels of this switch support
    * 'smart on'. Smart on is the ability to turn on a channel
    * such that only 1-Wire device on this channel are awake
    * and ready to do an operation.  This greatly reduces
    * the time to discover the device down a branch.
    * If this method returns <code>true</code> then the
    * method <code>setLatchState(int,boolean,boolean,byte[])</code>
    * can be used with the <code>doSmart</code> parameter <code>true</code>.
    *
    * @return <code>true</code> if channels support 'smart on'
    *
    * @see #setLatchState(int,boolean,boolean,byte[])
    */
   public boolean hasSmartOn()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).hasSmartOn();
   }

   /**
    * Checks to see if the channels of this switch require that only one
    * channel is on at any one time.  If this method returns <code>true</code> then the
    * method <code>setLatchState(int,boolean,boolean,byte[])</code>
    * will not only affect the state of the given
    * channel but may affect the state of the other channels as well
    * to insure that only one channel is on at a time.
    *
    * @return <code>true</code> if only one channel can be on at a time.
    *
    * @see #setLatchState(int,boolean,boolean,byte[])
    */
   public boolean onlySingleChannelOn()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).onlySingleChannelOn();
   }

   /**
    * Query to get the number of channels supported by this switch.
    * Channel specific methods will use a channel number specified
    * by an integer from [0 to (<code>getNumberChannels(byte[])</code> - 1)].  Note that
    * all devices of the same family will not necessarily have the
    * same number of channels.  The DS2406 comes in two packages--one that
    * has a single channel, and one that has two channels.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the number of channels for this device
    */
   public int getNumberChannels(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).getNumberChannels(state.array);
   }

   /**
    * Checks the sensed level on the indicated channel.
    * To avoid an exception, verify that this switch
    * has level sensing with the  <code>hasLevelSensing()</code>.
    * Level sensing means that the device can sense the logic
    * level on its PIO pin.
    *
    * @param channel channel to execute this operation, in the range [0 to (<code>getNumberChannels(byte[])</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if level sensed is 'high' and <code>false</code> if level sensed is 'low'
    *
    * @see OneWireSensor#readDevice()
    * @see #hasLevelSensing()
    */
   public boolean getLevel(int a0, ByteArray a1)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).getLevel(a0, a1.array);
   }

   /**
    * Checks the latch state of the indicated channel.
    *
    * @param channel channel to execute this operation, in the range [0 to (<code>getNumberChannels(byte[])</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if channel latch is 'on'
    * or conducting and <code>false</code> if channel latch is 'off' and not
    * conducting.  Note that the actual output when the latch is 'on'
    * is returned from the <code>isHighSideSwitch()</code> method.
    *
    * @see OneWireSensor#readDevice()
    * @see #isHighSideSwitch()
    * @see #setLatchState(int,boolean,boolean,byte[])
    */
   public boolean getLatchState(int a0, ByteArray a1)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).getLatchState(a0, a1.array);
   }

   /**
    * Checks if the indicated channel has experienced activity.
    * This occurs when the level on the PIO pins changes.  To clear
    * the activity that is reported, call <code>clearActivity()</code>.
    * To avoid an exception, verify that this device supports activity
    * sensing by calling the method <code>hasActivitySensing()</code>.
    *
    * @param channel channel to execute this operation, in the range [0 to (<code>getNumberChannels(byte[])</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if activity was detected and <code>false</code> if no activity was detected
    *
    * @throws OneWireException if this device does not have activity sensing
    *
    * @see #hasActivitySensing()
    * @see #clearActivity()
    */
   public boolean getSensedActivity(int channel, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).getSensedActivity(channel, state.array);
   }

   /**
    * Checks if the control I/O pin mode is automatic (see DS2409 data sheet).
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if control mode is automatic
    */
   public boolean isModeAuto(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).isModeAuto(state.array);
   }

   /**
    * Checks the channel association of the control pin.
    * This value only makes sense if
    * the control mode is automatic (see <CODE>isModeAuto</CODE>).
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>int</code> the channel number that is associated
    * with the control pin
    */
   public int getControlChannelAssociation(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).getControlChannelAssociation(state.array);
   }

   /**
    * Checks the control data value.
    * This value only makes sense if
    * the control mode is manual (see <CODE>isModeAuto</CODE>).
    * 0 = output transistor off, 1 = output transistor on
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>int</code> the control output transistor state
    */
   public int getControlData(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).getControlData(state.array);
   }

   /**
    * Gets flag that indicates if a device was present when doing the
    * last smart on.  Note that this flag is only valid if the DS2409
    * flag was cleared with an ALL_LINES_OFF command and the last writeDevice
    * performed a 'smart-on' on one of the channels.
    *
    * @return <code>true</code> if device detected on branch
    */
   public boolean getLastSmartOnDeviceDetect()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).getLastSmartOnDeviceDetect();
   }

   /**
    * Sets the latch state of the indicated channel.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param channel channel to execute this operation, in the range [0 to (<code>getNumberChannels(byte[])</code> - 1)]
    * @param latchState <code>true</code> to set the channel latch 'on'
    *     (conducting) and <code>false</code> to set the channel latch 'off' (not
    *     conducting).  Note that the actual output when the latch is 'on'
    *     is returned from the <code>isHighSideSwitch()</code> method.
    * @param doSmart If latchState is 'on'/<code>true</code> then doSmart indicates
    *                  if a 'smart on' is to be done.  To avoid an exception
    *                  check the capabilities of this device using the
    *                  <code>hasSmartOn()</code> method.
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see #hasSmartOn()
    * @see #getLatchState(int,byte[])
    * @see OneWireSensor#writeDevice(byte[])
    */
   public void setLatchState(int a0, boolean a1, boolean a2, ByteArray a3)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).setLatchState(a0, a1, a2, a3.array);
   }

   /**
    * Clears the activity latches the next time possible.  For
    * example, on a DS2406/07, this happens the next time the
    * status is read with <code>readDevice()</code>.
    *
    * @throws OneWireException if this device does not support activity sensing
    *
    * @see OneWireSensor#readDevice()
    * @see #getSensedActivity(int,byte[])
    */
   public void clearActivity()
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).clearActivity();
   }

   /**
    * Sets the control pin mode.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param makeAuto <CODE>true</CODE> to set to auto mode, false for manual mode
    * @param state current state of the device returned from <code>readDevice()</code>
    */
   public void setModeAuto(boolean makeAuto, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).setModeAuto(makeAuto, state.array);
   }

   /**
    * Sets the control pin channel association.  This only makes sense
    * if the contol pin is in automatic mode.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param channel channel to associate with control pin
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireException when trying to set channel association in manual mode
    */
   public void setControlChannelAssociation(int channel, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).setControlChannelAssociation(channel, state.array);
   }

   /**
    * Sets the control pin data to a value. Note this
    * method only works if the control pin is in manual mode.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param data <CODE>true</CODE> for on and <CODE>false</CODE> for off
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireException when trying to set control data in automatic mode
    */
   public void setControlData(boolean data, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer1F)objectInstance).setControlData(data, state.array);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer1F)o;
      return this;
   }
}
