// COM proxy class, output from FunctionList.js
package owapi;
/**
 *<P>1-Wire&#174 container that encapsulates the functionality of the 1-Wire
 *family type <b>20</b> (hex), Dallas Semiconductor part number: <B> DS2450,
 * 1-Wire Quad A/D Converter</B>.</P>
 *
 *
 * <H3>Features</H3>
 * <UL>
 *   <LI>Four high-impedance inputs
 *   <LI>Programmable input range (2.56V, 5.12V),
 *       resolution (1 to 16 bits) and alarm thresholds
 *   <LI>5V, single supply operation
 *   <LI>Very low power, 2.5 mW active, 25 &#181W idle
 *   <LI>Unused analog inputs can serve as open
 *       drain digital outputs for closed-loop control
 *   <LI>Operating temperature range from -40&#176C to
 *        +85&#176C
 * </UL>
 *
 * <H3>Usage</H3>
 *
 * <P>Example device setup</P>
 * <PRE><CODE>
 *      byte[] state = owd.readDevice();
 *      owd.setResolution(OneWireContainer20.CHANNELA, 16, state);
 *      owd.setResolution(OneWireContainer20.CHANNELB, 8, state);
 *      owd.setRange(OneWireContainer20.CHANNELA, 5.12, state);
 *      owd.setRange(OneWireContainer20.CHANNELB, 2.56, state);
 *      owd.writeDevice();
 * </CODE></PRE>
 *
 * <P>Example device read</P>
 * <PRE><CODE>
 *      owd.doADConvert(OneWireContainer20.CHANNELA, state);
 *      owd.doADConvert(OneWireContainer20.CHANNELB, state);
 *      double chAVolatge = owd.getADVoltage(OneWireContainer20.CHANNELA, state);
 *      double chBVoltage = owd.getADVoltage(OneWireContainer20.CHANNELB, state);
 * </CODE></PRE>
 *
 * <H3>Note</H3>
 *
 * <P>When converting analog voltages to digital, the user of the device must
 * gaurantee that the voltage seen by the channel of the quad A/D does not exceed
 * the selected input range of the device.  If this happens, the device will default
 * to reading 0 volts.  There is NO way to know if the device is reading a higher than
 * specified voltage or NO voltage.</P>
 *
 * <H3> DataSheet </H3>
 *
 *   <A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2450.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2450.pdf</A>
 *
 * @version CLSID=6FBC3D9E-4C4E-44CD-8080-687F707DAAC3 -     0.00, 28 Aug 2000
 * @author     JK,DSS
 * @com.register ( clsid=6FBC3D9E-4C4E-44CD-8080-687F707DAAC3, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer20
   extends OneWireContainer
   implements com.ms.com.IUnknown, ADContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer20 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer20()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer20());
   }

   OneWireContainer20(com.dalsemi.onewire.container.OneWireContainer20 o)
   {
      super(o);
   }
   OneWireContainer20(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer20)o);
   }

   public static final int BITMAP_OFFSET
          = com.dalsemi.onewire.container.OneWireContainer20.BITMAP_OFFSET;

   public static final int ALARM_OFFSET
          = com.dalsemi.onewire.container.OneWireContainer20.ALARM_OFFSET;

   public static final int EXPOWER_OFFSET
          = com.dalsemi.onewire.container.OneWireContainer20.EXPOWER_OFFSET;

   public static final int CHANNELA
          = com.dalsemi.onewire.container.OneWireContainer20.CHANNELA;

   public static final int CHANNELB
          = com.dalsemi.onewire.container.OneWireContainer20.CHANNELB;

   public static final int CHANNELC
          = com.dalsemi.onewire.container.OneWireContainer20.CHANNELC;

   public static final int CHANNELD
          = com.dalsemi.onewire.container.OneWireContainer20.CHANNELD;

   public static final int NO_PRESET
          = com.dalsemi.onewire.container.OneWireContainer20.NO_PRESET;

   public static final int PRESET_TO_ZEROS
          = com.dalsemi.onewire.container.OneWireContainer20.PRESET_TO_ZEROS;

   public static final int PRESET_TO_ONES
          = com.dalsemi.onewire.container.OneWireContainer20.PRESET_TO_ONES;

   public static final int NUM_CHANNELS
          = com.dalsemi.onewire.container.OneWireContainer20.NUM_CHANNELS;

   /**
    * Queries to get the number of channels supported by this A/D.
    * Channel specific methods will use a channel number specified
    * by an integer from <CODE>[0 to (getNumberChannels() - 1)]</CODE>.
    *
    * @return the number of channels
    */
   public int getNumberADChannels()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).getNumberADChannels();
   }

   /**
    * Queries to see if this A/D measuring device has high/low
    * alarms.
    *
    * @return <CODE>true</CODE> if it has high/low trips
    */
   public boolean hasADAlarms()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).hasADAlarms();
   }

   /**
    * Queries to get an array of available ranges for the specified
    * A/D channel.
    *
    * @param channel channel in the range
    *                 <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    *
    * @return available ranges starting
    *         from the largest range to the smallest range
    */
   public DoubleArray getADRanges(int channel)
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).getADRanges(channel));
   }

   /**
    * Queries to get an array of available resolutions based
    * on the specified range on the specified A/D channel.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param range specified range
    *
    * @return available resolutions
    */
   public DoubleArray getADResolutions(int channel, double range)
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).getADResolutions(channel, range));
   }

   /**
    * Queries to see if this A/D supports doing multiple voltage
    * conversions at the same time.
    *
    * @return <CODE>true</CODE> if can do multi-channel voltage reads
    */
   public boolean canADMultiChannelRead()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).canADMultiChannelRead();
   }

   /**
    * Retrieves the entire A/D control/status and alarm pages.
    * It reads this and verifies the data with the onboard CRC generator.
    * Use the byte array returned from this method with static
    * utility methods to extract the status, alarm and other register values.
    * Appended to the data is 2 bytes that represent a bitmap
    * of changed bytes.  These bytes are used in the <CODE>writeADRegisters()</CODE>
    * in conjuction with the 'set' methods to only write back the changed
    * register bytes.
    *
    * @return register page contents verified
    *  with onboard CRC
    *
    * @throws OneWireIOException Data was not read correctly
    * @throws OneWireException Could not find part
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).readDevice());
   }

   /**
    * Writes the bytes in the provided A/D register pages that
    * have been changed by the 'set' methods.  It knows which state has
    * changed by looking at the bitmap fields appended to the
    * register data.  Any alarm flags will be automatically
    * cleared.  Only VCC powered indicator byte in physical location 0x1C
    * can be written in the calibration memory bank.
    *
    * @param  state register pages
    *
    * @throws OneWireIOException Data was not written correctly
    * @throws OneWireException Could not find part
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).writeDevice(state.array);
   }

   /**
    * Reads the voltage values.  Must be used after a <CODE>doADConvert()</CODE>
    * method call.  Also must include the last valid state from the
    * <CODE>readDevice()</CODE> method and this A/D must support multi-channel
    * read <CODE>canMultiChannelRead()</CODE> if there are more then 1 channel.
    *
    * @param state current state of this device returned from
    *              <CODE>readDevice()</CODE>
    *
    * @return voltage values for all channels
    *
    * @throws OneWireIOException Data was not read correctly
    * @throws OneWireException Could not find part
    */
   public DoubleArray getADVoltage(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).getADVoltage(state.array));
   }

   /**
    * Reads a channels voltage value.  Must be used after a
    * <CODE>doADConvert()</CODE> method call.  Also must include
    * the last valid state from the <CODE>readDevice()</CODE> method.
    * Note, if more then one channel is to be read then it is more
    * efficient to use the <CODE>getADVoltage(byte[])</CODE> method that returns
    * all channel values.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state current state of this
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @return voltage value for the specified
    *                  channel
    *
    * @throws OneWireIOException Data was not read correctly
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public double getADVoltage(int channel, ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).getADVoltage(channel, state.array);
   }

   /**
    * Performs voltage conversion on specified channel.  The method
    * <CODE>getADVoltage()</CODE> can be used to read the result
    * of the conversion.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state current state of this
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws OneWireIOException Data was not written correctly
    * @throws OneWireException Could not find part
    */
   public void doADConvert(int channel, ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).doADConvert(channel, state.array);
   }

   /**
    * Performs voltage conversion on all specified channels.  The method
    * <CODE>getADVoltage()</CODE> can be used to read the result of the
    * conversion. This A/D must support multi-channel read
    * <CODE>canMultiChannelRead()</CODE> if there are more then 1 channel
    * is specified.
    *
    * @param doConvert which channels to perform conversion on.
    * @param state current state of this
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws OneWireIOException Data was not written correctly
    * @throws OneWireException Could not find part
    */
   public void doADConvertMulti(BooleanArray doConvert, ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).doADConvert(doConvert.array, state.array);
   }

   /**
    * Performs voltage conversion on specified channel.  The method
    * <CODE>getADVoltage()</CODE> can be used to read the result
    * of the conversion.
    *
    * @param channel 0,1,2,3 representing the channels A,B,C,D
    * @param preset preset value:
    *           <CODE>NO_PRESET (0), PRESET_TO_ZEROS (1), and PRESET_TO_ONES (2)</CODE>
    * @param state state of this
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws OneWireIOException Data could not be written correctly
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public void doADConvert(int channel, int preset, ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).doADConvert(channel, preset, state.array);
   }

   /**
    * Performs voltage conversion on all specified channels.
    * The method <CODE>getADVoltage()</CODE> can be used to read the result
    * of the conversion.
    *
    * @param doConvert which channels to perform conversion on
    * @param preset preset values
    *              <CODE>NO_PRESET (0), PRESET_TO_ZEROS (1), and PRESET_TO_ONES (2)</CODE>
    * @param state current state of this
    *              device returned from <CODE>readDevice()</CODE>
    *
    * @throws OneWireIOException Data could not be written correctly
    * @throws OneWireException Could not find part
    */
   public void doADConvertMulti(BooleanArray doConvert, IntArray preset, ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).doADConvert(doConvert.array, preset.array, state.array);
   }

   /**
    * Extracts the alarm voltage value of the specified channel from the
    * provided state buffer.  The state buffer is retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1) or ALARM_LOW (0)</CODE>
    * @param state current state of this
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @return alarm value in volts
    *
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public double getADAlarm(int channel, int alarmType, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).getADAlarm(channel, alarmType, state.array);
   }

   /**
    * Extracts the alarm enable value of the specified channel from
    * the provided state buffer.  The state buffer is retrieved from
    * the <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param state current state of the state
    *               returned from <CODE>readDevice()</CODE>
    *
    * @return <CODE>true</CODE> if specified alarm is enabled
    *
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public boolean getADAlarmEnable(int channel, int alarmType, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).getADAlarmEnable(channel, alarmType, state.array);
   }

   /**
    * Checks the alarm event value of the specified channel from the provided
    * state buffer.  The state buffer is retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param state current state of the state
    *               returned from <CODE>readDevice()</CODE>
    *
    * @return <CODE>true</CODE> if specified alarm occurred
    *
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public boolean hasADAlarmed(int channel, int alarmType, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).hasADAlarmed(channel, alarmType, state.array);
   }

   /**
    * Extracts the conversion resolution of the specified channel from the
    * provided state buffer expressed in volts.  The state is retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state current state of the state
    *               returned from <CODE>readDevice()</CODE>
    *
    * @return resolution of channel in volts
    *
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public double getADResolution(int channel, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).getADResolution(channel, state.array);
   }

   /**
    * Extracts the input voltage range of the specified channel from
    * the provided state buffer.  The state buffer is retrieved from
    * the <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state current state of the state
    *                  returned from <CODE>readDevice()</CODE>
    *
    * @return A/D input voltage range
    *
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public double getADRange(int channel, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).getADRange(channel, state.array);
   }

   /**
    * Detects if the output is enabled for the specified channel from
    * the provided register buffer.  The register buffer is retrieved
    * from the <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state current state of the device
    *                  returned from <CODE>readDevice()</CODE>
    *
    * @return <CODE>true</CODE> if output is enabled on specified channel
    *
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public boolean isOutputEnabled(int channel, ByteArray state)
      throws java.lang.IllegalArgumentException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).isOutputEnabled(channel, state.array);
   }

   /**
    * Detects if the output is enabled for the specified channel from
    * the provided register buffer.  The register buffer is retrieved
    * from the <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state current state of the device
    *                  returned from <CODE>readDevice()</CODE>
    *
    * @return <CODE>false</CODE> if output is conducting to ground and
    *         <CODE>true</CODE> if not conducting
    *
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public boolean getOutputState(int channel, ByteArray state)
      throws java.lang.IllegalArgumentException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).getOutputState(channel, state.array);
   }

   /**
    * Detects if this device has seen a Power-On-Reset (POR).  If this has
    * occured it may be necessary to set the state of the device to the
    * desired values.   The register buffer is retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param state current state of the device
    *                  returned from <CODE>readDevice()</CODE>
    *
    * @return <CODE>false</CODE> if output is conducting to ground and
    *         <CODE>true</CODE> if not conducting
    */
   public boolean getDevicePOR(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).getDevicePOR(state.array);
   }

   /**
    * Extracts the state of the external power indicator from the provided
    * register buffer.  Use 'setPower' to set or clear the external power
    * indicator flag. The register buffer is retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @return <CODE>true</CODE> if set to external power operation
    */
   public boolean isPowerExternal(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).isPowerExternal(state.array);
   }

   /**
    * Sets the alarm voltage value of the specified channel in the
    * provided state buffer.  The state buffer is retrieved from the
    * <CODE>readDevice()</CODE> method. The method <CODE>writeDevice()</CODE>
    * must be called to finalize these changes to the device.  Note that
    * multiple 'set' methods can be called before one call to
    * <CODE>writeDevice()</CODE>.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param alarm alarm value (will be reduced to 8 bit resolution)
    * @param state current state of this
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public void setADAlarm(int channel, int alarmType, double alarm, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).setADAlarm(channel, alarmType, alarm, state.array);
   }

   /**
    * Sets the alarm enable value of the specified channel in the
    * provided state buffer.  The state buffer is retrieved from the
    * <CODE>readDevice()</CODE> method. The method <CODE>writeDevice()</CODE>
    * must be called to finalize these changes to the device.  Note that
    * multiple 'set' methods can be called before one call to
    * <CODE>writeDevice()</CODE>.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param alarmEnable alarm enable value
    * @param state current state of this
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public void setADAlarmEnable(int channel, int alarmType, boolean alarmEnable, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).setADAlarmEnable(channel, alarmType, alarmEnable, state.array);
   }

   /**
    * Sets the conversion resolution value for the specified channel in
    * the provided state buffer.  The state buffer is retrieved from the
    * <CODE>readDevice()</CODE> method. The method <CODE>writeDevice()</CODE>
    * must be called to finalize these changes to the device.  Note that
    * multiple 'set' methods can be called before one call to
    * <CODE>writeDevice()</CODE>.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param resolution resolution to use in volts
    * @param state current state of this
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public void setADResolution(int channel, double resolution, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).setADResolution(channel, resolution, state.array);
   }

   /**
    * Sets the input range for the specified channel in the provided state
    * buffer.  The state buffer is retrieved from the <CODE>readDevice()</CODE>
    * method. The method <CODE>writeDevice()</CODE> must be called to finalize
    * these changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <CODE>writeDevice()</CODE>.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param range max volt range, use
    *                getRanges() method to get available ranges
    * @param state current state of this
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws IllegalArgumentException Invalid channel number passed
    */
   public void setADRange(int channel, double range, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).setADRange(channel, range, state.array);
   }

   /**
    * Sets the output enable and state for the specified channel in the
    * provided register buffer.  The register buffer is retrieved from
    * the <CODE>readDevice()</CODE> method. The method <CODE>writeDevice()</CODE>
    * must be called to finalize these changes to the device.  Note that
    * multiple 'set' methods can be called before one call to
    * <CODE>writeDevice()</CODE>.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param outputEnable <CODE>true</CODE> if output is enabled
    * @param outputState <CODE>false</CODE> if output is conducting to
    *           ground and <CODE>true</CODE> if not conducting.  This
    *           parameter is not used if <CODE>outputEnable</CODE> is
    *           <CODE>false</CODE>
    * @param state current state of the
    *                device returned from <CODE>readDevice()</CODE>
    */
   public void setOutput(int channel, boolean outputEnable, boolean outputState, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).setOutput(channel, outputEnable, outputState, state.array);
   }

   /**
    * Sets or clears the external power flag in the provided register buffer.
    * The register buffer is retrieved from the <CODE>readDevice()</CODE> method.
    * The method <CODE>writeDevice()</CODE> must be called to finalize these
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <CODE>writeDevice()</CODE>.
    *
    * @param external <CODE>true</CODE> if setting external power is used
    * @param state current state of this
    *               device returned from <CODE>readDevice()</CODE>
    */
   public void setPower(boolean external, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer20)objectInstance).setPower(external, state.array);
   }

   /**
    * Converts a raw voltage long value for the DS2450 into a valid voltage.
    * Requires the max voltage value.
    *
    * @param rawVoltage raw voltage
    * @param range max voltage
    *
    * @return calculated voltage based on the range
    */
   public double interpretVoltage(String rawVoltage, double range)
   {      
      return com.dalsemi.onewire.container.OneWireContainer20.interpretVoltage(Long.parseLong(rawVoltage), range);
   }

   /**
    * Converts a voltage double value to the DS2450 specific int value.
    * Requires the max voltage value.
    *
    * @param voltage voltage
    * @param range max voltage
    *
    * @return the DS2450 voltage
    */
   public int voltageToInt(double voltage, double range)
   {      
      return com.dalsemi.onewire.container.OneWireContainer20.voltageToInt(voltage, range);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer20)o;
      return this;
   }
}
