// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire container for Real-Time-Clock (RTC) iButton, DS1904 and 1-Wire Chip, DS2415.
 * This container encapsulates the functionality of the iButton family
 * type <B>24</B> (hex)</P>
 *
 * <P> This iButton is used as a portable real-time-clock. </P>
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> Real-Time Clock with fully compatible 1-Wire MicroLAN interface
 *   <LI> Uses the same binary time/date representation as the DS2404
 *        but with 1 second resolution
 *   <LI> Clock accuracy  2 minutes per month at 25&#176
 *   <LI> Operating temperature range from -40&#176C to
 *        +70&#176C (iButton), -40&#176C to +85&#176C (1-Wire chip)
 *   <LI> Over 10 years of data retention (iButton form factor)
 *   <LI> Low power, 200 nA typical with oscillator running
 * </UL>
 *
 * <H3> Alternate Names </H3>
 * <UL>
 *   <LI> DS2415
 * </UL>
 *
 * <H3> Clock </H3>
 *
 * <P>The clock methods can be organized into the following categories.  Note that methods
 *    that are implemented for the {@link ClockContainer ClockContainer}
 *    interface are marked with (*): </P>
 * <UL>
 *   <LI> <B> Information </B>
 *     <UL>
 *       <LI> {@link #hasClockAlarm() hasClockAlarm} *
 *       <LI> {@link #canDisableClock() canDisableClock} *
 *       <LI> {@link #getClockResolution() getClockResolution} *
 *     </UL>
 *   <LI> <B> Read </B>
 *     <UL>
 *       <LI> <I> Clock </I>
 *         <UL>
 *           <LI> {@link #getClock(byte[]) getClock} *
 *           <LI> {@link #getClockAlarm(byte[]) getClockAlarm} *
 *           <LI> {@link #isClockAlarming(byte[]) isClockAlarming} *
 *           <LI> {@link #isClockAlarmEnabled(byte[]) isClockAlarmEnabled} *
 *           <LI> {@link #isClockRunning(byte[]) isClockRunning} *
 *         </UL>
 *       <LI> <I> Misc </I>
 *         <UL>
 *           <LI> {@link #readDevice() readDevice} *
 *         </UL>
 *     </UL>
 *   <LI> <B> Write </B>
 *     <UL>
 *       <LI> <I> Clock </I>
 *         <UL>
 *           <LI> {@link #setClock(long, byte[]) setClock} *
 *           <LI> {@link #setClockAlarm(long, byte[]) setClockAlarm} *
 *           <LI> {@link #setClockRunEnable(boolean, byte[]) setClockRunEnable} *
 *           <LI> {@link #setClockAlarmEnable(boolean, byte[]) setClockAlarmEnable} *
 *         </UL>
 *       <LI> <I> Misc </I>
 *         <UL>
 *           <LI> {@link #writeDevice(byte[]) writeDevice} *
 *         </UL>
 *     </UL>
 *  </UL>
 *
 * <H3> Usage </H3>
 *
 * <DL>
 * <DD> See the usage examples in
 * {@link ClockContainer ClockContainer}
 * for basic clock operations.
 * </DL>
 *
 * <H3> DataSheets </H3>
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS1904.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS1904.pdf</A>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2415.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2415.pdf</A>
 * </DL>
 *
 * @see MemoryBank
 * @see PagedMemoryBank
 * @see ClockContainer
 *
 * @version CLSID=3867DE0B-3CB9-499E-8766-71A485529B11 -     1.00, 26 September 2001
 * @author     CO,BA
 * @com.register ( clsid=3867DE0B-3CB9-499E-8766-71A485529B11, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer24
   extends OneWireContainer
   implements com.ms.com.IUnknown, ClockContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer24 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer24()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer24());
   }

   OneWireContainer24(com.dalsemi.onewire.container.OneWireContainer24 o)
   {
      super(o);
   }
   OneWireContainer24(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer24)o);
   }

   /**
    * Query to see if the clock has an alarm feature.
    *
    * @return true if the Real-Time clock has an alarm
    *
    * @see #getClockAlarm(byte[])
    * @see #isClockAlarmEnabled(byte[])
    * @see #isClockAlarming(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public boolean hasClockAlarm()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).hasClockAlarm();
   }

   /**
    * Query to see if the clock can be disabled.
    *
    * @return true if the clock can be enabled and disabled
    *
    * @see #isClockRunning(byte[])
    * @see #setClockRunEnable(boolean,byte[])
    */
   public boolean canDisableClock()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).canDisableClock();
   }

   /**
    * Query to get the clock resolution in milliseconds
    *
    * @return the clock resolution in milliseconds
    */
   public String getClockResolution()
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).getClockResolution();
   }

   /**
    * Retrieves the five byte state over the 1-Wire bus.  This state array must be passed
    * to the Get/Set methods as well as the WriteDevice method.
    *
    * @return 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).readDevice());
   }

   /**
    * Writes the 1-Wire device sensor state that
    * have been changed by 'set' methods.  Only the state registers that
    * changed are updated.  This is done by referencing a field information
    * appended to the state data.
    *
    * @param  state 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).writeDevice(state.array);
   }

   /**
    * Extracts the Real-Time clock value in milliseconds.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the time represented in this clock in milliseconds since some reference time,
    *         as chosen by the user (ie. 12:00am, Jan 1st 1970)
    *
    * @see OneWireSensor#readDevice()
    * @see #setClock(long,byte[])
    */
   public String getClock(ByteArray a0)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).getClock(a0.array);
   }

   /**
    * Extracts the clock alarm value for the Real-Time clock.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return milliseconds since 1970 that the clock alarm is set to
    *
    * @throws OneWireException if this device does not have clock alarms
    *
    * @see OneWireSensor#readDevice()
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #isClockAlarming(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public String getClockAlarm(ByteArray a0)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).getClockAlarm(a0.array);
   }

   /**
    * Checks if the clock alarm flag has been set.
    * This will occur when the value of the Real-Time
    * clock equals the value of the clock alarm.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if the Real-Time clock is alarming
    *
    * @see OneWireSensor#readDevice()
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #getClockAlarm(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public boolean isClockAlarming(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).isClockAlarming(a0.array);
   }

   /**
    * Checks if the clock alarm is enabled.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if clock alarm is enabled
    *
    * @see OneWireSensor#readDevice()
    * @see #hasClockAlarm()
    * @see #isClockAlarming(byte[])
    * @see #getClockAlarm(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public boolean isClockAlarmEnabled(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).isClockAlarmEnabled(a0.array);
   }

   /**
    * Checks if the device's oscillator is enabled.  The clock
    * will not increment if the clock oscillator is not enabled.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if the clock is running
    *
    * @see OneWireSensor#readDevice()
    * @see #canDisableClock()
    * @see #setClockRunEnable(boolean,byte[])
    */
   public boolean isClockRunning(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).isClockRunning(a0.array);
   }

   /**
    * Sets the Real-Time clock.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param time new value for the Real-Time clock, in milliseconds
    * since some reference time (ie. 12:00am, January 1st, 1970)
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #getClock(byte[])
    */
   public void setClock(String a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).setClock(Long.parseLong(a0), a1.array);
   }

   /**
    * Sets the clock alarm.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.  Also note that
    * not all clock devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasClockAlarm()</code> method.
    *
    * @param time - new value for the Real-Time clock alarm, in milliseconds
    * since January 1, 1970
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireException if this device does not have clock alarms
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #getClockAlarm(byte[])
    * @see #isClockAlarming(byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public void setClockAlarm(String a0, ByteArray a1)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).setClockAlarm(Long.parseLong(a0), a1.array);
   }

   /**
    * Enables or disables the clock alarm.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.  Also note that
    * not all clock devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasClockAlarm()</code> method.
    *
    * @param alarmEnable true to enable the clock alarm
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireException if this device does not have clock alarms
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #getClockAlarm(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #isClockAlarming(byte[])
    */
   public void setClockAlarmEnable(boolean a0, ByteArray a1)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).setClockAlarmEnable(a0, a1.array);
   }

   /**
    * Enables or disables the oscillator, turning the clock 'on' and 'off'.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.  Also note that
    * not all clock devices can disable their oscillators.  Check to see if this device can
    * disable its oscillator first by calling the <code>canDisableClock()</code> method.
    *
    * @param runEnable true to enable the clock oscillator
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #canDisableClock()
    * @see #isClockRunning(byte[])
    */
   public void setClockRunEnable(boolean a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer24)objectInstance).setClockRunEnable(a0, a1.array);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer24)o;
      return this;
   }
}
