// COM proxy class, output from FunctionList.js
package owapi;
/**
 *  <P>1-Wire&#174 container that encapsulates the functionality of the 1-Wire
 *  family type <B>26</B> (hex), Dallas Semiconductor part number: <B>DS2438,
 *  Smart Battery Monitor</B>.</P>
 *
 * <H2>Features</H2>
 * <UL>
 *   <LI>direct-to-digital temperature sensor
 *   <LI>A/D converters which measures the battery voltage and current
 *   <LI>integrated current accumulator which keeps a running
 *       total of all current going into and out of the battery
 *   <LI>elapsed time meter
 *   <LI>40 bytes of nonvolatile EEPROM memory for storage of important parameters
 *   <LI>Operating temperature range from -40&#176C to
 *        +85&#176Ci
 * </UL>
 *
 * <H2>Note</H2>
 *  <P>
 *  Sometimes the VAD input will report 10.23 V even if nothing is attached.
 *  This value is also the maximum voltage that part can report.
 *  </P>
 *

 * <H3> DataSheet </H3>
 * <DL>
 * <DD>http://pdfserv.maxim-ic.com/arpdf/DS2438.pdf (not active yet, Sep-06-2001)
 * <DD><A HREF="http://www.ibutton.com/weather/humidity.html">http://www.ibutton.com/weather/humidity.html</A>
 * </DL>
 *
 *  @version CLSID=A19AC6CC-4D56-4269-9606-B875B91E355B -     0.00, 28 Aug 2000
 *  @author     COlmstea
 *
 * @com.register ( clsid=A19AC6CC-4D56-4269-9606-B875B91E355B, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer26
   extends OneWireContainer
   implements com.ms.com.IUnknown, ADContainer, TemperatureContainer, ClockContainer, HumidityContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer26 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer26()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer26());
   }

   OneWireContainer26(com.dalsemi.onewire.container.OneWireContainer26 o)
   {
      super(o);
   }
   OneWireContainer26(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer26)o);
   }

   public static final int CHANNEL_VDD
          = com.dalsemi.onewire.container.OneWireContainer26.CHANNEL_VDD;

   public static final int CHANNEL_VAD
          = com.dalsemi.onewire.container.OneWireContainer26.CHANNEL_VAD;

   public static final int CHANNEL_VSENSE
          = com.dalsemi.onewire.container.OneWireContainer26.CHANNEL_VSENSE;

   public static final byte IAD_FLAG
          = com.dalsemi.onewire.container.OneWireContainer26.IAD_FLAG;

   public static final byte CA_FLAG
          = com.dalsemi.onewire.container.OneWireContainer26.CA_FLAG;

   public static final byte EE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer26.EE_FLAG;

   public static final byte AD_FLAG
          = com.dalsemi.onewire.container.OneWireContainer26.AD_FLAG;

   public static final byte TB_FLAG
          = com.dalsemi.onewire.container.OneWireContainer26.TB_FLAG;

   public static final byte NVB_FLAG
          = com.dalsemi.onewire.container.OneWireContainer26.NVB_FLAG;

   public static final byte ADB_FLAG
          = com.dalsemi.onewire.container.OneWireContainer26.ADB_FLAG;

   /**
    * Set the value of the sense resistor used to determine
    * battery current.  This value is used in the <CODE>getCurrent()</CODE> calculation.
    * See the DS2438 datasheet for more information on sensing battery
    * current.
    *
    * @param resistance Value of the sense resistor in Ohms.
    */
   public synchronized void setSenseResistor(double resistance)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setSenseResistor(resistance);
   }

   /**
    * Get the value used for the sense resistor in the <CODE>getCurrent()</CODE>
    * calculations.
    *
    * @return currently stored value of the sense resistor in Ohms
    */
   public double getSenseResistor()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getSenseResistor();
   }

   /**
    * Directs the container to avoid the calls to doSpeed() in methods that communicate
    * with the Thermocron. To ensure that all parts can talk to the 1-Wire bus
    * at their desired speed, each method contains a call
    * to <code>doSpeed()</code>.  However, this is an expensive operation.
    * If a user manages the bus speed in an
    * application,  call this method with <code>doSpeedCheck</code>
    * as <code>false</code>.  The default behavior is
    * to call <code>doSpeed()</code>.
    *
    * @param doSpeedCheck <code>true</code> for <code>doSpeed()</code> to be called before every
    * 1-Wire bus access, <code>false</code> to skip this expensive call
    *
    * @see OneWireContainer#doSpeed()
    */
   public synchronized void setSpeedCheck(boolean doSpeedCheck)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setSpeedCheck(doSpeedCheck);
   }

   /**
    * Reads the specified 8 byte page and returns the data in an array.
    *
    * @param page the page number to read
    *
    * @return  eight byte array that make up the page
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public ByteArray readPage(int page)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).readPage(page));
   }

   /**
    * Writes a page of memory to this device. Pages 3-6 are always
    * available for user storage and page 7 is available if the CA bit is set
    * to 0 (false) with <CODE>setFlag()</CODE>.
    *
    * @param page    the page number
    * @param source  data to be written to page
    * @param offset  offset with page to begin writting
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public void writePage(int page, ByteArray source, int offset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).writePage(page, source.array, offset);
   }

   /**
    * Checks the specified flag in the status/configuration register
    * and returns its status as a boolean.
    *
    * @param  flagToGet flag bitmask.
    * Acceptable parameters: IAD_FLAG, CA_FLAG, EE_FLAG, AD_FLAG, TB_FLAG,
    * NVB_FLAG, ADB_FLAG
    * (may be ORed with | to check the status of more than one).
    *
    * @return state of flag
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public boolean getFlag(byte flagToGet)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getFlag(flagToGet);
   }

   /**
    * Set one of the flags in the STATUS/CONFIGURATION register.
    *
    * @param bitmask of the flag to set
    * Acceptable parameters: IAD_FLAG, CA_FLAG, EE_FLAG, AD_FLAG, TB_FLAG,
    * NVB_FLAG, ADB_FLAG.
    *
    * @param flagValue value to set flag to
    *
    * @throws OneWireIOException Error writting data
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public void setFlag(byte flagToSet, boolean flagValue)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setFlag(flagToSet, flagValue);
   }

   /**
    * Get the instantaneous current. The IAD flag must be true!!
    * Remember to set the Sense resistor value using
    * <CODE>setSenseResitor(double)</CODE>.
    *
    *
    * @param state current state of device
    * @return current value in Amperes
    */
   public double getCurrent(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getCurrent(state.array);
   }

   /**
    * Calculate the remaining capacity in mAH as outlined in the data sheet.
    *
    * @return battery capacity remaining in mAH
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public double getRemainingCapacity()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getRemainingCapacity();
   }

   /**
    * Determines if the battery is charging and returns a boolean.
    *
    *
    * @param state current state of device
    *
    * @return true if battery is changing, false if battery is idle or discharging
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public boolean isCharging(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).isCharging(state.array);
   }

   /**
    * Calibrate the current ADC. Although the part is shipped calibrated,
    * calibrations should be done whenever possible for best results.
    * NOTE: You MUST force zero current through Rsens (the sensor resistor)
    * while calibrating.
    *
    * @throws OneWireIOException Error calibrating
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public void calibrateCurrentADC()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).calibrateCurrentADC();
   }

   /**
    * Set the minimum current measurement magnitude for which the ICA/CCA/DCA
    * are incremented. This is important for applications where the current
    * may get very small for long periods of time. Small currents can be
    * inaccurate by a high percentage, which leads to very inaccurate
    * accumulations.
    *
    * @param threshold minimum number of bits a current measurement must have to be accumulated,
    * Only 0,2,4 and 8 are valid parameters
    *
    * @throws OneWireIOException Error setting the threshold
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public void setThreshold(byte thresholdValue)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setThreshold(thresholdValue);
   }

   /**
    * Retrieves the current ICA value in mVHr.
    *
    * @return value in the ICA register
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public int getICA()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getICA();
   }

   /**
    * Retrieves the current CCA value in mVHr. This value is accumulated over
    * the lifetime of the part (until it is set to 0 or the CA flag is set
    * to false) and includes only charging current (positive).
    *
    * @return CCA value
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public int getCCA()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getCCA();
   }

   /**
    * Retrieves the value of the DCA in mVHr. This value is accumulated over
    * the lifetime of the part (until explicitly set to 0 or if the CA flag
    * is set to false) and includes only discharging current (negative).
    *
    * @return DCA value
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public int getDCA()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getDCA();
   }

   /**
    * Set the value of the ICA.
    *
    * @param icaValue  new ICA value
    *
    * @throws OneWireIOException Error writing data
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public void setICA(int icaValue)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setICA(icaValue);
   }

   /**
    * Set the value of the CCA.
    *
    * @param ccaValue new CCA value
    *
    * @throws OneWireIOException Error writing data
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public void setCCA(int ccaValue)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setCCA(ccaValue);
   }

   /**
    * Set the value of the DCA.
    *
    * @param dcaValue new DCA value
    *
    * @throws OneWireIOException Error writing data
    * @throws OneWireException Could not find part
    * @throws IllegalArgumentException Bad parameters passed
    */
   public void setDCA(int dcaValue)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException, java.lang.IllegalArgumentException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setDCA(dcaValue);
   }

   /**
    * This method extracts the Clock Value in milliseconds from the
    * state data retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param state device state
    *
    * @return time in milliseconds that have
    * occured since 1970
    */
   public String getDisconnectTime(ByteArray state)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getDisconnectTime(state.array);
   }

   /**
    * This method extracts the Clock Value in milliseconds from the
    * state data retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param state device state
    *
    * @return time in milliseconds that have
    * occured since 1970
    */
   public String getEndOfChargeTime(ByteArray state)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getEndOfChargeTime(state.array);
   }

   /**
     * Query to get the number of channels supported by this A/D.
     * Channel specific methods will use a channel number specified
     * by an integer from [0 to (getNumberChannels() - 1)].
     *
     * @return number of channels
     */
   public int getNumberADChannels()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getNumberADChannels();
   }

   /**
    * Query to see if this A/D measuring device has high/low
    * alarms.
    *
    * @return true if has high/low trips
    */
   public boolean hasADAlarms()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).hasADAlarms();
   }

   /**
    * Query to get an array of available ranges for the specified
    * A/D channel.
    *
    * @param channel  channel in the range
    *                  [0 to (getNumberChannels() - 1)]
    *
    * @return available ranges
    */
   public DoubleArray getADRanges(int channel)
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getADRanges(channel));
   }

   /**
    * Query to get an array of available resolutions based
    * on the specified range on the specified A/D channel.
    *
    * @param channel channel in the range
    *                  [0 to (getNumberChannels() - 1)]
    * @param range A/D range
    *
    * @return available resolutions
    */
   public DoubleArray getADResolutions(int channel, double range)
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getADResolutions(channel, range));
   }

   /**
    * Query to see if this A/D supports doing multiple voltage
    * conversions at the same time.
    *
    * @return true if device can do multi-channel voltage reads
    */
   public boolean canADMultiChannelRead()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).canADMultiChannelRead();
   }

   /**
    * This method is used to perform voltage conversion on all specified
    * channels.  The method 'getVoltage()' can be used to read the result
    * of the conversion.
    *
    * @param channel channel in the range
    *                 <CODE> [0 to (getNumberChannels() - 1)]</CODE>
    * @param state  current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws OneWireIOException Error writing data
    * @throws OneWireException Could not find part
    */
   public void doADConvert(int channel, ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).doADConvert(channel, state.array);
   }

   /**
    * This method is used to perform voltage conversion on all specified
    * channels.  The method <CODE>getVoltage()</CODE> can be used to read the result
    * of the conversion. This A/D must support multi-channel read
    * <CODE>canMultiChannelRead()</CODE> if there are more then 1 channel is specified.
    *
    * @param doConvert  channels
    *                    to perform conversion on
    * @param state  current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws OneWireIOException Error writing data
    * @throws OneWireException Could not find part
    */
   public void doADConvertMulti(BooleanArray doConvert, ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).doADConvert(doConvert.array, state.array);
   }

   /**
    * This method is used to read the voltage values.  Must
    * be used after a <CODE>doADConvert()</CODE> method call.  Also must
    * include the last valid state from the <CODE>readDevice()</CODE> method
    * and this A/D must support multi-channel read <CODE>canMultiChannelRead()</CODE>
    * if there are more then 1 channel.
    *
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @return voltage values for all channels
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    */
   public DoubleArray getADVoltage(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getADVoltage(state.array));
   }

   /**
    * This method is used to read a channels voltage value.  Must
    * be used after a <CODE>doADConvert()</CODE> method call.  Also must
    * include the last valid state from the <CODE>readDevice()</CODE> method.
    * Note, if more then one channel is to be read then it is more
    * efficient to use the <CODE>getVoltage()</CODE> method that returns all
    * channel values.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @return   voltage value for the specified
    *                  channel
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    */
   public double getADVoltage(int channel, ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getADVoltage(channel, state.array);
   }

   /**
    * This method is used to extract the alarm voltage value of the
    * specified channel from the provided state buffer.  The
    * state buffer is retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @return alarm_value in volts
    *
    * @throws OneWireException Device does not support A/D alarms
    */
   public double getADAlarm(int channel, int alarmType, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getADAlarm(channel, alarmType, state.array);
   }

   /**
    * This method is used to extract the alarm enable value of the
    * specified channel from the provided state buffer.  The state
    * buffer is retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param state current state of the state
    *               returned from <CODE>readDevice()</CODE>
    *
    * @return true if specified alarm is enabled
    *
    * @throws OneWireException Device does not support A/D alarms
    */
   public boolean getADAlarmEnable(int channel, int alarmType, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getADAlarmEnable(channel, alarmType, state.array);
   }

   /**
    * This method is used to check the alarm event value of the
    * specified channel from the provided state buffer.  The
    * state buffer is retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param state current state of the state
                    returned from <CODE>readDevice()</CODE>
    *
    * @return true if specified alarm occurred
    *
    * @throws OneWireException Device does not support A/D alarms
    */
   public boolean hasADAlarmed(int channel, int alarmType, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).hasADAlarmed(channel, alarmType, state.array);
   }

   /**
    * This method is used to extract the conversion resolution of the
    * specified channel from the provided state buffer expressed in
    * volts.  The state is retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state current state of the state
    *               returned from <CODE>readDevice()</CODE>
    *
    * @return resolution of channel in volts
    */
   public double getADResolution(int channel, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getADResolution(channel, state.array);
   }

   /**
    * This method is used to extract the input voltage range of the
    * specified channel from the provided state buffer.  The state
    * buffer is retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state current state of the state
    *                  returned from <CODE>readDevice()</CODE>
    *
    * @return input voltage range
    */
   public double getADRange(int channel, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getADRange(channel, state.array);
   }

   /**
    * This method is used to set the alarm voltage value of the
    * specified channel in the provided state buffer.  The
    * state buffer is retrieved from the <CODE>readDevice()</CODE> method.
    * The method <CODE>writeDevice()</CODE> must be called to finalize these
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <CODE>writeDevice()</CODE>.
    *
    * @param channel  channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param alarm  alarm value (will be reduced to 8 bit resolution)
    * @param state  current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws OneWireException Device does not support A/D alarms
    */
   public void setADAlarm(int channel, int alarmType, double alarm, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setADAlarm(channel, alarmType, alarm, state.array);
   }

   /**
    * This method is used to set the alarm enable value of the
    * specified channel in the provided state buffer.  The
    * state buffer is retrieved from the <CODE>readDevice()</CODE> method.
    * The method <CODE>writeDevice()</CODE> must be called to finalize these
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <CODE>writeDevice()</CODE>.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param alarmEnable alarm enable value
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws OneWireException Device does not support A/D alarms
    */
   public void setADAlarmEnable(int channel, int alarmType, boolean alarmEnable, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setADAlarmEnable(channel, alarmType, alarmEnable, state.array);
   }

   /**
    * This method is used to set the conversion resolution value for the
    * specified channel in the provided state buffer.  The
    * state buffer is retrieved from the <CODE>readDevice()</CODE> method.
    * The method <CODE>writeDevice()</CODE> must be called to finalize these
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <CODE>writeDevice()</CODE>.
    *
    * @param channel  channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param resolution resolution to use in volts
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    */
   public void setADResolution(int channel, double resolution, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setADResolution(channel, resolution, state.array);
   }

   /**
    * This method is used to set the input range for the
    * specified channel in the provided state buffer.  The
    * state buffer is retrieved from the <CODE>readDevice()</CODE> method.
    * The method <CODE>writeDevice()</CODE> must be called to finalize these
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <CODE>writeDevice()</CODE>.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param range maximum volt range, use
    *                <CODE>getRanges()</CODE> method to get available ranges
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    */
   public void setADRange(int channel, double range, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setADRange(channel, range, state.array);
   }

   /**
    * This method retrieves the 1-Wire device sensor state.  This state is
    * returned as a byte array.  Pass this byte array to the static query
    * and set methods.  If the device state needs to be changed then call
    * the <CODE>writeDevice()</CODE> to finalize the one or more change.
    *
    * @return 1-Wire device's state
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).readDevice());
   }

   /**
    * This method write the 1-Wire device sensor state that
    * have been changed by the 'set' methods.  It knows which registers have
    * changed by looking at the bitmap fields appended to the state
    * data.
    *
    * @param  state device's state
    *
    * @throws OneWireIOException Error writting data
    * @throws OneWireException Could not find part
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).writeDevice(state.array);
   }

   /**
    * Query to see if this temperature measuring device has high/low
    * trip alarms.
    *
    * @return true if has high/low trip alarms
    */
   public boolean hasTemperatureAlarms()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).hasTemperatureAlarms();
   }

   /**
    * Query to see if this device has selectable resolution.
    *
    * @return true if device has selectable resolution
    */
   public boolean hasSelectableTemperatureResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).hasSelectableTemperatureResolution();
   }

   /**
    * Query to get an array of available resolutions in degrees C.
    *
    * @return available resolutions in degrees C
    */
   public DoubleArray getTemperatureResolutions()
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getTemperatureResolutions());
   }

   /**
    * Query to get the high/low resolution in degrees C.
    *
    * @return high/low resolution resolution in degrees C
    *
    * @throws OneWireException Device does not have temperature alarms
    */
   public double getTemperatureAlarmResolution()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getTemperatureAlarmResolution();
   }

   /**
    * Query to get the maximum temperature in degrees C.
    *
    * @return maximum temperature in degrees C
    */
   public double getMaxTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getMaxTemperature();
   }

   /**
    * Query to get the minimum temperature in degrees C.
    *
    * @return minimum temperature in degrees C
    */
   public double getMinTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getMinTemperature();
   }

   /**
    * Perform an temperature conversion.  Use this state information
    * to calculate the conversion time.
    *
    * @param state device state
    *
    * @throws OneWireIOException Error writting data
    * @throws OneWireException Could not find part
    */
   public void doTemperatureConvert(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).doTemperatureConvert(state.array);
   }

   /**
    * This method extracts the Temperature Value in degrees C from the
    * state data retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param state device state
    *
    * @return temperature in degrees C from the last <CODE>doTemperature()</CODE>
    */
   public double getTemperature(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getTemperature(state.array);
   }

   /**
    * This method extracts the specified Alarm value in degrees C from the
    * state data retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param alarmType alarm trip type <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param state device state
    *
    * @return alarm trip temperature in degrees C
    *
    * @throws OneWireException Device does not have temperature alarms
    */
   public double getTemperatureAlarm(int alarmType, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getTemperatureAlarm(alarmType, state.array);
   }

   /**
    * This method extracts the current resolution in degrees C from the
    * state data retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param state device state
    *
    * @return temperature resolution in degrees C
    */
   public double getTemperatureResolution(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getTemperatureResolution(state.array);
   }

   /**
    * This method sets the alarm value in degrees C in the
    * provided state data.  Use the method <CODE>writeDevice()</CODE> with
    * this data to finalize the change to the device.
    *
    * @param alarmType alarm type <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param alarmValue trip value in degrees C
    * @param state device state
    *
    * @throws OneWireException Device does not have temperature alarms
    */
   public void setTemperatureAlarm(int alarmType, double alarmValue, ByteArray state)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setTemperatureAlarm(alarmType, alarmValue, state.array);
   }

   /**
    * This method sets the current resolution in degrees C in the
    * provided state data.   Use the method <CODE>writeDevice()</CODE> with
    * this data to finalize the change to the device.
    *
    * @param resolution temperature resolution in degrees C
    * @param state device state
    *
    * @throws OneWireIOException Error writting data
    * @throws OneWireException Could not find part
    */
   public void setTemperatureResolution(double resolution, ByteArray state)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setTemperatureResolution(resolution, state.array);
   }

   /**
    * Query to see if the clock has an alarm feature.
    *
    * @return true if real-time-clock has an alarm
    */
   public boolean hasClockAlarm()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).hasClockAlarm();
   }

   /**
    * Query to see if the clock can be disabled.  See
    * the methods <CODE>isClockRunning()</CODE> and <CODE>setClockRunEnable()</CODE>.
    *
    * @return true if the clock can be enabled and
    * disabled
    */
   public boolean canDisableClock()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).canDisableClock();
   }

   /**
    * Query to get the clock resolution in milliseconds
    *
    * @return clock resolution in milliseconds.
    */
   public String getClockResolution()
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getClockResolution();
   }

   /**
    * This method extracts the Clock Value in milliseconds from the
    * state data retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param state  device state
    *
    * @return time in milliseconds that have
    * occured since 1970
    */
   public String getClock(ByteArray state)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getClock(state.array);
   }

   /**
    * This method extracts the Clock Alarm Value from the provided
    * state data retrieved from the <CODE>readDevice()</CODE>
    * method.
    *
    * @param state device state
    *
    * @return time in milliseconds that have
    * the clock alarm is set to
    *
    * @throws OneWireException Device does not have clock alarm
    */
   public String getClockAlarm(ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getClockAlarm(state.array);
   }

   /**
    * This method checks if the Clock Alarm flag has been set
    * from the state data retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param state device state
    *
    * @return true if clock is alarming
    */
   public boolean isClockAlarming(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).isClockAlarming(state.array);
   }

   /**
    * This method checks if the Clock Alarm is enabled
    * from the provided state data retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param state device state
    *
    * @return true if clock alarm is enabled
    */
   public boolean isClockAlarmEnabled(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).isClockAlarmEnabled(state.array);
   }

   /**
    * This method checks if the device's oscilator is enabled.  The clock
    * will not increment if the clock is not enabled.
    * This value is read from the provided state data retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param state device state
    *
    * @return true if clock is running
    */
   public boolean isClockRunning(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).isClockRunning(state.array);
   }

   /**
    * This method sets the Clock time in the provided state data
    * Use the method <CODE>writeDevice()</CODE> with
    * this data to finalize the change to the device.
    *
    * @param time new clock setting in milliseconds
    * @param state device state
    */
   public void setClock(String time, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setClock(Long.parseLong(time), state.array);
   }

   /**
    * This method sets the Clock Alarm in the provided state
    * data.  Use the method <CODE>writeDevice()</CODE> with
    * this data to finalize the change to the device.
    *
    * @param time new clock setting in mlliseconds
    * @param state device state
    *
    * @throws OneWireException Device does not support clock alarm
    */
   public void setClockAlarm(String time, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setClockAlarm(Long.parseLong(time), state.array);
   }

   /**
    * This method sets the oscillator enable to the specified
    * value. Use the method <CODE>writeDevice()</CODE> with this
    * data to finalize the change to the device.
    *
    * @param runEnable true to enable clock oscillator
    * @param state device state
    *
    * @throws OneWireException Device does not support disabled clock
    */
   public void setClockRunEnable(boolean runEnable, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setClockRunEnable(runEnable, state.array);
   }

   /**
    * This method sets the Clock Alarm enable. Use the method
    * <CODE>writeDevice()</CODE> with this data to finalize the
    * change to the device.
    *
    * @param  alarmEnable - true to enable clock alarm
    * @param state device state
    *
    * @throws OneWireException Device does not support clock alarm
    */
   public void setClockAlarmEnable(boolean alarmEnable, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setClockAlarmEnable(alarmEnable, state.array);
   }

   /**
    * Checks to see if humidity value given is a 'relative' humidity value.
    *
    * @return <code>true</code> if this <code>HumidityContainer</code>
    *         provides a relative humidity reading
    *
    * @see    #getHumidityResolution
    * @see    #getHumidityResolutions
    * @see    #setHumidityResolution
    */
   public boolean isRelative()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).isRelative();
   }

   /**
    * Checks to see if this Humidity measuring device has high/low
    * trip alarms.
    *
    * @return <code>true</code> if this <code>HumidityContainer</code>
    *         has high/low trip alarms
    *
    * @see    #getHumidityAlarm
    * @see    #setHumidityAlarm
    */
   public boolean hasHumidityAlarms()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).hasHumidityAlarms();
   }

   /**
    * Checks to see if this device has selectable Humidity resolution.
    *
    * @return <code>true</code> if this <code>HumidityContainer</code>
    *         has selectable Humidity resolution
    *
    * @see    #getHumidityResolution
    * @see    #getHumidityResolutions
    * @see    #setHumidityResolution
    */
   public boolean hasSelectableHumidityResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).hasSelectableHumidityResolution();
   }

   /**
    * Get an array of available Humidity resolutions in percent humidity (0 to 100).
    *
    * @return byte array of available Humidity resolutions in percent with
    *         minimum resolution as the first element and maximum resolution
    *         as the last element.
    *
    * @see    #hasSelectableHumidityResolution
    * @see    #getHumidityResolution
    * @see    #setHumidityResolution
    */
   public DoubleArray getHumidityResolutions()
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getHumidityResolutions());
   }

   /**
    * Gets the Humidity alarm resolution in percent.
    *
    * @return Humidity alarm resolution in percent for this 1-wire device
    *
    * @throws OneWireException         Device does not support Humidity
    *                                  alarms
    *
    * @see    #hasHumidityAlarms
    * @see    #getHumidityAlarm
    * @see    #setHumidityAlarm
    *
    */
   public double getHumidityAlarmResolution()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getHumidityAlarmResolution();
   }

   /**
    * Performs a Humidity conversion.
    *
    * @param  state byte array with device state information
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void doHumidityConvert(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).doHumidityConvert(state.array);
   }

   /**
    * Gets the humidity expressed as a percent value (0.0 to 100.0) of humidity.
    *
    * @param  state byte array with device state information
    * @return humidity expressed as a percent
    *
    * @see    #hasSelectableHumidityResolution
    * @see    #getHumidityResolution
    * @see    #setHumidityResolution
    */
   public double getHumidity(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getHumidity(state.array);
   }

   /**
    * Gets the current Humidity resolution in percent from the
    * <code>state</code> data retrieved from the <code>readDevice()</code>
    * method.
    *
    * @param  state byte array with device state information
    *
    * @return Humidity resolution in percent for this 1-wire device
    *
    * @see    #hasSelectableHumidityResolution
    * @see    #getHumidityResolutions
    * @see    #setHumidityResolution
    */
   public double getHumidityResolution(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getHumidityResolution(state.array);
   }

   /**
    * Gets the specified Humidity alarm value in percent from the
    * <code>state</code> data retrieved from the
    * <code>readDevice()</code> method.
    *
    * @param  alarmType valid value: <code>ALARM_HIGH</code> or
    *                   <code>ALARM_LOW</code>
    * @param  state     byte array with device state information
    *
    * @return Humidity alarm trip values in percent for this 1-wire device
    *
    * @throws OneWireException         Device does not support Humidity
    *                                  alarms
    *
    * @see    #hasHumidityAlarms
    * @see    #setHumidityAlarm
    */
   public double getHumidityAlarm(int alarmType, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).getHumidityAlarm(alarmType, state.array);
   }

   /**
    * Sets the Humidity alarm value in percent in the provided
    * <code>state</code> data.
    * Use the method <code>writeDevice()</code> with
    * this data to finalize the change to the device.
    *
    * @param  alarmType  valid value: <code>ALARM_HIGH</code> or
    *                    <code>ALARM_LOW</code>
    * @param  alarmValue alarm trip value in percent
    * @param  state      byte array with device state information
    *
    * @throws OneWireException         Device does not support Humidity
    *                                  alarms
    *
    * @see    #hasHumidityAlarms
    * @see    #getHumidityAlarm
    */
   public void setHumidityAlarm(int alarmType, double alarmValue, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setHumidityAlarm(alarmType, alarmValue, state.array);
   }

   /**
    * Sets the current Humidity resolution in percent in the provided
    * <code>state</code> data.   Use the method <code>writeDevice()</code>
    * with this data to finalize the change to the device.
    *
    * @param  resolution Humidity resolution in percent
    * @param  state      byte array with device state information
    *
    * @throws OneWireException         Device does not support selectable
    *                                  Humidity resolution
    *
    * @see    #hasSelectableHumidityResolution
    * @see    #getHumidityResolution
    * @see    #getHumidityResolutions
    */
   public void setHumidityResolution(double resolution, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer26)objectInstance).setHumidityResolution(resolution, state.array);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer26)o;
      return this;
   }
}
