// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire container for Real-Time Clock with Interrupt, DS2417.  The DS2417 is similar
 * to the DS2415 with the addition of a hardware interrupt pin.  This container 
 * encapsulates the functionality of the iButton family type <B>27</B> (hex)</P>
 * 
 * <H3> Features </H3> 
 * <UL>
 *   <LI> Real-Time Clock with fully compatible 1-Wire MicroLAN interface
 *   <LI> Programmable interrupt output for system wakeup
 *   <LI> Uses the same binary time/date representation as the DS2404 
 *        but with 1 second resolution
 *   <LI> Clock accuracy  2 minutes per month at 25&#176
 *   <LI> Operating temperature range from -40&#176C to
 *        +85&#176C
 *   <LI> Low power, 200 nA typical with oscillator running
 * </UL>
 * 
 * <H3> Clock </H3> 
 *
 * <P>The clock methods can be organized into the following categories.  Note that methods
 *    that are implemented for the {@link ClockContainer ClockContainer} 
 *    interface are marked with (*): </P>
 * <UL>
 *   <LI> <B> Information </B>
 *     <UL>
 *       <LI> {@link #hasClockAlarm() hasClockAlarm} *
 *       <LI> {@link #canDisableClock() canDisableClock} *
 *       <LI> {@link #getClockResolution() getClockResolution} *
 *     </UL>
 *   <LI> <B> Read </B>
 *     <UL>
 *       <LI> <I> Clock </I>
 *         <UL>
 *           <LI> {@link #getClock(byte[]) getClock} *
 *           <LI> {@link #getClockAlarm(byte[]) getClockAlarm} *
 *           <LI> {@link #isClockAlarming(byte[]) isClockAlarming} *
 *           <LI> {@link #isClockAlarmEnabled(byte[]) isClockAlarmEnabled} *
 *           <LI> {@link #isClockRunning(byte[]) isClockRunning} *
 *         </UL>
 *       <LI> <I> Misc </I>
 *         <UL>
 *           <LI> {@link #readDevice() readDevice} *
 *         </UL>
 *     </UL>
 *   <LI> <B> Write </B>
 *     <UL>
 *       <LI> <I> Clock </I>
 *         <UL>
 *           <LI> {@link #setClock(long, byte[]) setClock} *
 *           <LI> {@link #setClockAlarm(long, byte[]) setClockAlarm} *
 *           <LI> {@link #setClockRunEnable(boolean, byte[]) setClockRunEnable} *
 *           <LI> {@link #setClockAlarmEnable(boolean, byte[]) setClockAlarmEnable} *
 *         </UL>
 *       <LI> <I> Misc </I>
 *         <UL>
 *           <LI> {@link #writeDevice(byte[]) writeDevice} *
 *         </UL>
 *     </UL>
 *  </UL>
 *
 * <H3> Usage </H3> 
 * 
 * <DL> 
 * <DD> See the usage example in 
 * {@link ClockContainer ClockContainer}
 * for clock specific operations.
 * </DL>
 *
 * <H3> DataSheet </H3> 
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2417.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2417.pdf</A>
 * </DL>
 * 
 * @see ClockContainer
 * 
 * @version CLSID=4C19B40E-E90A-45F7-8F52-64560C8872C4 -     1.10, 26 September 2001
 * @author     BA
 * @com.register ( clsid=4C19B40E-E90A-45F7-8F52-64560C8872C4, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer27
   extends OneWireContainer24
   implements com.ms.com.IUnknown, ClockContainer 
{

   //Instance defined in super class: OneWireContainer24
   //com.dalsemi.onewire.container.OneWireContainer27 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer27()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer27());
   }

   OneWireContainer27(com.dalsemi.onewire.container.OneWireContainer27 o)
   {
      super(o);
   }
   OneWireContainer27(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer27)o);
   }

   public static final byte INTERRUPT_INTERVAL_1
          = com.dalsemi.onewire.container.OneWireContainer27.INTERRUPT_INTERVAL_1;

   public static final byte INTERRUPT_INTERVAL_4
          = com.dalsemi.onewire.container.OneWireContainer27.INTERRUPT_INTERVAL_4;

   public static final byte INTERRUPT_INTERVAL_32
          = com.dalsemi.onewire.container.OneWireContainer27.INTERRUPT_INTERVAL_32;

   public static final byte INTERRUPT_INTERVAL_64
          = com.dalsemi.onewire.container.OneWireContainer27.INTERRUPT_INTERVAL_64;

   public static final byte INTERRUPT_INTERVAL_2048
          = com.dalsemi.onewire.container.OneWireContainer27.INTERRUPT_INTERVAL_2048;

   public static final byte INTERRUPT_INTERVAL_4096
          = com.dalsemi.onewire.container.OneWireContainer27.INTERRUPT_INTERVAL_4096;

   public static final byte INTERRUPT_INTERVAL_65536
          = com.dalsemi.onewire.container.OneWireContainer27.INTERRUPT_INTERVAL_65536;

   public static final byte INTERRUPT_INTERVAL_131072
          = com.dalsemi.onewire.container.OneWireContainer27.INTERRUPT_INTERVAL_131072;

   /**
    * Returns the interval, in seconds, that the device will interrupt on.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    * @return number of seconds in between interrupts.
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #getClock(byte[])
    */
   public String getInterruptInterval(ByteArray a0)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer27)objectInstance).getInterruptInterval(a0.array);
   }

   /**
    *
    * Checks to see if interrupt mode is turned on. If so, pulses will be generated
    * at an interval selected by setInterruptInterval.
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if interrupts are enabled
    *
    * @see OneWireSensor#readDevice()
    * @see #canDisableClock()
    * @see #setClockRunEnable(boolean,byte[])
    */
   public boolean isInterruptEnabled(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer27)objectInstance).isInterruptEnabled(a0.array);
   }

   /**
    * Sets the interval at which interrupting will occur.  Note that this feature
    * must be enabled first using setInterruptEnable(true,state).
    *
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param intervalValue One of the following variables should be passed, representing
    * different time intervals to interrupt at:
    *       <code>INTERRUPT_INTERVAL_1</code>    1 second
    *       <code>INTERRUPT_INTERVAL_4</code>    4 seconds
    *       <code>INTERRUPT_INTERVAL_32</code>    32 seconds
    *       <code>INTERRUPT_INTERVAL_32</code>    64 seconds
    *       <code>INTERRUPT_INTERVAL_64</code>    2048 seconds
    *       <code>INTERRUPT_INTERVAL_2048</code>    4096 seconds
    *       <code>INTERRUPT_INTERVAL_4096</code>    65536 seconds
    *       <code>INTERRUPT_INTERVAL_131072</code>    131072 seconds
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #getClock(byte[])
    */
   public void setInterruptInterval(byte a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer27)objectInstance).setInterruptInterval(a0, a1.array);
   }

   /**
    * Enables or disables hardware interrupting.  If enabled, the
    * device sends an interrupt at intervals defined by using the
    * setInterruptInterval function.
    * @param runEnable true to enable interval interrupts.
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #canDisableClock()
    * @see #isClockRunning(byte[])
    */
   public void setInterruptEnable(boolean a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer27)objectInstance).setInterruptEnable(a0, a1.array);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer27)o;
      return this;
   }
}
