// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire container for temperature iButton which measures temperatures
 * from -55&#176C to +125&#176C, DS18B20.  This container encapsulates the
 * functionality of the iButton family type <B>28</B> (hex)</P>
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> Measures temperatures from -55&#176C to +125&#176C. Fahrenheit
 *        equivalent is -67&#176F to +257&#176F
 *   <LI> Power supply range is 3.0V to 5.5V
 *   <LI> Zero standby power
 *   <LI> +/- 0.5&#176C accuracy from -10&#176C to +85&#176C
 *   <LI> Thermometer resolution programmable from 9 to 12 bits
 *   <LI> Converts 12-bit temperature to digital word in 750 ms (max.)
 *   <LI> User-definable, nonvolatile temperature alarm settings
 *   <LI> Alarm search command identifies and addresses devices whose temperature is
 *        outside of programmed limits (temperature alarm condition)
 * </UL>
 *
 * <H3> Usage </H3>
 *
 * <DL>
 * <DD> See the usage example in
 * {@link TemperatureContainer TemperatureContainer}
 * for temperature specific operations.
 * </DL>
 *
 * <H3> DataSheet </H3>
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS18B20.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS18B20.pdf</A>
 * </DL>
 *
 * @see TemperatureContainer
 *
 * @version CLSID=00943C11-5E36-4271-8E10-F5321D792349 -     1.00, 15 September 2000
 * @author     BH
 * @com.register ( clsid=00943C11-5E36-4271-8E10-F5321D792349, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer28
   extends OneWireContainer
   implements com.ms.com.IUnknown, TemperatureContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer28 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer28()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer28());
   }

   OneWireContainer28(com.dalsemi.onewire.container.OneWireContainer28 o)
   {
      super(o);
   }
   OneWireContainer28(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer28)o);
   }

   public static final byte WRITE_SCRATCHPAD_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer28.WRITE_SCRATCHPAD_COMMAND;

   public static final byte READ_SCRATCHPAD_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer28.READ_SCRATCHPAD_COMMAND;

   public static final byte COPY_SCRATCHPAD_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer28.COPY_SCRATCHPAD_COMMAND;

   public static final byte CONVERT_TEMPERATURE_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer28.CONVERT_TEMPERATURE_COMMAND;

   public static final byte RECALL_E2MEMORY_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer28.RECALL_E2MEMORY_COMMAND;

   public static final byte READ_POWER_SUPPLY_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer28.READ_POWER_SUPPLY_COMMAND;

   public static final byte RESOLUTION_12_BIT
          = com.dalsemi.onewire.container.OneWireContainer28.RESOLUTION_12_BIT;

   public static final byte RESOLUTION_11_BIT
          = com.dalsemi.onewire.container.OneWireContainer28.RESOLUTION_11_BIT;

   public static final byte RESOLUTION_10_BIT
          = com.dalsemi.onewire.container.OneWireContainer28.RESOLUTION_10_BIT;

   public static final byte RESOLUTION_9_BIT
          = com.dalsemi.onewire.container.OneWireContainer28.RESOLUTION_9_BIT;

   /**
    * Checks to see if this temperature measuring device has high/low
    * trip alarms.
    *
    * @return <code>true</code> if this <code>OneWireContainer28</code>
    *         has high/low trip alarms
    *
    * @see    #getTemperatureAlarm
    * @see    #setTemperatureAlarm
    */
   public boolean hasTemperatureAlarms()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).hasTemperatureAlarms();
   }

   /**
    * Checks to see if this device has selectable temperature resolution.
    *
    * @return <code>true</code> if this <code>OneWireContainer28</code>
    *         has selectable temperature resolution
    *
    * @see    #getTemperatureResolution
    * @see    #getTemperatureResolutions
    * @see    #setTemperatureResolution
    */
   public boolean hasSelectableTemperatureResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).hasSelectableTemperatureResolution();
   }

   /**
    * Gets an array of available temperature resolutions in Celsius.
    *
    * @return byte array of available temperature resolutions in Celsius for
    *         this <code>OneWireContainer28</code>. The minimum resolution is
    *         returned as the first element and maximum resolution as the last
    *         element.
    *
    * @see    #hasSelectableTemperatureResolution
    * @see    #getTemperatureResolution
    * @see    #setTemperatureResolution
    */
   public DoubleArray getTemperatureResolutions()
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).getTemperatureResolutions());
   }

   /**
    * Gets the temperature alarm resolution in Celsius.
    *
    * @return temperature alarm resolution in Celsius for this
    *         <code>OneWireContainer28</code>
    *
    * @see    #hasTemperatureAlarms
    * @see    #getTemperatureAlarm
    * @see    #setTemperatureAlarm
    *
    */
   public double getTemperatureAlarmResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).getTemperatureAlarmResolution();
   }

   /**
    * Gets the maximum temperature in Celsius.
    *
    * @return maximum temperature in Celsius for this
    *         <code>OneWireContainer28</code>
    *
    * @see    #getMinTemperature
    */
   public double getMaxTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).getMaxTemperature();
   }

   /**
    * Gets the minimum temperature in Celsius.
    *
    * @return minimum temperature in Celsius for this
    *         <code>OneWireContainer28</code>
    *
    * @see    #getMaxTemperature
    */
   public double getMinTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).getMinTemperature();
   }

   /**
    * Performs a temperature conversion on <code>state</code> information.
    *
    * @param  state byte array with device state information
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer28</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see    #getTemperature
    */
   public void doTemperatureConvert(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).doTemperatureConvert(state.array);
   }

   /**
    * Gets the temperature value in Celsius from the <code>state</code>
    * data retrieved from the <code>readDevice()</code> method.
    *
    * @param  state byte array with device state information for this
    *         <code>OneWireContainer28</code>
    *
    * @return temperature in Celsius from the last
    *                     <code>doTemperatureConvert()</code>
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer28</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    *
    * @see    #doTemperatureConvert
    */
   public double getTemperature(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).getTemperature(state.array);
   }

   /**
    * Gets the specified temperature alarm value in Celsius from the
    * <code>state</code> data retrieved from the  <code>readDevice()</code>
    * method.
    *
    * @param  alarmType valid value: <code>ALARM_HIGH</code> or
    *                   <code>ALARM_LOW</code>
    * @param  state     byte array with device state information
    *
    * @return temperature alarm trip values in Celsius for this
    *         <code>OneWireContainer28</code>
    *
    * @see    #hasTemperatureAlarms
    * @see    #setTemperatureAlarm
    */
   public double getTemperatureAlarm(int alarmType, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).getTemperatureAlarm(alarmType, state.array);
   }

   /**
    * Gets the current temperature resolution in Celsius from the
    * <code>state</code> data retrieved from the <code>readDevice()</code>
    * method.
    *
    * @param  state byte array with device state information
    *
    * @return temperature resolution in Celsius for this
    *         <code>OneWireContainer28</code>
    *
    * @see    #RESOLUTION_9_BIT
    * @see    #RESOLUTION_10_BIT
    * @see    #RESOLUTION_11_BIT
    * @see    #RESOLUTION_12_BIT
    * @see    #hasSelectableTemperatureResolution
    * @see    #getTemperatureResolutions
    * @see    #setTemperatureResolution
    */
   public double getTemperatureResolution(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).getTemperatureResolution(state.array);
   }

   /**
    * Sets the temperature alarm value in Celsius in the provided
    * <code>state</code> data.
    * Use the method <code>writeDevice()</code> with
    * this data to finalize the change to the device.
    *
    * @param  alarmType  valid value: <code>ALARM_HIGH</code> or
    *                    <code>ALARM_LOW</code>
    * @param  alarmValue alarm trip value in Celsius
    * @param  state      byte array with device state information
    *
    * @see    #hasTemperatureAlarms
    * @see    #getTemperatureAlarm
    */
   public void setTemperatureAlarm(int alarmType, double alarmValue, ByteArray state)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).setTemperatureAlarm(alarmType, alarmValue, state.array);
   }

   /**
    * Sets the current temperature resolution in Celsius in the provided
    * <code>state</code> data.   Use the method <code>writeDevice()</code>
    * with this data to finalize the change to the device.
    *
    * @param  resolution temperature resolution in Celsius. Valid values are
    *                    <code>RESOLUTION_9_BIT</code>,
    *                    <code>RESOLUTION_10_BIT</code>,
    *                    <code>RESOLUTION_11_BIT</code> and
    *                    <code>RESOLUTION_12_BIT</code>.
    * @param  state      byte array with device state information
    *
    * @see    #RESOLUTION_9_BIT
    * @see    #RESOLUTION_10_BIT
    * @see    #RESOLUTION_11_BIT
    * @see    #RESOLUTION_12_BIT
    * @see    #hasSelectableTemperatureResolution
    * @see    #getTemperatureResolution
    * @see    #getTemperatureResolutions
    */
   public void setTemperatureResolution(double resolution, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).setTemperatureResolution(resolution, state.array);
   }

   /**
    * Retrieves this <code>OneWireContainer28</code> state information.
    * The state information is returned as a byte array.  Pass this byte
    * array to the '<code>get</code>' and '<code>set</code>' methods.
    * If the device state needs to be changed, then call the
    * <code>writeDevice()</code> to finalize the changes.
    *
    * @return <code>OneWireContainer28</code> state information.
    * Device state looks like this:
    * <pre>
    *   0 : temperature LSB
    *   1 : temperature MSB
    *   2 : trip high
    *   3 : trip low
    *   4 : configuration register (for resolution)
    *   5 : reserved
    *   6 : reserved
    *   7 : reserved
    *   8 : an 8 bit CRC of the previous 8 bytes
    * </pre>
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer28</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see    #writeDevice
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).readDevice());
   }

   /**
    * Writes to this <code>OneWireContainer28</code> <code>state</code>
    * information that have been changed by '<code>set</code>' methods.
    * Only the state registers that changed are updated.  This is done
    * by referencing a field information appended to the state data.
    *
    * @param  state      byte array with device state information
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer28</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see    #readDevice
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).writeDevice(state.array);
   }

   /**
    * Reads the Scratchpad of the DS18B20.
    *
    * @return 9-byte buffer representing the scratchpad
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer28</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public ByteArray readScratchpad()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).readScratchpad());
   }

   /**
    * Writes to the Scratchpad of the DS18B20.
    *
    * @param data data to be written to the scratchpad.  First
    *             byte of data must be the temperature High Trip Point, the
    *             second byte must be the temperature Low Trip Point, and
    *             the third must be the Resolution (configuration register).
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer28</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    * @throws IllegalArgumentException when data is of invalid length
    */
   public void writeScratchpad(ByteArray data)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).writeScratchpad(data.array);
   }

   /**
    * Copies the Scratchpad to the E-squared memory of the DS18B20.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer28</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void copyScratchpad()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).copyScratchpad();
   }

   /**
    * Recalls the DS18B20 temperature trigger values (<code>ALARM_HIGH</code>
    * and <code>ALARM_LOW</code>) and the configuration register to the
    * scratchpad and reads the scratchpad.
    *
    * @return byte array representing data in the device's scratchpad.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer28</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public ByteArray recallE2()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).recallE2());
   }

   /**
    * Reads the way power is supplied to the DS18B20.
    *
    * @return <code>true</code> for external power, <BR>
    *         <code>false</code> for parasite power
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from this <code>OneWireContainer28</code>.
    *         This could be caused by a physical interruption in the 1-Wire
    *         Network due to shorts or a newly arriving 1-Wire device issuing a
    *         'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public boolean isExternalPowerSupplied()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).isExternalPowerSupplied();
   }

   /**
    * Converts a temperature reading from Celsius to Fahrenheit.
    *
    * @param   celsiusTemperature temperature value in Celsius
    *
    * @return  the Fahrenheit conversion of the supplied temperature
    *
    * @deprecated Replace with call to toFahrenheit()
    *
    * @see Convert#toFahrenheit(double)
    */
   public float convertToFahrenheit(float a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer28)objectInstance).convertToFahrenheit(a0);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer28)o;
      return this;
   }
}
