// COM proxy class, output from FunctionList.js
package owapi;
/**
 *<P>1-Wire&#174 container that encapsulates the functionality of the 1-Wire
 * family type <B>30</B> (hex), Dallas Semiconductor part number: <B>DS2760,
 * High Precision Li-ion Battery Monitor</B>.</P>
 *
 * <H3>Features</H3>
 * <UL>
 *    <LI>Li-ion safety circuit
 *       <UL>
 *         <LI>Overvoltage protection
 *         <LI>Overcurrent/short circuit protection
 *         <LI>Undervoltage protection
 *       </UL>
 *    <LI>Two sense resistor configurations
 *       <UL>
 *          <LI>Internal 25 mOhm sense resistor
 *          <LI>External user-selectable sense resistor
 *       </UL>
 *     <LI>12-bit bi-directional current measurement
 *     <LI>Current accumulation
 *     <LI>Voltage measurement
 *     <LI>Direct-to-digital temperature measurement
 *     <LI>32 bytes of lockable EEPROM
 *     <LI>16 bytes of general purpose SRAM
 *     <LI>Low power consumption
 *        <UL>
 *           <LI>Active current: 80 &#181A max
 *           <LI>Sleep current: 2 &#181A max
 *        </UL>
 * </UL>
 *
 * <H3>Data sheet</H3>
 *
 * <A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2760.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2760.pdf</A>
 *
 *
 *
 * @version CLSID=57A521BD-0DD3-4B97-9516-F157F78CC07F -     0.00, 28 Aug 2000
 * @author     COlmstea
 *
 * Converted to use interfaces, general rework KLA
 * @com.register ( clsid=57A521BD-0DD3-4B97-9516-F157F78CC07F, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer30
   extends OneWireContainer
   implements com.ms.com.IUnknown, ADContainer, TemperatureContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer30 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer30()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer30());
   }

   OneWireContainer30(com.dalsemi.onewire.container.OneWireContainer30 o)
   {
      super(o);
   }
   OneWireContainer30(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer30)o);
   }

   public static final byte PROTECTION_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer30.PROTECTION_REGISTER;

   public static final byte STATUS_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer30.STATUS_REGISTER;

   public static final byte EEPROM_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer30.EEPROM_REGISTER;

   public static final byte SPECIAL_FEATURE_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer30.SPECIAL_FEATURE_REGISTER;

   public static final byte OVERVOLTAGE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.OVERVOLTAGE_FLAG;

   public static final byte UNDERVOLTAGE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.UNDERVOLTAGE_FLAG;

   public static final byte CHARGE_OVERCURRENT_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.CHARGE_OVERCURRENT_FLAG;

   public static final byte DISCHARGE_OVERCURRENT_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.DISCHARGE_OVERCURRENT_FLAG;

   public static final byte CC_PIN_STATE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.CC_PIN_STATE_FLAG;

   public static final byte DC_PIN_STATE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.DC_PIN_STATE_FLAG;

   public static final byte CHARGE_ENABLE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.CHARGE_ENABLE_FLAG;

   public static final byte DISCHARGE_ENABLE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.DISCHARGE_ENABLE_FLAG;

   public static final byte SLEEP_MODE_ENABLE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.SLEEP_MODE_ENABLE_FLAG;

   public static final byte READ_NET_ADDRESS_OPCODE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.READ_NET_ADDRESS_OPCODE_FLAG;

   public static final byte EEPROM_COPY_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.EEPROM_COPY_FLAG;

   public static final byte EEPROM_LOCK_ENABLE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.EEPROM_LOCK_ENABLE_FLAG;

   public static final byte EEPROM_BLOCK_1_LOCK_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.EEPROM_BLOCK_1_LOCK_FLAG;

   public static final byte EEPROM_BLOCK_0_LOCK_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.EEPROM_BLOCK_0_LOCK_FLAG;

   public static final byte PS_PIN_STATE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.PS_PIN_STATE_FLAG;

   public static final byte PIO_PIN_SENSE_AND_CONTROL_FLAG
          = com.dalsemi.onewire.container.OneWireContainer30.PIO_PIN_SENSE_AND_CONTROL_FLAG;

   /**
    * Sets the DS2760 to use its internal .025 ohm resistor for measurements.
    * This should only be enabled if there is NO external resistor physically
    * attached to the device.
    */
   public synchronized void setResistorInternal()
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).setResistorInternal();
   }

   /**
    * Sets the DS2760 to use an external, user-selectable resistance. This
    * Resistance should be wired directly to the VSS (negative terminal of
    * the cell).
    *
    * @param Rsens resistance in ohms
    */
   public synchronized void setResistorExternal(double Rsens)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).setResistorExternal(Rsens);
   }

   /**
    * Reads a register byte from the memory of the DS2760.  Note that there
    * is no error checking as the DS2760 performs no CRC on the data.
    * <p>
    * Note: This function should only be used when reading the register
    * memory of the DS2760. The EEPROM blocks (addresses 32-64) should be
    * accessed with writeBlock/readBlock.
    *
    * @param memAddr the address to read (0-255)
    *
    * @return data read from memory
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    */
   public byte readByte(int memAddr)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).readByte(memAddr);
   }

   /**
    * Reads bytes from the DS2760.  Note that there is no error-checking as
    * the DS2760 does not perform a CRC on the data.
    * <p>
    * Note: This function should only be used when reading the register
    * memory of the DS2760. The EEPROM blocks (addresses 32-64) should be
    * accessed with writeBlock/readBlock.
    *
    * @param memAddr the address to read (0-255)
    * @param buffer buffer to receive data
    * @param start start position within buffer to place data
    * @param len length of buffer
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    */
   public void readBytes(int memAddr, ByteArray buffer, int start, int len)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).readBytes(memAddr, buffer.array, start, len);
   }

   /**
    * Writes a register byte to the memory of the DS2760.  Note that the
    * DS2760 does not make any use of cyclic redundancy checks (error-checking).
    * To ensure error free transmission, double check write operation.
    * <p>
    * Note: This method should only be used when writing to the register memory
    * of the DS2760. The EEPROM blocks (addresses 32-64) require special treatment
    * and thus the writeBlock/readBlock functions should be used for those.
    *
    * @param memAddr  address to write (0-255)
    * @param data     data byte to write to memory
    *
    * @throws OneWireIOException Error writing data
    * @throws OneWireException Could not find part
    */
   public void writeByte(int memAddr, byte data)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).writeByte(memAddr, data);
   }

   /**
    * Reads a 16 byte data block from one of the user EEPROM blocks.
    * Note that there is no error-checking as the DS2760 performs
    * no CRCs.
    *
    * @param blockNumber the EEPROM block number to read,
    * acceptable parameters are 0 and 1
    *
    * @return 16 data bytes
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    */
   public ByteArray readEEPROMBlock(int blockNumber)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).readEEPROMBlock(blockNumber));
   }

   /**
    * Writes a 16 byte data block to one of the user blocks. The block may be
    * rewritten at any time, except after it is locked with <CODE>lockBlock()</CODE>.
    * This method performs error checking by verifying data written.
    *
    * @param blockNumber block to write,
    * acceptable parameters are 0 and 1
    * @param data 16 bytes of data to write
    *
    * @throws OneWireIOException Error writing data
    * @throws OneWireException Could not find part
    */
   public void writeEEPROMBlock(int blockNumber, ByteArray data)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).writeEEPROMBlock(blockNumber, data.array);
   }

   /**
    * Permanently write-protects one of the user blocks of EEPROM.
    *
    * @param blockNumber block number to permanently write protect,
    * acceptable parameters are 0 and 1.
    *
    * @throws OneWireIOException Error locking block
    * @throws OneWireException Could not find part
    */
   public void lockBlock(int blockNumber)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).lockBlock(blockNumber);
   }

   /**
    * Checks the specified flag in the specified register.  <BR>
    * Valid registers are:
    * <A HREF="#PROTECTION_REGISTER"><CODE>PROTECTION_REGISTER</CODE></A>,
    * <A HREF="#STATUS_REGISTER"><CODE>STATUS_REGISTER</CODE></A>,
    * <A HREF="#EEPROM_REGISTER"><CODE>EEPROM_REGISTER</CODE></A> and
    * <A HREF="#SPECIAL_FEATURE_REGISTER"><CODE>SPECIAL_FEATURE_REGISTER</CODE></A>.
    *
    * @param memAddr registers address. Pre-defined
    * fields for each register are defined above.
    * @param flagToGet bitmask of desired flag, the acceptable parameters
    * pertaining to each register are defined as constant fields above
    *
    * @return value of the flag: <CODE>true</CODE> if flag is set (=1)
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    *
    */
   public boolean getFlag(int memAddr, byte flagToGet)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getFlag(memAddr, flagToGet);
   }

   /**
    * Sets one of the flags in one of the registers.<BR>
    * Valid registers are:
    * <A HREF="#PROTECTION_REGISTER"><CODE>PROTECTION_REGISTER</CODE></A>,
    * <A HREF="#STATUS_REGISTER"><CODE>STATUS_REGISTER</CODE></A>,
    * <A HREF="#EEPROM_REGISTER"><CODE>EEPROM_REGISTER</CODE></A> and
    * <A HREF="#SPECIAL_FEATURE_REGISTER"><CODE>SPECIAL_FEATURE_REGISTER</CODE></A>.
    *
    * @param memAddr register address, these addresses are
    * predefined above
    * @param flagToSet bitmask of flag to set, valid
    * parameters pertaining to each register are defined
    * as constant fields above
    * @param flagValue value to set the flag to
    *
    * @throws OneWireIOException Error setting flag
    * @throws OneWireException Could not find part
    */
   public void setFlag(int memAddr, byte flagToSet, boolean flagValue)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).setFlag(memAddr, flagToSet, flagValue);
   }

   /**
    * Gets the instantaneous current.
    *
    *
    * @param state device state
    * @return current in Amperes
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    */
   public double getCurrent(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getCurrent(state.array);
   }

   /**
    * Allows user to set the remaining capacity. Good for accurate capacity
    * measurements using temperature and battery life.
    * <p> By measuring the battery's current and voltage when it is fully
    * charged and when it is empty, the voltage corresponding to an empty battery
    * and the current corresponding to a full one can be derived. These
    * values can be detected in user program and the remaining capacity can
    * be set to the empty/full levels accordingly for nice accuracy.
    *
    * @param remainingCapacity remaining capacity in mAH
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    */
   public void setRemainingCapacity(double remainingCapacity)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).setRemainingCapacity(remainingCapacity);
   }

   /**
    * Calculates the remaining capacity in mAHours from the current
    * Accumulator. Accurate to +/- .25 mAH.
    *
    * @param state device state
    * @return mAHours of battery capacity remaining
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    */
   public double getRemainingCapacity(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getRemainingCapacity(state.array);
   }

   /**
    * No documentation available for method 
    */
   public void setLatchState(boolean on)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).setLatchState(on);
   }

   /**
    * Returns the latch state of the Programmable Input/Ouput
    * pin on the DS2760.
    *
    * @return state of the Programmable Input/Ouput pin
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find part
    */
   public boolean getLatchState()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getLatchState();
   }

   /**
    * Clears the overvoltage, undervoltage, charge overcurrent,
    * and discharge overcurrent flags.  Each time a violation
    * occurs, these flags stay set until reset.  This method
    * resets all 4 flags.
    *
    * @throws OneWireIOException Error writting data
    * @throws OneWireException Could not find part
    */
   public void clearConditions()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).clearConditions();
   }

   /**
    * Queries to get the number of channels supported by this A/D device.
    * Channel specific methods will use a channel number specified
    * by an integer from <CODE>[0 to (getNumberChannels() - 1)]</CODE>.
    *
    * @return number of channels
    */
   public int getNumberADChannels()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getNumberADChannels();
   }

   /**
    * Queries to see if this A/D measuring device has high/low
    * alarms.
    *
    * @return <CODE>true</CODE> if has high/low trips
    */
   public boolean hasADAlarms()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).hasADAlarms();
   }

   /**
    * Queries to get an array of available ranges for the specified
    * A/D channel.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    *
    * @return available ranges
    */
   public DoubleArray getADRanges(int channel)
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getADRanges(channel));
   }

   /**
    * Queries to get an array of available resolutions based
    * on the specified range on the specified A/D channel.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param range range of channel specified in channel parameter
    *
    * @return available resolutions
    */
   public DoubleArray getADResolutions(int channel, double range)
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getADResolutions(channel, range));
   }

   /**
    * Queries to see if this A/D device supports doing multiple voltage
    * conversions at the same time.
    *
    * @return <CODE>true</CODE> if can do multi-channel voltage reads
    */
   public boolean canADMultiChannelRead()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).canADMultiChannelRead();
   }

   /**
    * Performs voltage conversion on the specified channel.  The method
    * <CODE>getADVoltage()</CODE> can be used to read the result of the
    * conversion.
    *
    * @param channel   channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state     current state of this
    *                  device returned from <CODE>readDevice()</CODE>
    *
    * @throws OneWireIOException Error writting data
    * @throws OneWireException Could not find device
    */
   public void doADConvert(int channel, ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).doADConvert(channel, state.array);
   }

   /**
    * Performs voltage conversion on all specified channels.  The method
    * <CODE>getADVoltage()</CODE> can be used to read the result
    * of the conversion. This A/D must support multi-channel read
    * <CODE>canMultiChannelRead()</CODE> if there are more than 1 channel
    * is specified.
    *
    * @param doConvert channels to perform conversion on
    * @param state  current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws OneWireIOException Error writting data
    * @throws OneWireException Device does not support multi-channel reading
    */
   public void doADConvertMulti(BooleanArray doConvert, ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).doADConvert(doConvert.array, state.array);
   }

   /**
    * Reads the voltage values.  Must be used after a <CODE>doADConvert()</CODE>
    * method call.  Also must include the last valid state from the
    * <CODE>readDevice()</CODE> method and this A/D must support multi-channel
    * read <CODE>canMultiChannelRead()</CODE> if there are more than 1 channel.
    *
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @return voltage values for all channels
    *
    * @throws OneWireIOException Error writting data
    * @throws OneWireException Device does not support multi-channel reading
    */
   public DoubleArray getADVoltage(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getADVoltage(state.array));
   }

   /**
    * Reads a channel voltage value.  Must be used after a
    * <CODE>doADConvert()</CODE> method call.  Also must
    * include the last valid state from the <CODE>readDevice()</CODE>
    * method.
    * Note, if more than one channel is to be read then it is more
    * efficient to use the <CODE>getADVoltage(byte[])</CODE> method that returns all
    * channel values.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @return voltage value for the specified
    *                  channel
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find device
    */
   public double getADVoltage(int channel, ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getADVoltage(channel, state.array);
   }

   /**
    * Extracts the alarm voltage value of the specified channel from the
    * provided state buffer.  The state buffer is retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @return alarm_value in volts
    *
    * @throws OneWireException Device does not support A/D alarms
    */
   public double getADAlarm(int channel, int alarmType, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getADAlarm(channel, alarmType, state.array);
   }

   /**
    * Extracts the alarm enable value of the specified channel from the
    * provided state buffer.  The state buffer is retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param state current state of the device
    *               returned from <CODE>readDevice()</CODE>
    *
    * @return <CODE>true</CODE> if specified alarm is enabled
    *
    * @throws OneWireException Device does not support A/D alarms
    */
   public boolean getADAlarmEnable(int channel, int alarmType, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getADAlarmEnable(channel, alarmType, state.array);
   }

   /**
    * Checks the A/D alarm event value of the specified channel from the
    * provided state buffer.  The state buffer is retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param state current state of the device
    *               returned from <CODE>readDevice()</CODE>
    *
    * @return <CODE>true</CODE> if specified alarm occurred
    *
    * @throws OneWireException Device does not support A/D alarms
    */
   public boolean hasADAlarmed(int channel, int alarmType, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).hasADAlarmed(channel, alarmType, state.array);
   }

   /**
    * Extracts the A/D conversion resolution of the specified channel from the
    * provided state buffer expressed in volts.  The state is retrieved from
    * the <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                 <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state current state of the device
    *               returned from <CODE>readDevice()</CODE>
    *
    * @return A/D resolution of channel in volts
    */
   public double getADResolution(int channel, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getADResolution(channel, state.array);
   }

   /**
    * Extracts the A/D input voltage range of the specified channel from the
    * provided state buffer.  The state buffer is retrieved from the
    * <CODE>readDevice()</CODE> method.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param state current state of the device
    *                  returned from <CODE>readDevice()</CODE>
    *
    * @return A/D input voltage range
    */
   public double getADRange(int channel, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getADRange(channel, state.array);
   }

   /**
    * Sets the A/D alarm voltage value of the specified channel in the
    * provided state buffer.  The state buffer is retrieved from the
    * <CODE>readDevice()</CODE> method. The method <CODE>writeDevice()</CODE>
    * must be called to finalize these changes to the device.  Note that
    * multiple 'set' methods can be called before one call to
    * <CODE>writeDevice()</CODE>.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param alarm A/D alarm value (will be reduced to 8 bit resolution)
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws OneWireException Device does not support A/D alarms
    */
   public void setADAlarm(int channel, int alarmType, double alarm, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).setADAlarm(channel, alarmType, alarm, state.array);
   }

   /**
    * Sets the A/D alarm enable value of the specified channel in the
    * provided state buffer.  The state buffer is retrieved from the
    * <CODE>readDevice()</CODE> method. The method <CODE>writeDevice()</CODE>
    * must be called to finalize these changes to the device.  Note that
    * multiple 'set' methods can be called before one call to
    * <CODE>writeDevice()</CODE>.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param alarmType desired alarm, <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param alarmEnable A/D alarm enable value
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    *
    * @throws OneWireException Device does not support A/D alarms
    */
   public void setADAlarmEnable(int channel, int alarmType, boolean alarmEnable, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).setADAlarmEnable(channel, alarmType, alarmEnable, state.array);
   }

   /**
    * Sets the A/D conversion resolution value for the specified channel in the
    * provided state buffer.  The state buffer is retrieved from the
    * <CODE>readDevice()</CODE> method.
    * The method <CODE>writeDevice()</CODE> must be called to finalize these
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <CODE>writeDevice()</CODE>.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param resolution A/D resolution in volts
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    */
   public void setADResolution(int channel, double resolution, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).setADResolution(channel, resolution, state.array);
   }

   /**
    * Sets the A/D input range for the specified channel in the provided state
    * buffer.  The state buffer is retrieved from the <CODE>readDevice()</CODE>
    * method. The method <CODE>writeDevice()</CODE> must be called to finalize
    * these changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <CODE>writeDevice()</CODE>.
    *
    * @param channel channel in the range
    *                  <CODE>[0 to (getNumberChannels() - 1)]</CODE>
    * @param range max A/D volt range, use
    *                <CODE>getRanges()</CODE> method to get available ranges
    * @param state current state of the
    *               device returned from <CODE>readDevice()</CODE>
    */
   public void setADRange(int channel, double range, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).setADRange(channel, range, state.array);
   }

   /**
    * Queries to see if this temperature measuring device has high/low
    * trip alarms.
    *
    * @return <CODE>true</CODE> if has high/low temperature trip alarms
    */
   public boolean hasTemperatureAlarms()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).hasTemperatureAlarms();
   }

   /**
    * Queries to see if this device has selectable temperature resolution.
    *
    * @return <CODE>true</CODE> if has selectable temperature resolution
    */
   public boolean hasSelectableTemperatureResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).hasSelectableTemperatureResolution();
   }

   /**
    * Queries to get an array of available temperature resolutions in
    * degrees C.
    *
    * @return available temperature resolutions in degrees C
    */
   public DoubleArray getTemperatureResolutions()
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getTemperatureResolutions());
   }

   /**
    * Queries to get the high/low temperature alarm resolution in degrees C.
    *
    * @return high/low temperature alarm resolution in degrees C
    *
    * @throws OneWireException Device does not support temperature alarms
    */
   public double getTemperatureAlarmResolution()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getTemperatureAlarmResolution();
   }

   /**
    * Queries to get the maximum temperature in degrees C.
    *
    * @return maximum temperature in degrees C
    */
   public double getMaxTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getMaxTemperature();
   }

   /**
    * Queries to get the minimum temperature in degrees C.
    *
    * @return minimum temperature in degrees C
    */
   public double getMinTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getMinTemperature();
   }

   /**
    * Performs a temperature conversion.
    *
    * @param state device state
    *
    * @throws OneWireIOException Error writting data
    * @throws OneWireException Could not find device
    */
   public void doTemperatureConvert(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).doTemperatureConvert(state.array);
   }

   /**
    * Extracts the temperature value in degrees C from the
    * state data retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param state device state
    *
    * @return temperature in degrees C from the last
    * <CODE>doTemperatureConvert()</CODE>
    */
   public double getTemperature(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getTemperature(state.array);
   }

   /**
    * Extracts the specified temperature alarm value in degrees C from the
    * state data retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param alarmType trip type <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param state device state
    *
    * @return alarm trip temperature in degrees C
    *
    * @throws OneWireException Device does not support temerature alarms
    */
   public double getTemperatureAlarm(int alarmType, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getTemperatureAlarm(alarmType, state.array);
   }

   /**
    * Extracts the current temperature resolution in degrees C from the
    * state data retrieved from the <CODE>readDevice()</CODE> method.
    *
    * @param state device state
    *
    * @return temperature resolution in degrees C
    */
   public double getTemperatureResolution(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).getTemperatureResolution(state.array);
   }

   /**
    * Sets the temperature alarm value in degrees C in the
    * provided state data.  Use the method <CODE>writeDevice()</CODE> with
    * this data to finalize the change to the device.
    *
    * @param alarmType trip type <CODE>ALARM_HIGH (1)
    *               or ALARM_LOW (0)</CODE>
    * @param alarmValue high/low temperature trip value in degrees C
    * @param state device state
    *
    * @throws OneWireIOException Error writting data
    * @throws OneWireException Device does not support temperature alarms
    */
   public void setTemperatureAlarm(int alarmType, double alarmValue, ByteArray state)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).setTemperatureAlarm(alarmType, alarmValue, state.array);
   }

   /**
    * Sets the current temperature resolution in degrees C in the provided state data.
    * Use the method <CODE>writeDevice()</CODE> with this data to finalize
    * the change to the device.
    *
    * @param resolution temperature resolution in degrees C
    * @param state device state
    *
    * @throws OneWireIOException Error writting data
    * @throws OneWireException Could not find device
    */
   public void setTemperatureResolution(double resolution, ByteArray state)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).setTemperatureResolution(resolution, state.array);
   }

   /**
    * Retrieves the 1-Wire device sensor state.  This state is
    * returned as a byte array.  Pass this byte array to the static query
    * and set methods.  If the device state needs to be changed then call
    * the <CODE>writeDevice()</CODE> to finalize the one or more change.  With the
    * DS2760, there are no CRC checks on data.  To ensure the integrity
    * of this data, call twice and make sure only fields expected to change
    * have changed.  This method returns bytes 0 to 31 of the memory.
    * Many applications will not need to worry about the lack of CRC checks.
    *
    * @return 1-Wire device state
    *
    * @throws OneWireIOException Error reading data
    * @throws OneWireException Could not find device
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).readDevice());
   }

   /**
    * Writes the 1-Wire device sensor state that have been changed by the
    * 'set' methods.  It knows which registers have changed by looking at
    * the bitmap fields appended to the state data.
    *
    * @param  state device state
    *
    * @throws OneWireIOException Error writting data
    * @throws OneWireException Could not find device
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer30)objectInstance).writeDevice(state.array);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer30)o;
      return this;
   }
}
