// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire&#174 container for a 32K bytes of read-only and read/write password
 * protected memory, DS1977.  This container encapsulates the functionality
 * of the 1-Wire family type <B>37</B> (hex).
 * </P>
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> 32K bytes EEPROM organized as pages of 64 bytes.
 *   <LI> 512-bit scratchpad ensures integrity of data transfer
 *   <LI> On-chip 16-bit CRC generator
 * </UL>
 *
 * <H3> Memory </H3>
 *
 * <P> The memory can be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 *
 * The following is a list of the MemoryBank instances that are returned:
 *
 * <UL>
 *   <LI> <B> Scratchpad with CRC and Password support </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 64 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write not-general-purpose volatile
 *         <LI> <I> Pages</I> 1 page of length 64 bytes
 *         <LI> <I> Page Features </I> page-device-CRC
 *         <li> <i> Extra information for each page</i>  Target address, offset, length 3
 *         <LI> <i> Supports Copy Scratchpad With Password command </I>
 *      </UL>
 *   <LI> <B> Main Memory </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32704 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 511 pages of length 64 bytes giving 61 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC
 *         <LI> <I> Read-Only and Read/Write password </I> if enabled, passwords are required for
 *                  reading from and writing to the device.
 *      </UL>
 *   <LI> <B> Register control </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 64 starting at physical address 32704
 *         <LI> <I> Features</I> Read/Write not-general-purpose non-volatile
 *         <LI> <I> Pages</I> 1 pages of length 64 bytes
 *         <LI> <I> Page Features </I> page-device-CRC
 *         <LI> <I> Read-Only and Read/Write password </I> if enabled, passwords are required for
 *                  reading from and writing to the device.
 *      </UL>
 * </UL>
 *
 * For examples regarding memory operations,
 * <uL>
 * <li> See the usage example in
 * {@link OneWireContainer OneWireContainer}
 * to enumerate the MemoryBanks.
 * <li> See the usage examples in
 * {@link MemoryBank MemoryBank} and
 * {@link PagedMemoryBank PagedMemoryBank}
 * for bank specific operations.
 * </uL>
 *
 * @see PasswordContainer
 *
 * @version CLSID=4854257B-80D8-4DE5-A6A5-E39D195F6FBC -     1.00, 18 Aug 2003
 * @author     jevans
 *
 * @com.register ( clsid=4854257B-80D8-4DE5-A6A5-E39D195F6FBC, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer37
   extends OneWireContainer
   implements com.ms.com.IUnknown, PasswordContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer37 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer37()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer37());
   }

   OneWireContainer37(com.dalsemi.onewire.container.OneWireContainer37 o)
   {
      super(o);
   }
   OneWireContainer37(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer37)o);
   }

   public static final byte WRITE_SCRATCHPAD_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer37.WRITE_SCRATCHPAD_COMMAND;

   public static final byte READ_SCRATCHPAD_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer37.READ_SCRATCHPAD_COMMAND;

   public static final byte COPY_SCRATCHPAD_PW_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer37.COPY_SCRATCHPAD_PW_COMMAND;

   public static final byte READ_MEMORY_PW_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer37.READ_MEMORY_PW_COMMAND;

   public static final byte VERIFY_PSW_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer37.VERIFY_PSW_COMMAND;

   public static final byte READ_VERSION
          = com.dalsemi.onewire.container.OneWireContainer37.READ_VERSION;

   public static final int PASSWORD_CONTROL_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer37.PASSWORD_CONTROL_REGISTER;

   public static final int READ_ACCESS_PASSWORD
          = com.dalsemi.onewire.container.OneWireContainer37.READ_ACCESS_PASSWORD;

   public static final int READ_WRITE_ACCESS_PASSWORD
          = com.dalsemi.onewire.container.OneWireContainer37.READ_WRITE_ACCESS_PASSWORD;

   public static final int READ_WRITE_PWD
          = com.dalsemi.onewire.container.OneWireContainer37.READ_WRITE_PWD;

   public static final int READ_ONLY_PWD
          = com.dalsemi.onewire.container.OneWireContainer37.READ_ONLY_PWD;

   /**
    * Directs the container to avoid the calls to doSpeed() in methods that communicate
    * with the Thermocron. To ensure that all parts can talk to the 1-Wire bus
    * at their desired speed, each method contains a call
    * to <code>doSpeed()</code>.  However, this is an expensive operation.
    * If a user manages the bus speed in an
    * application,  call this method with <code>doSpeedCheck</code>
    * as <code>false</code>.  The default behavior is
    * to call <code>doSpeed()</code>.
    *
    * @param doSpeedCheck <code>true</code> for <code>doSpeed()</code> to be called before every
    * 1-Wire bus access, <code>false</code> to skip this expensive call
    *
    * @see OneWireContainer#doSpeed()
    */
   public synchronized void setSpeedCheck(boolean doSpeedCheck)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).setSpeedCheck(doSpeedCheck);
   }

   /**
    * Retrieves the password length for the read-only password.
    *
    * @return  the read-only password length
    *
    * @throws OneWireException
    */
   public int getReadOnlyPasswordLength()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).getReadOnlyPasswordLength();
   }

   /**
    * Retrieves the password length for the read/write password.
    *
    * @return  the read/write password length
    *
    * @throws OneWireException
    */
   public int getReadWritePasswordLength()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).getReadWritePasswordLength();
   }

   /**
    * Retrieves the password length for the write-only password.
    *
    * @return  the write-only password length
    *
    * @throws OneWireException
    */
   public int getWriteOnlyPasswordLength()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).getWriteOnlyPasswordLength();
   }

   /**
    * Retrieves the address the read only password starts
    *
    * @return the address of the read only password
    */
   public int getReadOnlyPasswordAddress()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).getReadOnlyPasswordAddress();
   }

   /**
    * Retrieves the address the read/write password starts
    *
    * @return the address of the read/write password
    */
   public int getReadWritePasswordAddress()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).getReadWritePasswordAddress();
   }

   /**
    * Retrieves the address the write only password starts
    *
    * @return the address of the write only password
    */
   public int getWriteOnlyPasswordAddress()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).getWriteOnlyPasswordAddress();
   }

   /**
    * Tells whether the device has a read only password.
    *
    * @return  if the device has a read only password
    */
   public boolean hasReadOnlyPassword()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).hasReadOnlyPassword();
   }

   /**
    * Tells whether the device has a read/write password.
    *
    * @return  if the device has a read/write password
    */
   public boolean hasReadWritePassword()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).hasReadWritePassword();
   }

   /**
    * Tells whether the device has a write only password.
    *
    * @return  if the device has a write only password
    */
   public boolean hasWriteOnlyPassword()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).hasWriteOnlyPassword();
   }

   /**
    * Tells whether the read only password has been enabled.
    *
    * @return  the enabled status of the read only password
    *
    * @throws OneWireException
    */
   public boolean getDeviceReadOnlyPasswordEnable()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).getDeviceReadOnlyPasswordEnable();
   }

   /**
    * Tells whether the read/write password has been enabled.
    *
    * @return  the enabled status of the read/write password
    *
    * @throws OneWireException
    */
   public boolean getDeviceReadWritePasswordEnable()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).getDeviceReadWritePasswordEnable();
   }

   /**
    * Tells whether the write only password has been enabled.
    *
    * @return  the enabled status of the write only password
    *
    * @throws OneWireException
    */
   public boolean getDeviceWriteOnlyPasswordEnable()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).getDeviceWriteOnlyPasswordEnable();
   }

   /**
    * Returns true if this device has the capability to enable one type of password
    * while leaving another type disabled.  i.e. if the device has Read-Only password
    * protection and Write-Only password protection, this method indicates whether or
    * not you can enable Read-Only protection while leaving the Write-Only protection
    * disabled.
    *
    * @return <code>true</code> if the device has the capability to enable one type
    *         of password while leaving another type disabled.
    */
   public boolean hasSinglePasswordEnable()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).hasSinglePasswordEnable();
   }

   /**
    * <p>Enables/Disables passwords for this device.  If the part has more than one
    * type of password (Read-Only, Write-Only, or Read/Write), all passwords
    * will be enabled.  This function is equivalent to the following:
    *    <code> owc37.setDevicePasswordEnable(
    *                    owc37.hasReadOnlyPassword(),
    *                    owc37.hasReadWritePassword(),
    *                    owc37.hasWriteOnlyPassword() ); </code></p>
    *
    * <p>For this to be successful, either write-protect passwords must be disabled,
    * or the write-protect password(s) for this container must be set and must match
    * the value of the write-protect password(s) in the device's register.</P>
    *
    * <P><B>
    * WARNING: Enabling passwords requires that both the read password and the
    * read/write password be re-written to the part.  Before calling this method,
    * you should set the container read password and read/write password values.
    * This will ensure that the correct value is written into the part.
    * </B></P>
    *
    * @param enableAll if <code>true</code>, all passwords are enabled.  Otherwise,
    *        all passwords are disabled.
    */
   public void setDevicePasswordEnableAll(boolean enableAll)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).setDevicePasswordEnableAll(enableAll);
   }

   /**
    * Attempts to change the value of the read password in the device's
    * register. For this to be successful, either passwords must be disabled,
    * or the read/write password for this container must be set and must match
    * the value of the read/write password in the device's register.
    *
    * <P><B>
    * WARNING: Setting the read password requires that both the read password
    * and the read/write password be written to the part.  Before calling this
    * method, you should set the container read/write password value.
    * This will ensure that the correct value is written into the part.
    * </B></P>
    *
    * @param password the new value of 8-byte device read password, to be copied
    *        into the devices register.
    * @param offset the offset to start copying the 8 bytes from the array
    */
   public void setDeviceReadOnlyPassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).setDeviceReadOnlyPassword(password.array, offset);
   }

   /**
    * Attempts to change the value of the read/write password in the device's
    * register.  For this to be successful, either passwords must be disabled,
    * or the read/write password for this container must be set and must match
    * the current value of the read/write password in the device's register.
    *
    * @param password the new value of 8-byte device read/write password, to be
    *        copied into the devices register.
    * @param offset the offset to start copying the 8 bytes from the array
    */
   public void setDeviceReadWritePassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).setDeviceReadWritePassword(password.array, offset);
   }

   /**
    * Attempts to change the value of the write only password in the device's
    * register.  For this to be successful, either passwords must be disabled,
    * or the read/write password for this container must be set and must match
    * the current value of the read/write password in the device's register.
    *
    * @param password the new value of 8-byte device read/write password, to be
    *        copied into the devices register.
    * @param offset the offset to start copying the 8 bytes from the array
    */
   public void setDeviceWriteOnlyPassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).setDeviceWriteOnlyPassword(password.array, offset);
   }

   /**
    * <P>Enables/disables passwords by writing to the devices password control
    * register.  For this to be successful, either passwords must be disabled,
    * or the read/write password for this container must be set and must match
    * the current value of the read/write password in the device's register.</P>
    *
    * <P><B>
    * WARNING: Enabling passwords requires that both the read password and the
    * read/write password be re-written to the part.  Before calling this method,
    * you should set the container read password and read/write password values.
    * This will ensure that the correct value is written into the part.
    * </B></P>
    *
    * @param enable if <code>true</code>, device passwords will be enabled.
    *        All subsequent read and write operations will require that the
    *        passwords for the container are set.
    */
   public void setDevicePasswordEnable(boolean enableReadOnly, boolean enableReadWrite, boolean enableWriteOnly)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).setDevicePasswordEnable(enableReadOnly, enableReadWrite, enableWriteOnly);
   }

   /**
    * Sets the value of the read password for the container.  This is the value
    * used by this container to read the memory of the device.  If this password
    * does not match the value of the read password in the device's password
    * register, all subsequent read operations will fail.
    *
    * @param password New 8-byte value of container's read password.
    * @param offset Index to start copying the password from the array.
    */
   public void setContainerReadOnlyPassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).setContainerReadOnlyPassword(password.array, offset);
   }

   /**
    * Returns the read password used by this container to read the memory
    * of the device.
    *
    * @param password Holds the 8-byte value of container's read password.
    * @param offset Index to start copying the password into the array.
    */
   public void getContainerReadOnlyPassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).getContainerReadOnlyPassword(password.array, offset);
   }

   /**
    * Returns true if the container's read password has been set.  The return
    * value is not affected by whether or not the read password of the container
    * actually matches the value in the device's password register.
    *
    * @return <code>true</code> if the container's read password has been set
    */
   public boolean isContainerReadOnlyPasswordSet()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).isContainerReadOnlyPasswordSet();
   }

   /**
    * Sets the value of the read/write password for the container.  This is the
    * value used by this container to read and write to the memory of the
    * device.  If this password does not match the value of the read/write
    * password in the device's password register, all subsequent read and write
    * operations will fail.
    *
    * @param password New 8-byte value of container's read/write password.
    * @param offset Index to start copying the password from the array.
    */
   public void setContainerReadWritePassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).setContainerReadWritePassword(password.array, offset);
   }

   /**
    * Returns the read/write password used by this container to read from and
    * write to the memory of the device.
    *
    * @param password Holds the 8-byte value of container's read/write password.
    * @param offset Index to start copying the password into the array.
    */
   public void getContainerReadWritePassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).getContainerReadWritePassword(password.array, offset);
   }

   /**
    * Returns true if the container's read/write password has been set.  The
    * return value is not affected by whether or not the read/write password of
    * the container actually matches the value in the device's password
    * register.
    *
    * @return <code>true</code> if the container's read/write password has been
    *         set.
    */
   public boolean isContainerReadWritePasswordSet()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).isContainerReadWritePasswordSet();
   }

   /**
    * Sets the value of the read/write password for the container.  This is the
    * value used by this container to read and write to the memory of the
    * device.  If this password does not match the value of the read/write
    * password in the device's password register, all subsequent read and write
    * operations will fail.
    *
    * @param password New 8-byte value of container's read/write password.
    * @param offset Index to start copying the password from the array.
    */
   public void setContainerWriteOnlyPassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).setContainerWriteOnlyPassword(password.array, offset);
   }

   /**
    * Returns the read/write password used by this container to read from and
    * write to the memory of the device.
    *
    * @param password Holds the 8-byte value of container's read/write password.
    * @param offset Index to start copying the password into the array.
    */
   public void getContainerWriteOnlyPassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).getContainerWriteOnlyPassword(password.array, offset);
   }

   /**
    * Returns true if the container's read/write password has been set.  The
    * return value is not affected by whether or not the read/write password of
    * the container actually matches the value in the device's password
    * register.
    *
    * @return <code>true</code> if the container's read/write password has been
    *         set.
    */
   public boolean isContainerWriteOnlyPasswordSet()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).isContainerWriteOnlyPasswordSet();
   }

   /**
    * No documentation available for method 
    */
   public boolean verifyPassword(ByteArray password, int offset, int type)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer37)objectInstance).verifyPassword(password.array, offset, type);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer37)o;
      return this;
   }
}
