// COM proxy class, output from FunctionList.js
package owapi;
/**
 * A <code>ResponseAPDU</code> represents an Application Protocol Data Unit (APDU)
 * received from the smart card in response to a previous <code>CommandAPDU</code>.
 * A <code>ResponseAPDU</code> consists of an optional body and a mandatory
 * Status Word (SW). <BR><BR>
 *
 * According to ISO 7816-4, a <code>ResponseAPDU</code>  has the following
 * format:
 *
 * <pre>
 *          DATA   |  STATUS WORD
 *         [data]  |  SW1     SW2 </pre>
 *
 * where
 * <ul>
 * <li><code>data</code> is an optional byte array of data received from the smart card.
 * <li><code>SW1</code>  is the status byte 1 containing command processing status.
 * <li><code>SW2</code>  is the status byte 2 containing command processing qualifier.
 * </ul>
 *
 * 
 * <H3> Usage </H3> 
 * <OL>
 * <LI>
 *   <code><pre>
 *   byte[] buffer = {(byte)0x01, (byte)0x02, (byte)0x90, (byte)0x00};
 *   ResponseAPDU rapdu = new ResponseAPDU(buffer); </pre></code>
 * <LI>
 *   <code><pre>
 *   OneWireContainer16 owc16 = new OneWireContainer16(adapter, address);
 *   byte[] buffer = {(byte)0x90, (byte)0x00, (byte)0x00, (byte)0x00, 
 *                    (byte)0x01, (byte)0x02, (byte)0x03};
 *   CommandAPDU capdu = new CommandAPDU(buffer);
 *   ResponseAPDU rapdu = owc16.sendAPDU(capdu, runTime); </pre></code>
 * </OL>
 *
 * <H3> Additonal information </H3> 
 * <DL>
 * <DD><A HREF="http://www.opencard.org"> http://www.opencard.org</A>
 * </DL>
 * 
 * @see CommandAPDU
 * @see OneWireContainer16
 * 
 * @version CLSID=E7634208-5586-4162-95CD-57769B7DB83F -     0.00, 28 Aug 2000
 * @author     YL
 *
 * @com.register ( clsid=E7634208-5586-4162-95CD-57769B7DB83F, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class ResponseAPDU
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.container.ResponseAPDU objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public ResponseAPDU()
   {
   }

   ResponseAPDU(com.dalsemi.onewire.container.ResponseAPDU o)
   {
      this.objectInstance = o;
   }
   ResponseAPDU(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.container.ResponseAPDU)o);
   }

   /**
    * Constructs a new <code>ResponseAPDU</code> with the given buffer 
    * byte array. The internal <code>apduLength</code> is set to the 
    * length of the buffer passed.
    *
    * @param  buffer  the byte array with data for the internal
    *                 <code>apduBuffer</code>
    * 
    * @throws RuntimeException thrown when <code>buffer</code> length 
    *                          < <code>2</code>.
    *
    * @see    CommandAPDU
    */
   public void createNewInstance(ByteArray buffer)
   {      
      objectInstance = new com.dalsemi.onewire.container.ResponseAPDU(buffer.array);
   }

   /**
    * Gets the data field of this <code>ResponseAPDU</code>.
    *
    * @return a byte array containing this <code>ResponseAPDU</code> data field
    */
   public ByteArray getData()
   {      
      return new ByteArray().setupObject(objectInstance.getData());
   }

   /**
    * Gets the value of SW1 and SW2 as an integer.
    * It is computed as:<BR><BR>
    * <code>(((SW1 << 8) & 0xFF00) | (SW2 & 0xFF))</code><BR>
    *
    * @return    <code>(((SW1 << 8) & 0xFF00) | (SW2 & 0xFF))</code> as an integer
    */
   public final int getSW()
   {      
      return objectInstance.getSW();
   }

   /**
    * Gets the value of SW1.
    *
    * @return    value of SW1 as a byte
    */
   public final byte getSW1()
   {      
      return objectInstance.getSW1();
   }

   /**
    * Gets the value of SW2.
    *
    * @return    value of SW2 as a byte
    */
   public final byte getSW2()
   {      
      return objectInstance.getSW2();
   }

   /**
    * Gets the byte value at the specified offset in <code>apduBuffer</code>.
    *
    * @param index   the offset in the <code>apduBuffer</code>
    * @return        the value at the given offset,
    *                or <code>-1</code> if the offset is invalid
    *
    * @see #getBytes
    * @see #getLength
    */
   public final byte getByte(int index)
   {      
      return objectInstance.getByte(index);
   }

   /**
    * Gets a byte array holding this <code>ResponseAPDU</code> 
    * <code>apduBuffer</code>.
    *
    * @return  <code>apduBuffer</code> copied into a new array
    *
    * @see #getByte
    * @see #getLength
    */
   public final ByteArray getBytes()
   {      
      return new ByteArray().setupObject(objectInstance.getBytes());
   }

   /**
    * Gets the length of <code>apduBuffer</code>.
    *
    * @return  <code>apduLength</code> the length of the 
    *          <code>apduBuffer</code> currently stored
    */
   public final int getLength()
   {      
      return objectInstance.getLength();
   }

   /**
    * Gets a string representation of this <code>ResponseAPDU</code>.
    *
    * @return a string describing this <code>ResponseAPDU</code>
    */
   public java.lang.String toString()
   {      
      return objectInstance.toString();
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   ResponseAPDU setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.ResponseAPDU)o;
      return this;
   }
}
