// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>Abstract super class for all SHA Transactions.  Typical SHA transactions
 * might be something like an account debit application, a door access control
 * system, or a web-based authentication servlet.  The <code>SHATransaction</code>
 * super class contains the bare minimum functionality necessary for the steps
 * involved in most SHA transaction applications.</P>
 *
 * <P>The first characteristic of a SHA Transaction is that it is tied to an
 * immutable <code>SHAiButtonCopr</code>, used for data signing and recreating
 * user authentication responses.  The SHA Transaction guarantees an interface
 * for initializing account transaction data (<code>setupTransactionData</code>),
 * verifying that the transaction data has not been tampered with
 * (<code>verifyTransactionData</code>), performing the transaction and updating
 * the data (<code>executeTransaction</code>), and validating a user with a
 * challenge-response authentication protocol (<code>verifyUser</code>).</P>
 *
 * <P>In addition, all transactions are characterized by certain parameters (i.e.
 * how much to debit from the user or what level of access is being requested
 * from the system).  The interface for retrieving and setting these parameters is
 * provided through the generic <code>getParameter</code> and
 * <code>setParameter</code>.</P>
 *
 * @see SHADebit
 * @see SHADebitUnsigned
 *
 * @version CLSID=91435CC5-B687-4DAE-9A3A-9E645455F306 -  1.00
 * @author  SKH
 * @com.register ( clsid=91435CC5-B687-4DAE-9A3A-9E645455F306, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class SHATransaction
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.application.sha.SHATransaction objectInstance  = null;

   /**
    * Default constructor. Does nothing.
    */
   public SHATransaction()
   {
   }

   SHATransaction(com.dalsemi.onewire.application.sha.SHATransaction o)
   {
      this.objectInstance = o;
   }
   SHATransaction(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.application.sha.SHATransaction)o);
   }

   public static final int NO_ERROR
          = com.dalsemi.onewire.application.sha.SHATransaction.NO_ERROR;

   public static final int SHA_FUNCTION_FAILED
          = com.dalsemi.onewire.application.sha.SHATransaction.SHA_FUNCTION_FAILED;

   public static final int MATCH_SCRATCHPAD_FAILED
          = com.dalsemi.onewire.application.sha.SHATransaction.MATCH_SCRATCHPAD_FAILED;

   public static final int COPR_WRITE_DATAPAGE_FAILED
          = com.dalsemi.onewire.application.sha.SHATransaction.COPR_WRITE_DATAPAGE_FAILED;

   public static final int COPR_WRITE_SCRATCHPAD_FAILED
          = com.dalsemi.onewire.application.sha.SHATransaction.COPR_WRITE_SCRATCHPAD_FAILED;

   public static final int COPR_BIND_SECRET_FAILED
          = com.dalsemi.onewire.application.sha.SHATransaction.COPR_BIND_SECRET_FAILED;

   public static final int COPR_COMPUTE_CHALLENGE_FAILED
          = com.dalsemi.onewire.application.sha.SHATransaction.COPR_COMPUTE_CHALLENGE_FAILED;

   public static final int COPROCESSOR_FAILURE
          = com.dalsemi.onewire.application.sha.SHATransaction.COPROCESSOR_FAILURE;

   public static final int USER_READ_AUTH_FAILED
          = com.dalsemi.onewire.application.sha.SHATransaction.USER_READ_AUTH_FAILED;

   public static final int USER_WRITE_DATA_FAILED
          = com.dalsemi.onewire.application.sha.SHATransaction.USER_WRITE_DATA_FAILED;

   public static final int USER_BAD_ACCOUNT_DATA
          = com.dalsemi.onewire.application.sha.SHATransaction.USER_BAD_ACCOUNT_DATA;

   public static final int USER_DATA_NOT_UPDATED
          = com.dalsemi.onewire.application.sha.SHATransaction.USER_DATA_NOT_UPDATED;

   /**
    * <P>Returns the error code for the last error in the transaction
    * process.</P>
    */
   public int getLastError()
   {      
      return objectInstance.getLastError();
   }

   /**
    * <P>Returns the error code for the last error in the transaction
    * process.</P>
    */
   public int getLastCoprError()
   {      
      return objectInstance.getLastCoprError();
   }

   /**
    * <P>Setups initial transaction data on SHAiButtonUser.  This step
    * creates the account data file, signs it with the coprocessor,
    * and writes it to the iButton.</P>
    */
   public boolean setupTransactionData(SHAiButtonUser user)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.setupTransactionData(((com.dalsemi.onewire.application.sha.SHAiButtonUser)user.objectInstance));
   }

   /**
    * <P>Verifies that SHAiButtonUser is a valid user of this service.
    * This step writes a three byte challenge to the SHAiButtonUser
    * before doing an authenticated read of the account data.  The
    * returned MAC is verified using the system authentication secret
    * on the coprocessor.  If the MAC matches that generated by the
    * coprocessor, this function returns true.</P>
    */
   public boolean verifyUser(SHAiButtonUser user)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.verifyUser(((com.dalsemi.onewire.application.sha.SHAiButtonUser)user.objectInstance));
   }

   /**
    * <P>Verifies account data is valid for this service.  The user's
    * account data is recreated on the coprocessor and signed using
    * the system signing secret.  If the recreated signature matches
    * the signature in the account data, the account data is valid.</P>
    */
   public boolean verifyTransactionData(SHAiButtonUser user)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.verifyTransactionData(((com.dalsemi.onewire.application.sha.SHAiButtonUser)user.objectInstance));
   }

   /**
    * <P>Performs the transaction.  For any given transaction type,
    * this step would involve updating any necessary account data,
    * signing the account data using the coprocessor's system signing
    * secret, and writing the updated account data to the user
    * iButton</P>
    */
   public boolean executeTransaction(SHAiButtonUser user, boolean verifySuccess)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.executeTransaction(((com.dalsemi.onewire.application.sha.SHAiButtonUser)user.objectInstance), verifySuccess);
   }

   /**
    * <P>Sets a particular parameter for this transaction.  Parameters
    * are specified in the class documentation for the specific type of
    * transaction that is being peformed.</P>
    */
   public boolean setParameter(int type, int param)
   {      
      return objectInstance.setParameter(type, param);
   }

   /**
    * <P>Retrieves the value of a particular parameter for this
    * transaction.  Parameters are specified in the class documentation
    * for the specific type of transaction that is being peformed.</P>
    */
   public int getParameter(int type)
   {      
      return objectInstance.getParameter(type);
   }

   /**
    * <P>Resets the value of all parameters for this transaction.
    * Parameters are specified in the class documentation for the
    * specific type of transaction that is being peformed.</P>
    */
   public void resetParameters()
   {      
      objectInstance.resetParameters();
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   SHATransaction setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.application.sha.SHATransaction)o;
      return this;
   }
}
