// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>Class for simulating an instance of a SHA iButton Coprocessor involved
 * in SHA Transactions.  The Coprocessor is used for digitally signing transaction
 * data as well as generating random challenges for users and verifying
 * their response.</P>
 *
 * <p>With this class, no DS1963S SHA iButton is necessary for the coprocessor in
 * SHA Transactions.  The simulated Coprocessor iButton verifies signatures
 * and signs data for User iButtons.</P>
 *
 * <p>This class makes use of several performance enhancements for TINI.
 * For instance, most methods are <code>synchronized</code> to access instance variable
 * byte arrays rather than creating new byte arrays every time a transaction
 * is performed.  This could hurt performance in multi-threaded
 * applications, but the usefulness of having several threads contending
 * to talk to a single iButton is questionable since the methods in
 * <code>DSPortAdapter</code>
 * <code>beginExclusive(boolean)</code> and <code>endExclusive()</code> should be used.</p>
 *
 * @see SHATransaction
 * @see SHAiButtonUser
 * @see SHAiButtonCopr
 *
 * @version CLSID=AFDB0D37-D471-4597-B17F-D28D2D42356B -  1.00
 * @author  SKH
 * @com.register ( clsid=AFDB0D37-D471-4597-B17F-D28D2D42356B, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class SHAiButtonCoprVM
   extends SHAiButtonCopr
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: SHAiButtonCopr
   //com.dalsemi.onewire.application.sha.SHAiButtonCoprVM objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public SHAiButtonCoprVM()
   {
   }

   SHAiButtonCoprVM(com.dalsemi.onewire.application.sha.SHAiButtonCoprVM o)
   {
      super(o);
   }
   SHAiButtonCoprVM(java.lang.Object o)
   {
      super((com.dalsemi.onewire.application.sha.SHAiButtonCoprVM)o);
   }

   /**
    * <P>Sets up this simulated coprocessor based on the provided parameters.
    * Then, the system secret and authentication secret are installed on the
    * simulated coprocessor iButton.</P>
    *
    * <P>For the proper format of the coprocessor data file, see the
    * document entitled "Implementing Secured D-Identification and E-Payment
    * Applications using SHA iButtons".  For the format of TMEX file
    * structures, see Application Note 114.</P>
    *
    * @param RomID The address for the simulated coprocessor.
    * @param l_signPageNumber page number used for signing user account data.
    *        (Should be page 8, but page 0 is acceptable if you don't need
    *        the TMEX directory structure)
    * @param l_authPageNumber page number used for recreating user secret.
    * @param l_wspcPageNumber page number used for storing user secret and
    *        recreating authentication MAC.
    * @param l_version version of the service provided by this coprocessor.
    * @param l_encCode refers to a type of encryption used for user account
    *        data stored on user buttons.
    * @param l_serviceFileExt the file extension used for the service file.
    *        (An extension of decimal 102 is reserved for Money files).
    * @param l_serviceFilename the 4-byte name of the user's account data
    *        file.
    * @param l_providerName the name of the provider of this service
    * @param l_bindData the binding data used to finalize secret installation
    *        on user buttons.
    * @param l_bindCode the binding code used to finalize secret installation
    *        on user buttons.
    * @param l_auxData any auxilliary or miscellaneous data to be stored on
    *        the coprocessor.
    * @param l_initialSignature the 20-byte initial MAC placed in user account
    *        data before generating actual MAC.
    * @param l_signingChlg the 3-byte challenge used for signing user
    *        account data.
    * @param l_signingSecret the system signing secret used by the
    *        service being installed on this coprocessor.
    * @param l_authSecret the system authentication secret used by the
    *        service being installed on this coprocessor.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonCoprVM(String)
    * @see #SHAiButtonCoprVM(String,byte[],byte[])
    * @see #SHAiButtonCoprVM(OneWireContainer,String)
    * @see #SHAiButtonCoprVM(OneWireContainer,String,byte[],byte[])
    * @see #SHAiButtonCoprVM(OneWireContainer18,String,byte[],byte[])
    */
   public void createNewInstanceFromContainer(ByteArray RomID, int l_signPageNumber, int l_authPageNumber, int l_wspcPageNumber, int l_version, int l_encCode, byte l_serviceFileExt, ByteArray l_serviceFilename, ByteArray l_providerName, ByteArray l_bindData, ByteArray l_signPageNumber0, ByteArray l_signPageNumber1, ByteArray l_signPageNumber2, ByteArray l_signPageNumber3, ByteArray l_signPageNumber4, ByteArray l_signPageNumber5)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonCoprVM(RomID.array, l_signPageNumber, l_authPageNumber, l_wspcPageNumber, l_version, l_encCode, l_serviceFileExt, l_serviceFilename.array, l_providerName.array, l_bindData.array, l_signPageNumber0.array, l_signPageNumber1.array, l_signPageNumber2.array, l_signPageNumber3.array, l_signPageNumber4.array, l_signPageNumber5.array);
   }

   /**
    * <p>Loads a simulated DS1963S coprocessor device from disk.  The given
    * file name is loaded to get all the parameters of the coprocessor.
    * It is assumed that the secrets were stored in the file when
    * the simulated coprocessor's data was saved to disk.</p>
    *
    * @param filename The filename of the simulated coprocessor's data file ("shaCopr.dat")
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonCoprVM(String,byte[],byte[])
    * @see #SHAiButtonCoprVM(OneWireContainer,String)
    * @see #SHAiButtonCoprVM(OneWireContainer,String,byte[],byte[])
    * @see #SHAiButtonCoprVM(OneWireContainer18,String,byte[],byte[])
    * @see #SHAiButtonCoprVM(byte[],int,int,int,int,int,byte,byte[],byte[],byte[],byte[],byte[],byte[],byte[],byte[],byte[])
    *
    */
   public void createNewInstanceFromContainer(java.lang.String filename)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonCoprVM(filename);
   }

   /**
    * <p>Loads a simulated DS1963S coprocessor device from disk.  The given
    * file name is loaded to get all the parameters of the coprocessor.
    * After it is loaded, the given secrets are installed.</p>
    *
    * @param filename The filename of the simulated coprocessor's data file ("shaCopr.dat")
    * @param sign_secret The system data signing secret.
    * @param auth_secret The system device authentication secret.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonCoprVM(String)
    * @see #SHAiButtonCoprVM(OneWireContainer,String)
    * @see #SHAiButtonCoprVM(OneWireContainer,String,byte[],byte[])
    * @see #SHAiButtonCoprVM(OneWireContainer18,String,byte[],byte[])
    * @see #SHAiButtonCoprVM(byte[],int,int,int,int,int,byte,byte[],byte[],byte[],byte[],byte[],byte[],byte[],byte[],byte[])
    */
   public void createNewInstanceFromContainer(java.lang.String filename, ByteArray sign_secret, ByteArray auth_secret)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonCoprVM(filename, sign_secret.array, auth_secret.array);
   }

   /**
    * <p>Loads a simulated DS1963S coprocessor device from any 1-Wire memory device
    * supported by the 1-Wire File I/O API.  The given file name is loaded to get
    * all the parameters of the coprocessor.  It is assumed that the secrets were
    * stored in the file when the simulated coprocessor's data was saved to disk.</p>
    *
    * @param owc 1-Wire memory device with valid TMEX file system
    * @param filename The filename of the simulated coprocessor's data file ("shaCopr.dat")
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonCoprVM(String)
    * @see #SHAiButtonCoprVM(String,byte[],byte[])
    * @see #SHAiButtonCoprVM(OneWireContainer,String,byte[],byte[])
    * @see #SHAiButtonCoprVM(OneWireContainer18,String,byte[],byte[])
    * @see #SHAiButtonCoprVM(byte[],int,int,int,int,int,byte,byte[],byte[],byte[],byte[],byte[],byte[],byte[],byte[],byte[])
    */
   public void createNewInstanceFromContainer(OneWireContainer owc, java.lang.String filename)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonCoprVM(((com.dalsemi.onewire.container.OneWireContainer)owc.objectInstance), filename);
   }

   /**
    * <p>Loads a simulated DS1963S coprocessor device from any 1-Wire
    * memory device supported by the 1-Wire File I/O API.  The given
    * file name is loaded to get all the parameters of the coprocessor.
    * After it is loaded, the given secrets are installed.</p>
    *
    * @param owc 1-Wire memory device with valid TMEX file system
    * @param filename The filename of the simulated coprocessor's data file ("shaCopr.dat")
    * @param sign_secret The system data signing secret.
    * @param auth_secret The system device authentication secret.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonCoprVM(String)
    * @see #SHAiButtonCoprVM(String,byte[],byte[])
    * @see #SHAiButtonCoprVM(OneWireContainer,String)
    * @see #SHAiButtonCoprVM(OneWireContainer18,String,byte[],byte[])
    * @see #SHAiButtonCoprVM(byte[],int,int,int,int,int,byte,byte[],byte[],byte[],byte[],byte[],byte[],byte[],byte[],byte[])
    */
   public void createNewInstanceFromContainer(OneWireContainer owc, java.lang.String filename, ByteArray sign_secret, ByteArray auth_secret)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonCoprVM(((com.dalsemi.onewire.container.OneWireContainer)owc.objectInstance), filename, sign_secret.array, auth_secret.array);
   }

   /**
    * <p>Simulates a specific DS1963S coprocessor device.  First, the given
    * TMEX file name is loaded of the container to get all the parameters of
    * the coprocessor.  Then (since secrets are not readable off the iButton,
    * they must be provided) the secrets are installed on the virtual
    * coprocessor.</p>
    *
    * @param owc The coprocessor button this VM will simulate.
    * @param filename The TMEX filename of the coprocessor service file ("COPR.0")
    * @param sign_secret The system data signing secret.
    * @param auth_secret The system device authentication secret.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonCoprVM(String)
    * @see #SHAiButtonCoprVM(String,byte[],byte[])
    * @see #SHAiButtonCoprVM(OneWireContainer,String)
    * @see #SHAiButtonCoprVM(OneWireContainer,String,byte[],byte[])
    * @see #SHAiButtonCoprVM(byte[],int,int,int,int,int,byte,byte[],byte[],byte[],byte[],byte[],byte[],byte[],byte[],byte[])
    */
   public void createNewInstance(OneWireContainer18 owc, java.lang.String filename, ByteArray sign_secret, ByteArray auth_secret)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonCoprVM(((com.dalsemi.onewire.container.OneWireContainer18)owc.objectInstance), filename, sign_secret.array, auth_secret.array);
   }

   /**
    * <p>Saves simulated coprocessor configuration info to an (almost)
    * standard-format to a hard drive file.</p>
    *
    * @param filename The filename of the simulated coprocessor's data
    *        file ("shaCopr.dat")
    * @param saveSecretData If <code>true</true>, the raw secret information
    *        is also written to the file
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @return <code>true</code> if the info was successfully saved
    */
   public boolean save(java.lang.String filename, boolean saveSecretData)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonCoprVM)objectInstance).save(filename, saveSecretData);
   }

   /**
    * <p>Saves simulated coprocessor configuration info to an (almost)
    * standard-format to a 1-Wire Memory Device's TMEX file.</p>
    *
    * @param owc 1-Wire Memory Device with valid TMEX file structure.
    * @param filename The TMEX filename of the simulated coprocessor's data
    *        file ("COPR.2")
    * @param saveSecretData If <code>true</true>, the raw secret information
    *        is also written to the file.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @return <code>true</code> if the info was successfully saved
    */
   public boolean save(OneWireContainer owc, java.lang.String filename, boolean saveSecretData)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonCoprVM)objectInstance).save(((com.dalsemi.onewire.container.OneWireContainer)owc.objectInstance), filename, saveSecretData);
   }

   /**
    * <p>Loads coprocessor configuration information from an (almost) standard
    * service file on hard drive. If secret information was saved, this routine
    * automatically loads it.</P>
    *
    * @param filename The filename of the simulated coprocessor's data
    *        file ("shaCopr.dat")
    *
    * @return <code>true</code> if the info was successfully loaded
    */
   public boolean loadFromContainer(java.lang.String filename)
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonCoprVM)objectInstance).load(filename);
   }

   /**
    * <p>Loads coprocessor configuration information from an (almost) standard
    * service TMEX file on 1-Wire memory device. If secret information was saved,
    * this routine automatically loads it.</P>
    *
    * @param owc 1-Wire memory device with valid TMEX file structure
    * @param filename The TMEX filename of the simulated coprocessor's data
    *        file ("COPR.2")
    *
    * @return <code>true</code> if the info was successfully loaded
    */
   public boolean loadFromContainer(OneWireContainer owc, java.lang.String filename)
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonCoprVM)objectInstance).load(((com.dalsemi.onewire.container.OneWireContainer)owc.objectInstance), filename);
   }

   /**
    * <p>Loads coprocessor configuration information from a standard TMEX
    * service file on a DS1963S.</P>
    *
    * @param owc DS1963S set up as a valid coprocessor
    * @param filename The TMEX filename of the coprocessor's data
    *        file ("COPR.0")
    *
    * @return <code>true</code> if the info was successfully loaded
    */
   public boolean load(OneWireContainer18 owc, java.lang.String filename)
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonCoprVM)objectInstance).load(((com.dalsemi.onewire.container.OneWireContainer18)owc.objectInstance), filename);
   }

   /**
    * <p>Binds an installed secret to this virtual DS1963S by using
    * well-known binding data and this DS1963S's (unique?)
    * address.  This makes the secret unique
    * for this iButton.  Coprocessor iButtons use this method
    * to recreate the iButton's secret to verify authentication.
    * Roving iButtons use this method to finalize their secret keys.</p>
    *
    * <p>Note that unlike in the <code>installMasterSecret()</code> method,
    * the page number does not need to be equivalent to the <code>secret_number</code>
    * modulo 8.  The new secret (installed secret + binding code) is generated
    * from this page but can be copied into another secret.  User iButtons should
    * bind to the same page the secret was installed on.  Coprocessor iButtons
    * must copy to a new secret to preserve the general system authentication
    * secret.</p>
    *
    * <p>The binding should be either 7 bytes long or 15 bytes long.
    * A 15-length <code>byte</code> array is unaltered and placed in the scratchpad
    * for the binding.  A 7-length <code>byte</code> array is combined with the page
    * number and DS1963S unique address and then placed in the scratchpad.
    * Coprocessors should use a pre-formatted 15-length <code>byte</code> array.
    * User iButtons should let the method format for them (i.e.
    * use the 7-length <code>byte</code> array option).</p>
    *
    * @param page the page number that has the master secret already installed
    * @param bind_data 32 bytes of binding data used to bind the iButton to the system
    * @param bind_code the 7-byte or 15-byte binding code
    * @param secret_number secret number to copy the resulting secret to
    *
    * @return <code>true</code> if successful
    *
    * @see #installMasterSecret(int,byte[],int)
    */
   public synchronized boolean bindSecretToiButton(int pageNum, ByteArray bindData, ByteArray bindCode, int secretNum)
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonCoprVM)objectInstance).bindSecretToiButton(pageNum, bindData.array, bindCode.array, secretNum);
   }

   /**
    * <p>Installs a secret on this virtual DS1963S.  The secret is written in partial phrases
    * of 47 bytes (32 bytes to a memory page, 15 bytes to the scratchpad) and
    * is cumulative until the entire secret is processed.  Secrets are associated
    * with a page number.  See the datasheet for more information on this
    * association.</p>
    *
    * <p>In most cases, <code>page</code> should be equal to <code>secret_number</code>
    * or <code>secret_number+8</code>, based on the association of secrets and page numbers.
    * A secret is 8 bytes and there are 8 secrets.  These 8 secrets are associated with the
    * first 16 pages of memory.</p>
    *
    * <p>On TINI, this method will be slightly faster if the secret's length is divisible by 47.
    * However, since secret key generation is a part of initialization, it is probably
    * not necessary.</p>
    *
    * @param page the page number used to write the partial secrets to
    * @param secret the entire secret to be installed
    * @param secret_number the secret 'page' to use (0 - 7)
    *
    * @return <code>true</code> if successful
    *
    * @see #bindSecretToiButton(int,byte[],byte[],int)
    */
   public boolean installMasterSecret(int pageNum, ByteArray secret, int secretNum)
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonCoprVM)objectInstance).installMasterSecret(pageNum, secret.array, secretNum);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   SHAiButtonCopr setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.application.sha.SHAiButtonCoprVM)o;
      return this;
   }
}
