// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>The abstract superclass for all users of a SHAiButton transaction system.
 * The user in a SHA transaction system mainly consists of a page (or pages) of
 * account data.  The abstract superclass guarantees an interface for retrieving
 * information about account data, as well as reading and writing that data.<P>
 *
 * <P><code>SHAiButtonUser</code> was defined for use with the DS1963S (family
 * code 0x18) and the DS1961S (family code 0x33).  The benefit to using our SHA
 * iButtons in a transaction is for device authentication.  Using a
 * challenge-response protocol, the DS1961S and the DS1963S can authenticate
 * themselves to the system before their actual account data is verified.  But,
 * if device authentication isn't important to your transaction, the
 * <code>SHAiButtonUser</code> can be extended to support any 1-Wire memory
 * device.</P>
 *
 * <P>The format of user's account data is not specified by this class, only
 * the interface for accessing it.  Each different SHATransaction is free to
 * implement whatever format is appropriate for the transaction type.</P>
 *
 * @see SHATransaction
 * @see SHAiButtonCopr
 * @see SHAiButtonUser18
 * @see SHAiButtonUser33
 *
 * @version CLSID=5CE2324F-5BC4-47F1-91E8-DADADF0B46AF -  1.00
 * @author  SKH
 * @com.register ( clsid=5CE2324F-5BC4-47F1-91E8-DADADF0B46AF, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class SHAiButtonUser
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.application.sha.SHAiButtonUser objectInstance  = null;

   /**
    * Default constructor. Does nothing.
    */
   public SHAiButtonUser()
   {
   }

   SHAiButtonUser(com.dalsemi.onewire.application.sha.SHAiButtonUser o)
   {
      this.objectInstance = o;
   }
   SHAiButtonUser(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.application.sha.SHAiButtonUser)o);
   }

   /**
    * <P>Returns the page number of the first memory page where account
    * data is stored.</P>
    *
    * @return page number where account data is stored.
    */
   public int getAccountPageNumber()
   {      
      return objectInstance.getAccountPageNumber();
   }

   /**
    * <P>Returns the TMEX filename of the user's account data file.</P>
    *
    * @return filename of user's account data file
    */
   public java.lang.String getAccountFilename()
   {      
      return objectInstance.getAccountFilename();
   }

   /**
    *<P>Returns the 8 byte address of the OneWireContainer this
    * SHAiButton refers to.</P>
    *
    * @return 8 byte array containing family code, address, and
    *         crc8 of the OneWire device.
    */
   public ByteArray getAddress()
   {      
      return new ByteArray().setupObject(objectInstance.getAddress());
   }

   /**
    * <P>Copies the 8 byte address of the OneWireContainer into
    * the provided array starting at the given offset.</P>
    *
    * @param data array with at least 8 bytes after offset
    * @param offset the index at which copying starts
    */
   public void getAddress(ByteArray data, int offset)
   {      
      objectInstance.getAddress(data.array, offset);
   }

   /**
    * <P>Copies the specified number of bytes from the address
    * of the OneWireContainer into the provided array starting
    * at the given offset.</P>
    *
    * @param data array with at least cnt bytes after offset
    * @param offset the index at which copying starts
    * @param cnt the number of bytes to copy
    */
   public void getAddress(ByteArray data, int offset, int cnt)
   {      
      objectInstance.getAddress(data.array, offset, cnt);
   }

   /**
    * Sets whether or not the container should be forced into
    * overdrive.
    *
    * @param value if true, the container will be forced to overdrive
    */
   public void setForceOverdrive(boolean value)
   {      
      objectInstance.setForceOverdrive(value);
   }

   /**
    * Reports whether or not the container is forced into
    * overdrive.
    *
    * @return if true, the container will be forced to overdrive
    */
   public boolean getForceOverdrive()
   {      
      return objectInstance.getForceOverdrive();
   }

   /**
    * <P>Modifies this SHA iButton so that it refers to another device.
    * If this object already has an appropriate instance of OneWireContainer,
    * that instance is updated with the new address.</P>
    *
    * @param adapter The adapter that the device can be found on.
    * @param address The address of the 1-Wire device
    *
    * @return <code>true</code> if a valid account service file exists on
    *         this <code>OneWireContainer18</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public boolean setiButtonUser(DSPortAdapter adapter, ByteArray address)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.setiButtonUser(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), address.array);
   }

   /**
    * <P>Modifies this SHA iButton so that it refers to another device.
    * If this object already has an appropriate instance of OneWireContainer,
    * that instance is updated with the new address.</P>
    *
    * @param adapter The adapter that the device can be found on.
    * @param address The address of the 1-Wire device
    *
    * @return <code>true</code> if a valid account service file exists on
    *         this <code>OneWireContainer18</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public boolean setiButtonUser(ByteArray adapter)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.setiButtonUser(adapter.array);
   }

   /**
    * <P>Returns the value of the write cycle counter for the
    * page where the account data is stored.  If the write
    * cycle counter has ever been retrieved, this returns the
    * cached value.  Otherwise, this method reads the value
    * from the part.</P>
    *
    * <P>For devices that do not support write cycle counters,
    * this method always returns -1.</P>
    *
    * @return the value of the write cycle counter for the
    *         account data page.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public int getWriteCycleCounter()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.getWriteCycleCounter();
   }

   /**
    * <P>Returns <code>true</code> if this buttons account data is stored
    * on a page that has a write cycle counter.</P>
    *
    * @return <code>true</code> if account page has write cycle counter.
    */
   public boolean hasWriteCycleCounter()
   {      
      return objectInstance.hasWriteCycleCounter();
   }

   /**
    * <P>This function creates the full 15-byte binding data for the
    * coprocessor to use to recreate this user's secret on the copr's
    * workspace page.  This function is located in the SHAiButtonUser
    * class to support binding codes for user buttons who use alternate
    * techniques (such as the DS1961S) for secret computation.</P>
    *
    * @param bindCode the 7-byte binding code from coprocessor's service file
    * @param fullBindCode the 15-byte full binding code to to be copied into
    *                     the coprocessor's scratchpad.  There should be 15
    *                     bytes available starting from the offset.
    * @param offset the offset into fullBindCode where copying should begin.
    *
    */
   public void getFullBindCode(ByteArray l_fullBindCode, int offset)
   {      
      objectInstance.getFullBindCode(l_fullBindCode.array, offset);
   }

   /**
    * <P>Returns a byte representing the appropriate authorization command
    * for the coprocessor to use to authenticate this user.  For a DS1961S,
    * the authentication command is AUTH_HOST, but for a DS1963S, the
    * authentication command is VALIDATE_PAGE.</P>
    *
    * @return byte indicating appropriate command for authenticating user
    *
    */
   public byte getAuthorizationCommand()
   {      
      return objectInstance.getAuthorizationCommand();
   }

   /**
    * <P>Writes the account data to the SHAiButton.  First, this function
    * asserts that the account page number is known.  The account data is
    * copied from dataBuffer starting at the offset.  If there are less
    * than 32 bytes available to copy, this function only copies the bytes
    * that are available.</P>
    *
    * @param dataBuffer the buffer to copy the account data from
    * @param offset the index into the buffer where copying should begin
    * @return whether or not the data write succeeded
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public boolean writeAccountData(ByteArray dataBuffer, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.writeAccountData(dataBuffer.array, offset);
   }

   /**
    * <P>Reads the account data off the SHAiButton using a standard READ
    * command.  First, this function asserts that the account page number is
    * known as well as the length of the account file.  The 32 byte account
    * data page is copied into dataBuffer starting at the given offset.</P>
    *
    * @param dataBuffer the buffer to copy the account data into
    * @param offset the index into the buffer where copying should begin
    * @return whether or not the read was successful
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public boolean readAccountData(ByteArray dataBuffer, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.readAccountData(dataBuffer.array, offset);
   }

   /**
    * <P>Reads the account data off the SHAiButton using a READ_AUTHENTICATE
    * command.  First, this function asserts that the account page number is
    * known as well as the length of the account file.  Then it copies the
    * 3 byte challenge to the scratchpad before sending the command for
    * READ_AUTHENTICATE.  The 32 byte account data page is copied into
    * dataBuffer starting at dataStart.</P>
    *
    * <P>In addition to the account data, this function also returns a
    * calculated MAC.  The MAC requires 20 bytes after the start index.
    * The return value is the write cycle counter value for the account
    * data page<p>
    *
    * @param chlg the buffer containing a 3-byte random challenge.
    * @param chlgStart the index into the buffer where the 3 byte
    *        challenge begins.
    * @param dataBuffer the buffer to copy the account data into
    * @param dataStart the index into the buffer where copying should begin
    * @param mac the buffer to copy the resulting Message Authentication Code
    * @param macStart the index into the mac buffer to start copying
    *
    * @return the value of the write cycle counter for the page
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public int readAccountData(ByteArray chlg, int chlgStart, ByteArray dataBuffer, int dataStart, ByteArray mac, int macStart)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.readAccountData(chlg.array, chlgStart, dataBuffer.array, dataStart, mac.array, macStart);
   }

   /**
    * Refreshes eeprom SHA devices in case of weakly-programmed bits on
    * the account page.
    *
    * @return true if the refresh was successful
    */
   public boolean refreshDevice()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.refreshDevice();
   }

   /**
    * <P>Returns a string representing this SHAiButton.</P>
    *
    * @return a string containing the 8-byte address of this 1-Wire device.
    */
   public java.lang.String toString()
   {      
      return objectInstance.toString();
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   SHAiButtonUser setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.application.sha.SHAiButtonUser)o;
      return this;
   }
}
