// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>Class representing DS1961S (or DS2432), family-code 0x33, SHA iButtons as a user
 * token in SHA Transactions.</P>
 *
 * @see SHATransaction
 * @see SHAiButtonCopr
 * @see SHAiButtonUser18
 *
 * @version CLSID=611EB244-C952-45A9-9BC4-6642B66027B5 -  1.00
 * @author  SKH
 * @com.register ( clsid=611EB244-C952-45A9-9BC4-6642B66027B5, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class SHAiButtonUser33
   extends SHAiButtonUser
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: SHAiButtonUser
   //com.dalsemi.onewire.application.sha.SHAiButtonUser33 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public SHAiButtonUser33()
   {
   }

   SHAiButtonUser33(com.dalsemi.onewire.application.sha.SHAiButtonUser33 o)
   {
      super(o);
   }
   SHAiButtonUser33(java.lang.Object o)
   {
      super((com.dalsemi.onewire.application.sha.SHAiButtonUser33)o);
   }

   /**
    * <P>Initialize a DS1961S as a fresh user iButton for a given SHA service.
    * This constructor not only creates the service file for the user iButton
    * using the TMEX file structure, but it also installs the master
    * authentication secret and binds it to the iButton (making it unique for
    * a particular button).  Optionally, the device can be formatted before
    * the service file is installed.</P>
    *
    * <P>Note: With this constructor, the master secret is installed and bound
    * to the iButton, so the final secret is none by the object.  For that
    * reason, a hardware coprocessor is not necessary for generating the
    * write-authorization MAC.</P>
    *
    * @param copr The SHAiButtonCopr to which the user object is tied.  This
    *        Coprocessor contains the necessary binding code and service
    *        filename, necessary for both locating a user and recreating his
    *        unique secret.
    * @param owc The DS1963S iButton that this object will refer to.
    * @param formatDevice If <code>true</code>, the TMEX filesystem will be
    *        formatted before the account service file is created.
    * @param authSecret The master authentication secret for the systm.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonUser33(SHAiButtonCopr,SHAiButtonCopr,OneWireContainer33)
    * @see #SHAiButtonUser33(SHAiButtonCopr,SHAiButtonCopr)
    */
   public void createNewInstance(SHAiButtonCopr copr, OneWireContainer33 owc, boolean formatDevice, ByteArray authSecret)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonUser33(((com.dalsemi.onewire.application.sha.SHAiButtonCopr)copr.objectInstance), ((com.dalsemi.onewire.container.OneWireContainer33)owc.objectInstance), formatDevice, authSecret.array);
   }

   /**
    * <P>Initialize a DS1961S as a fresh user iButton for a given SHA service.
    * This constructor not only creates the service file for the user iButton
    * using the TMEX file structure, but it also installs the master
    * authentication secret and binds it to the iButton (making it unique for
    * a particular button).  Optionally, the device can be formatted before
    * the service file is installed.</P>
    *
    * <P>Note: With this constructor, the master secret is installed and bound
    * to the iButton, so the final secret is none by the object.  For that
    * reason, a hardware coprocessor is not necessary for generating the
    * write-authorization MAC.</P>
    *
    * @param coprBindCode The Coprocessor Bind Code without the information.
    * @param fileName The file name from the Coprocessor.
    * @param fileNameExt The file extenstion from the Coprocessor
    * @param owc The DS1963S iButton that this object will refer to.
    * @param formatDevice If <code>true</code>, the TMEX filesystem will be
    *        formatted before the account service file is created.
    * @param authSecret The master authentication secret for the systm.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonUser33(SHAiButtonCopr,SHAiButtonCopr,OneWireContainer33)
    * @see #SHAiButtonUser33(SHAiButtonCopr,SHAiButtonCopr)
    */
   public void createNewInstanceFromCoprocessor(ByteArray coprBindCode, ByteArray fileName, int fileNameExt, OneWireContainer33 owc, boolean formatDevice, ByteArray authSecret)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonUser33(coprBindCode.array, fileName.array, fileNameExt, ((com.dalsemi.onewire.container.OneWireContainer33)owc.objectInstance), formatDevice, authSecret.array);
   }

   /**
    * <P>Creates a valid SHAiButtonUser object.  If the service file,
    * whose name is taken from the <code>SHAiButtonCopr</code>, is not
    * found on the user iButton, a OneWireException is thrown with the
    * message "Invalid SHA user".</P>
    *
    * <P>Note: The same coprocessor can be used for write-authorization as
    * authentication if you're transaction system is using unsigned transaction
    * data.</P>
    *
    * @param copr The SHAiButtonCopr to which the user object is tied.  This
    *        Coprocessor contains the necessary binding code and service
    *        filename, necessary for both locating a user and recreating his
    *        unique secret.
    * @param authCopr The SHAiButtonCopr used to generate the write-authorization
    *        MAC for the copy-scratchpad command of the DS1961S.
    * @param owc The DS1961S iButton that this object will refer to.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonUser33(SHAiButtonCopr,OneWireContainer33,boolean,byte[])
    * @see #SHAiButtonUser33(SHAiButtonCopr,SHAiButtonCopr)
    */
   public void createNewInstance(SHAiButtonCopr copr, SHAiButtonCopr authCopr, OneWireContainer33 owc)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonUser33(((com.dalsemi.onewire.application.sha.SHAiButtonCopr)copr.objectInstance), ((com.dalsemi.onewire.application.sha.SHAiButtonCopr)authCopr.objectInstance), ((com.dalsemi.onewire.container.OneWireContainer33)owc.objectInstance));
   }

   /**
    * <P>Initialize a DS1961S as a fresh user iButton for a given SHA service.
    * This constructor not only creates the service file for the user iButton
    * using the TMEX file structure, but it also installs the master
    * authentication secret and binds it to the iButton (making it unique for
    * a particular button).  Optionally, the device can be formatted before
    * the service file is installed.</P>
    *
    * <P>Note: With this constructor, the master secret is installed and bound
    * to the iButton, so the final secret is none by the object.  For that
    * reason, a hardware coprocessor is not necessary for generating the
    * write-authorization MAC.</P>
    *
    * @param coprBindCode The Coprocessor Bind Code without the information.
    * @param fileName The file name from the Coprocessor.
    * @param fileNameExt The file extenstion from the Coprocessor
    * @param owc The DS1963S iButton that this object will refer to.
    * @param formatDevice If <code>true</code>, the TMEX filesystem will be
    *        formatted before the account service file is created.
    * @param authSecret The master authentication secret for the systm.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonUser33(SHAiButtonCopr,SHAiButtonCopr,OneWireContainer33)
    * @see #SHAiButtonUser33(SHAiButtonCopr,SHAiButtonCopr)
    */
   public void createNewInstanceFromCoprocessor(ByteArray coprBindCode, ByteArray fileName, int fileNameExt, OneWireContainer33 owc)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonUser33(coprBindCode.array, fileName.array, fileNameExt, ((com.dalsemi.onewire.container.OneWireContainer33)owc.objectInstance));
   }

   /**
    * <P>Creates a valid SHAiButtonUser object.  If the service file,
    * whose name is taken from the <code>SHAiButtonCopr</code>, is not
    * found on the user iButton, a OneWireException is thrown with the
    * message "Invalid SHA user".</P>
    *
    * <P>Note: The same coprocessor can be used for write-authorization as
    * authentication if you're transaction system is using unsigned transaction
    * data.</P>
    *
    * @param copr The SHAiButtonCopr to which the user object is tied.  This
    *        Coprocessor contains the necessary binding code and service
    *        filename, necessary for both locating a user and recreating his
    *        unique secret.
    * @param authCopr The SHAiButtonCopr used to generate the write-authorization
    *        MAC for the copy-scratchpad command of the DS1961S.
    * @param owc The DS1961S iButton that this object will refer to.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonUser33(SHAiButtonCopr,OneWireContainer33,boolean,byte[])
    * @see #SHAiButtonUser33(SHAiButtonCopr,SHAiButtonCopr)
    */
   public void createNewInstance(SHAiButtonCopr copr, SHAiButtonCopr authCopr)
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonUser33(((com.dalsemi.onewire.application.sha.SHAiButtonCopr)copr.objectInstance), ((com.dalsemi.onewire.application.sha.SHAiButtonCopr)authCopr.objectInstance));
   }

   /**
    * <P>Modifies this SHA iButton so that it refers to another DS1961S
    * container.  This function only copies the reference to the
    * OneWireContainer, copes the reference to it's 1-Wire address, and
    * then asserts that the iButton contains a valid acccount info file
    * associated with the system.</P>
    *
    * @param owc The <code>OneWireContainer33</code> this object will refer to.
    *
    * @return <code>true</code> if a valid account service file exists on
    *         this <code>OneWireContainer33</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public synchronized boolean setiButton33FromCoprocessor(OneWireContainer33 owc)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser33)objectInstance).setiButton33(((com.dalsemi.onewire.container.OneWireContainer33)owc.objectInstance));
   }

   /**
    * <P>Modifies this SHA iButton so that it refers to another 1963S.
    * If this object already has an appropriate instance of OneWireContainer,
    * that instance is updated with the new address.</P>
    *
    * @param adapter The adapter that the device can be found on.
    * @param address The address of the 1-Wire device
    *
    * @return <code>true</code> if a valid account service file exists on
    *         this <code>OneWireContainer18</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public synchronized boolean setiButtonUserFromCoprocessor(DSPortAdapter adapter, ByteArray address)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser33)objectInstance).setiButtonUser(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), address.array);
   }

   /**
    * <P>Modifies this SHA iButton so that it refers to another 1963S.
    * If this object already has an appropriate instance of OneWireContainer,
    * that instance is updated with the new address.</P>
    *
    * @param adapter The adapter that the device can be found on.
    * @param address The address of the 1-Wire device
    *
    * @return <code>true</code> if a valid account service file exists on
    *         this <code>OneWireContainer18</code>.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public synchronized boolean setiButtonUserFromCoprocessor(ByteArray adapter)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser33)objectInstance).setiButtonUser(adapter.array);
   }

   /**
    * <P>Returns the value of the write cycle counter for the
    * page where the account data is stored.  If the write
    * cycle counter has ever been retrieved, this returns the
    * cached value.  Otherwise, this method reads the value
    * from the part.</P>
    *
    * <P>Since the DS1961S has no "write cycle counters", this function
    * always returns -1.</P>
    *
    * @return the value of the write cycle counter for the
    *         account data page.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public synchronized int getWriteCycleCounter()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser33)objectInstance).getWriteCycleCounter();
   }

   /**
    * <P>Returns <code>true</code> if this buttons account data is stored
    * on a page that has a write cycle counter.</P>
    *
    * <P>Since the DS1961S has no "write cycle counters", this function
    * always returns false.</P>
    *
    * @return <code>true</code> if account page has write cycle counter.
    */
   public synchronized boolean hasWriteCycleCounter()
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser33)objectInstance).hasWriteCycleCounter();
   }

   /**
    * <P>Writes the account data to the SHAiButton.  First, this function
    * asserts that the account page number is known.  The account data is
    * copied from dataBuffer starting at the offset.  If there are less
    * than 32 bytes available to copy, this function only copies the bytes
    * that are available.</P>
    *
    * <P>Note that for the DS1961S user button, an authorization MAC must
    * be generated for the copy-scratchpad command.  Since the scratchpad
    * is only 8 bytes long, this must be done 4 times to write a page of
    * data.  So, this function only writes (in 8 byte blocks) the bytes
    * that have changed.</P>
    *
    * @param dataBuffer the buffer to copy the account data from
    * @param offset the index into the buffer where copying should begin
    * @return whether or not the data write succeeded
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public synchronized boolean writeAccountDataFromCoprocessor(ByteArray dataBuffer, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser33)objectInstance).writeAccountData(dataBuffer.array, offset);
   }

   /**
    * <P>Reads the account data off the SHAiButton using a standard READ
    * command.  First, this function asserts that the account page number is
    * known as well as the length of the account file.  The 32 byte account
    * data page is copied into dataBuffer starting at the given offset.</P>
    *
    * @param dataBuffer the buffer to copy the account data into
    * @param offset the index into the buffer where copying should begin
    * @return whether or not the read was successful
    */
   public synchronized boolean readAccountDataFromCoprocessor(ByteArray dataBuffer, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser33)objectInstance).readAccountData(dataBuffer.array, offset);
   }

   /**
    * <P>Reads the account data off the SHAiButton using a READ_AUTHENTICATE
    * command.  First, this function asserts that the account page number is
    * known as well as the length of the account file.  Then it copies the
    * 3 byte challenge to the scratchpad before sending the command for
    * READ_AUTHENTICATE.  The 32 byte account data page is copied into
    * dataBuffer starting at dataStart.</P>
    *
    * <P>In addition to the account data, this function also returns a
    * calculated MAC.  The MAC requires 20 bytes after the start index.
    * The return value is the write cycle counter value for the account
    * data page<p>
    *
    * @param chlg the buffer containing a 3-byte random challenge.
    * @param chlgStart the index into the buffer where the 3 byte
    *        challenge begins.
    * @param dataBuffer the buffer to copy the account data into
    * @param dataStart the index into the buffer where copying should begin
    * @param mac the buffer to copy the resulting Message Authentication Code
    * @param macStart the index into the mac buffer to start copying
    *
    * @return the value of the write cycle counter for the page
    */
   public synchronized int readAccountDataFromCoprocessor(ByteArray chlg, int chlgStart, ByteArray dataBuffer, int dataStart, ByteArray mac, int macStart)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHAiButtonUser33)objectInstance).readAccountData(chlg.array, chlgStart, dataBuffer.array, dataStart, mac.array, macStart);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   SHAiButtonUser setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.application.sha.SHAiButtonUser33)o;
      return this;
   }
}
